//=== calendar ===================================
(function(){
    laf.calendar = {}; //calendar namespace
    
    laf.calendar.addEvent = function(eventTitle, eventDetails, eventDate, eventStartTime, eventEndTime, calendarID, reminderMin, onComplete) {	
        if (calendarID != undefined && calendarID >= 0) {
			//Cleanup scheduled times/date
            var eventBegins = new Date(eventDate.getFullYear(), eventDate.getMonth(), eventDate.getDate(), eventStartTime.getHours(), eventStartTime.getMinutes(), 0);
            var eventEnds = new Date(eventDate.getFullYear(), eventDate.getMonth(), eventDate.getDate(), eventEndTime.getHours(), eventEndTime.getMinutes(), 0);
			
            //Create the event			
            var calendar = Ti.Android.Calendar.getCalendarById(calendarID);			
            var event = calendar.createEvent({
                title: eventTitle,
                description: eventDetails,
                begin: eventBegins,
                end: eventEnds				
			});
            
			//Add a reminder if requested
            if (reminderMin != undefined && reminderMin > 0) {
                event.createReminder({
                    minutes: remainderMin,
                    method: Ti.Android.Calendar.METHOD_DEFAULT					
				});
            }
            
			if (onComplete != undefined) {
				onComplete(event);
			}
        } else {
			if (onComplete != undefined) {
				onComplete();
			}
		}
    };
    
    laf.calendar.eventExists = function(eventTitle, eventDetails, eventDate, eventStartTime, calendarID) {
		if (calendarID != undefined && calendarID >= 0) {
        	var events = Ti.Android.Calendar.getCalendarById(calendarID).getEventsInDate(eventDate.getFullYear(), eventDate.getMonth(), eventDate.getDate());
			if (events != undefined) {
				for (var eventItr = 0, eventItrLen = events.length; eventItr < eventItrLen; eventItr++) {
					if (events[eventItr].title == eventTitle && events[eventItr].description == eventDetails) {
						return true;
					}
				}
			}			
		}
		return false;
    };
    
	//Debug method
    laf.calendar.getEventInCalendar = function(year, calendarID){
        var win = Ti.UI.currentWindow;
        var sv = Ti.UI.createScrollView();
        win.add(sv);
        
        var console = Ti.UI.createLabel({
            backgroundColor: 'white',
            color: 'black',
            text: 'generating info...'
        });
        sv.add(console);
        
        var consoleString = '';
        
        function print(s){
            laf.window.alert(s);
            if (consoleString.length > 0) {
                consoleString = consoleString + '';
            }
            consoleString = consoleString + s;
        }
        
        // SHOW ALL EVENTS FOR ONE CALENDAR
        var YEAR = year;
        var TEST_WITH_THIS_CAL_ID = calendarID;
        var calendar = Ti.Android.Calendar.getCalendarById(TEST_WITH_THIS_CAL_ID);
        
        function printReminder(r){
            var typetext = '[method unknown]';
            if (r.method == Ti.Android.Calendar.METHOD_EMAIL) {
                typetext = 'Email';
            }
            else 
                if (r.method == Ti.Android.Calendar.METHOD_SMS) {
                    typetext = 'SMS';
                }
                else 
                    if (r.method == Ti.Android.Calendar.METHOD_ALERT) {
                        typetext = 'Alert';
                    }
                    else 
                        if (r.method == Ti.Android.Calendar.METHOD_DEFAULT) {
                            typetext = '[default reminder method]';
                        }
            laf.window.alert(typetext + ' reminder to be sent ' + r.minutes + ' minutes before the event');
        }
        
        function printAlert(a){
            laf.window.alert('Alert id ' + a.id + ' begin ' + a.begin + '; end ' + a.end + '; alarmTime ' + a.alarmTime + '; minutes ' + a.minutes);
        }
        
        function printEvent(event){
            if (event.allDay) {
                laf.window.alert('Event: ' + event.title + '; ' + event.begin.toLocaleDateString() + ' (all day)');
            }
            else {
                laf.window.alert('Event: ' + event.title + '; ' + event.begin.toLocaleDateString() + ' ' + event.begin.toLocaleTimeString() + '-' + event.end.toLocaleTimeString());
            }
            
            var reminders = event.reminders;
            if (reminders && reminders.length) {
                laf.window.alert('There is/are ' + reminders.length + ' reminder(s)');
                for (var i = 0; i < reminders.length; i++) {
                    printReminder(reminders[i]);
                }
            }
            
            laf.window.alert('hasAlarm? ' + event.hasAlarm);
            var alerts = event.alerts;
            if (alerts && alerts.length) {
                for (i = 0; i < alerts.length; i++) {
                    printAlert(alerts[i]);
                }
            }
            
            var status = event.status;
            if (status == Ti.Android.Calendar.STATUS_TENTATIVE) {
                laf.window.alert('This event is tentative');
            }
            if (status == Ti.Android.Calendar.STATUS_CONFIRMED) {
                laf.window.alert('This event is confirmed');
            }
            if (status == Ti.Android.Calendar.STATUS_CANCELED) {
                laf.window.alert('This event was canceled');
            }
        }
        
        var events = calendar.getEventsInYear(YEAR);
        if (events && events.length) {
            laf.window.alert(events.length + ' event(s) in ' + YEAR);
            laf.window.alert('');
            for (var i = 0; i < events.length; i++) {
                printEvent(events[i]);
                laf.window.alert('');
            }
        }
        else {
            laf.window.alert('No events on 2010-12-6');
        }
        console.text = consoleString;
    };
    
    laf.calendar.getID = function(calendarName){
        for (var cal = 0, calLength = Ti.Android.Calendar.selectableCalendars.length; cal < calLength; cal++) {
            if (Ti.Android.Calendar.selectableCalendars[cal].name == calendarName) {
                return Ti.Android.Calendar.selectableCalendars[cal].id;
            }
        }
    };
    
    laf.calendar.getName = function(calendarID){
        for (var cal = 0, calLength = Ti.Android.Calendar.selectableCalendars.length; cal < calLength; cal++) {
            if (Ti.Android.Calendar.selectableCalendars[cal].id == calendarID) {
                return Ti.Android.Calendar.selectableCalendars[cal].name;
            }
        }
    };
    
    laf.calendar.picker = function(dialogTitle, onComplete){
        var calendarNames = [];
        
        //Get all writeable calendars
        for (var calArray = 0, calArrayLen = Ti.Android.Calendar.selectableCalendars.length; calArray < calArrayLen; calArray++) {
            calendarNames.push(Ti.Android.Calendar.selectableCalendars[calArray].name);
        }
        
        //Display an option dialog of calendars to add to
        var odConfirmCalendar = Ti.UI.createOptionDialog({
            options: calendarNames,
            title: (dialogTitle != undefined) ? dialogTitle : 'Pick a calendar to add this event to',
            buttonNames: ['Cancel']
        });
        odConfirmCalendar.addEventListener('click', function(e){
            if (onComplete != undefined) {
                if ((e.index == 0 && e.button) || (calendarNames[e.index] == undefined)) {
                    onComplete(-1);
                } else {
                	onComplete(laf.calendar.getID(calendarNames[e.index]));					
				}
            }            
        });
        odConfirmCalendar.show();
    };
    
})();
