//=== data ===================================
(function(){
    function getDB(dbName){
        var db, rows;
        
        try {
            db = Ti.Database.open(dbName);
            if (db != undefined) {
                //Ensure database has tables and is not a newly created blank database
                rows = db.execute('SELECT name FROM sqlite_master WHERE type=\'table\' AND name <> \'android_metadata\'');
            }
            if (db == undefined || rows == undefined || rows.rowCount == 0) {
                if (rows != undefined) {
                    rows.close();
                }
                if (db != undefined) {
                    db.remove();
                    db.close();
                }
                
                Ti.API.info('Installing DB ' + dbName);
                var dbPath = (Ti.Platform.name == 'iPhone OS') ? Ti.Filesystem.getFile(Ti.Filesystem.resourcesDirectory).path + '/data/' : 'data/';
                db = Ti.Database.install(dbPath + dbName + '.db', dbName);
                
                if (dbName == 'club') {
                    Ti.App.Properties.removeProperty('LastUpdate');
                    Ti.App.Properties.removeProperty('LastUpdateCheck');
                }
            }
            else {
                rows.close();
            }
        } 
        catch (er) {
            Ti.API.info('DB Error ' + er);
        }
        
        return db;
    }
    
    function executeNonQuery(db, sqlQuery){
        var result = 0;
        
        try {
            db.execute(sqlQuery);
            result = db.rowsAffected;
            db.close();
        } 
        catch (er) {
            Ti.API.info('DB Error ' + er);
        }
        
        return result;
    }
    
    function executeScalar(db, sqlQuery){
        var result;
        
        try {
            var rows = db.execute(sqlQuery);
            if (rows != undefined) {
                if (rows.isValidRow() && rows.getFieldCount() > 0) {
                    result = rows.field(0);
                }
                rows.close();
            }
            db.close();
        } 
        catch (er) {
            Ti.API.info('DB Error ' + er);
        }
        
        return result;
    }
    
    function executeRow(db, sqlQuery, fieldNames){
        var rowObj = {};
        
        try {
            var rows = db.execute(sqlQuery);
            if (rows != undefined) {
                if (rows.isValidRow()) {
                    for (var i = 0, fieldCount = rows.getFieldCount(); i < fieldCount; i++) {
                        if (fieldNames == undefined || fieldNames.length < i || fieldNames[i] == undefined) {
                            rowObj[rows.fieldName(i)] = rows.field(i);
                        }
                        else {
                            rowObj[fieldNames[i]] = rows.field(i);
                        }
                    }
                }
                rows.close();
            }
            db.close();
        } 
        catch (er) {
            Ti.API.info('DB Error ' + er);
        }
        
        return rowObj;
    }
    
    function executeSet(db, sqlQuery, fieldNames){
        var resultSet = [];
        
        try {
            var rows = db.execute(sqlQuery);
            if (rows != undefined) {
                while (rows.isValidRow()) {
                    var rowObj = {};
                    for (var i = 0, fieldCount = rows.getFieldCount(); i < fieldCount; i++) {
                        if (fieldNames == undefined || fieldNames.length < i || fieldNames[i] == undefined) {
                            rowObj[rows.fieldName(i)] = rows.field(i);
                        }
                        else {
                            rowObj[fieldNames[i]] = rows.field(i);
                        }
                    }
                    resultSet.push(rowObj);
                    rows.next();
                }
                rows.close();
            }
            db.close();
        } 
        catch (er) {
            Ti.API.info('DB Error ' + er);
        }
        
        return resultSet;
    }
    
    laf.data = {}; //db namespace
    laf.data.clubRow = function(sqlQuery, fieldNames){
        return executeRow(getDB('club'), sqlQuery, fieldNames);
    };
    
    laf.data.clubScalar = function(sqlQuery){
        return executeScalar(getDB('club'), sqlQuery);
    };
    
    laf.data.clubSet = function(sqlQuery, fieldNames){
        return executeSet(getDB('club'), sqlQuery, fieldNames);
    };
    
    laf.data.exerciseRow = function(sqlQuery, fieldNames){
        return executeRow(getDB('exercise'), sqlQuery, fieldNames);
    };
    
    laf.data.exerciseScalar = function(sqlQuery){
        return executeScalar(getDB('exercise'), sqlQuery);
    };
    
    laf.data.exerciseSet = function(sqlQuery, fieldNames){
        return executeSet(getDB('exercise'), sqlQuery, fieldNames);
    };
    
    laf.data.postalRow = function(sqlQuery, fieldNames){
        return executeRow(getDB('postal'), sqlQuery, fieldNames);
    };
    
    laf.data.postalScalar = function(sqlQuery){
        return executeScalar(getDB('postal'), sqlQuery);
    };
    
    laf.data.postalSet = function(sqlQuery, fieldNames){
        return executeSet(getDB('postal'), sqlQuery, fieldNames);
    };
    
    laf.data.fitnessTipsScalar = function(sqlQuery){
        return executeScalar(getDB('fitnessTips'), sqlQuery);
    };
    
    laf.data.workoutMakeSync = function(tableName, GUID, inactive, fieldNames, fieldValues){
        var nowUTC = laf.dateTime.toString(new Date(), 'utc');
        var fieldLen = (fieldNames == undefined || fieldValues == undefined || fieldNames.length != fieldValues.length) ? 0 : fieldNames.length;
        var sqlQuery = '';
        
        if (GUID != undefined && executeScalar(getDB('workout'), 'SELECT GUID FROM ' + tableName + ' WHERE GUID = "' + GUID + '"') != undefined) {
            sqlQuery = 'UPDATE ' + tableName + ' ';
            sqlQuery += 'SET CreateUTC = ifnull(CreateUTC, "' + nowUTC + '"), ';
            sqlQuery += 'UpdateUTC = "' + nowUTC + '", ChangeSourceID = "' + 15 + '", Inactive = "';
            sqlQuery += (inactive == undefined || inactive == false) ? 0 + '" ' : 1 + '" ';
            
            if (fieldLen > 0) {
                for (var fieldItr = 0; fieldItr < fieldLen; fieldItr++) {
                    sqlQuery += ", " + fieldNames[fieldItr];
                    sqlQuery += (fieldValues[fieldItr] == undefined || fieldValues[fieldItr].toString().toLowerCase() == 'null') ? ' = null ' : ' = "' + fieldValues[fieldItr] + '" ';
                }
            }
            
            sqlQuery += 'WHERE GUID = "' + GUID + '"';
        }
        else {
			if (GUID == undefined) {
            	GUID = laf.object.newGUID();
			}
			
            sqlQuery = 'INSERT INTO ' + tableName + ' ';
            sqlQuery += '(GUID, CreateUTC, UpdateUTC, ChangeSourceID, Inactive';
            
            if (fieldLen > 0) {
                for (var fieldNameItr = 0; fieldNameItr < fieldLen; fieldNameItr++) {
                    sqlQuery += ', ' + fieldNames[fieldNameItr];
                }
            }
            
            sqlQuery += ') VALUES ("' + GUID + '", "' + nowUTC + '", "' + nowUTC + '", "' + 15 + '", "';
            sqlQuery += (inactive == undefined || inactive == false) ? 0 + '"' : 1 + '"';
            
            if (fieldLen > 0) {
                for (var fieldValueItr = 0; fieldValueItr < fieldLen; fieldValueItr++) {
                    sqlQuery += (fieldValues[fieldValueItr] == undefined || fieldValues[fieldValueItr].toString().toLowerCase() == 'null') ? ', null' : ', "' + fieldValues[fieldValueItr] + '" ';
                }
            }
            
            sqlQuery += ')';
        }
        
        return executeNonQuery(getDB('workout'), sqlQuery);
    };
    
    laf.data.workoutNonQuery = function(sqlQuery){
        return executeNonQuery(getDB('workout'), sqlQuery);
    };
    
    laf.data.workoutRow = function(sqlQuery, fieldNames){
        return executeRow(getDB('workout'), sqlQuery, fieldNames);
    };
    
    laf.data.workoutScalar = function(sqlQuery){
        return executeScalar(getDB('workout'), sqlQuery);
    };
    
    laf.data.workoutSet = function(sqlQuery, fieldNames){
        return executeSet(getDB('workout'), sqlQuery, fieldNames);
    };
    
    laf.data.updateDB = function(dbName, dbPath, oncomplete){
        //Wait for any running DB operations to finish
        //Shouldn't be any, being as we are on same thread
        setTimeout(function(){
            try {
                //Remove current DB
                var db = Ti.Database.open(dbName);
                db.remove();
                db.close();
                
                //Install new DB
                db = Ti.Database.install(dbPath, dbName); //Install new DB
                db.close();
                
                if (oncomplete != undefined) {
                    oncomplete();
                }
            } 
            catch (er) {
                if (oncomplete != undefined) {
                    oncomplete();
                }
            }
        }, 3000);
    };
})();
