//=== dateTime ===================================
(function () {
    laf.dateTime = {}; //dateTime namespace
    
    laf.dateTime.getTimezoneSign = function (dateAndTime) {
        return (dateAndTime.getTimezoneOffset() > 0) ? '-' : '+';
    };
    
    laf.dateTime.toString = function (dateAndTime, kind) {
        //We are going to use our own datetime serialization due to:
        //#1 the difference between .NETs JSON serialization and appcelerator serialization
        //#2 the lack of ability to specifiy 'kind' in javascript - 'unspecified' kind is important for us
        switch (kind.toLowerCase()) {
            //Use this if the timezone is known and automatic adjustments to the users timezone is preferred
        case 'utc':
            var utcDate = new Date(dateAndTime.getTime() + (dateAndTime.getTimezoneOffset() * 60 * 1000));
            return '' + utcDate.getFullYear() + '-' + String("0" + (utcDate.getMonth() + 1)).slice(-2) + '-' + String("0" + utcDate.getDate()).slice(-2) + 'T' + String("0" + utcDate.getHours()).slice(-2) + ':' + String("0" + utcDate.getMinutes()).slice(-2) + ':' + String("0" + utcDate.getSeconds()).slice(-2) + '.' + String("00" + dateAndTime.getMilliseconds()).slice(-3) + 'Z';
            //Use this if the timezone is unknown OR if no adjustments to the users timezone is preferred	
        case 'unspecified':
            return '' + dateAndTime.getFullYear() + '-' + String("0" + (dateAndTime.getMonth() + 1)).slice(-2) + '-' + String("0" + dateAndTime.getDate()).slice(-2) + 'T' + String("0" + dateAndTime.getHours()).slice(-2) + ':' + String("0" + dateAndTime.getMinutes()).slice(-2) + ':' + String("0" + dateAndTime.getSeconds()).slice(-2) + '.' + String("00" + dateAndTime.getMilliseconds()).slice(-3);
            //WARNING! Do not use Local time for any dates that will be stored.  
            //			Daylight savings time shifts will cause it to be wrong.	
            //			Use this only for temporary/session storage or for transport
        case 'local':
            return '' + dateAndTime.getFullYear() + '-' + String("0" + (dateAndTime.getMonth() + 1)).slice(-2) + '-' + String("0" + dateAndTime.getDate()).slice(-2) + 'T' + String("0" + dateAndTime.getHours()).slice(-2) + ':' + String("0" + dateAndTime.getMinutes()).slice(-2) + ':' + String("0" + dateAndTime.getSeconds()).slice(-2) + '.' + String("00" + dateAndTime.getMilliseconds()).slice(-3) + laf.dateTime.getTimezoneSign(dateAndTime) + String("0" + (Math.abs(dateAndTime.getTimezoneOffset())/60)).slice(-2)+':00';
        }
    };
    
    laf.dateTime.fromString = function (string) {
        var regexp = /^([0-9]{4})(\-([0-9]{2})(\-([0-9]{2})(T([0-9]{2}):([0-9]{2})(:([0-9]{2})(\.([0-9]+))?)?(Z|(([\-+])([0-9]{2}):([0-9]{2})))?)?)?)?$/;
        var d = string.match(regexp);
        var offset = 0;
        var date = new Date(d[1], 0, 1);

        if (d[3]) { date.setMonth(d[3] - 1); }
        if (d[5]) { date.setDate(d[5]); }
        if (d[7]) { date.setHours(d[7]); }
        if (d[8]) { date.setMinutes(d[8]); }
        if (d[10]) { date.setSeconds(d[10]); }
        if (d[12]) { date.setMilliseconds(Number("0." + d[12]) * 1000); }
        if (d[14]) {
            offset = (Number(d[16]) * 60) + Number(d[17]);
            offset *= ((d[15] == '-') ? 1 : -1);
        } else if (string.substring(string.length-1) == 'Z') {
            offset = 0;
        } else {
            offset = date.getTimezoneOffset();
        }

        offset -= date.getTimezoneOffset();
        time = (Number(date) + (offset * 60 * 1000));
        return new Date(time);
    };
    
    laf.dateTime.toDateString = function (date, seperatorChar) {
		if (date == undefined) {
			date = new Date();
		}
		
		if (typeof(date) != date) {
			var tmpDate = new Date(date);
			if (isNaN(tmpDate.getMonth())) {
				tmpDate = new Date(date.replace(/-/g, '/')); //JS does not recognize 2010-11-1 for conversion to date
			}
			date = tmpDate;
		}

        if (seperatorChar == undefined) {
            seperatorChar = '/'; //JS does not recognize 2010-11-1 for conversion to date
        }
    
        var month = (date.getMonth() + 1).toString();
        if (month.length == 1) {
            month = '0' + month;
        }
	
        var day = date.getDate().toString();
        if (day.length == 1) {
            day = '0' + day;
        }
        
        return date.getFullYear() + seperatorChar + month + seperatorChar + day;
    };
    
    laf.dateTime.toTimeString = function (dateTime, showFullTime) {
        var d = new Date(dateTime);
        
        var curr_hour = d.getHours();
        var a_p = (curr_hour < 12) ? 'AM' : 'PM';
        if (curr_hour > 12) {
            curr_hour = curr_hour - 12;
        } else if (curr_hour == 0) {
            curr_hour = 12;
        }        

        var curr_min = d.getMinutes().toString();
        if (curr_min.length == 1) {
            curr_min = '0' + curr_min;
        }
        
        if (curr_min == '00') {
            if (curr_hour == 12) {
                return (a_p == 'AM') ? 'Midnight' : 'Noon';
            } else {
                return (showFullTime == undefined || showFullTime == false) ? curr_hour + a_p : curr_hour + ':00' + a_p;
            }
        } else {
            return curr_hour + ':' + curr_min + a_p;
        }
    };   
})();
