//=== location ===================================
(function() {
    var clubDistance = [];
    var clubFilterString = '';
    var lastLon = 0;
    var lastLat = 0;
    var lastRadius = 0;
    var radConvert = Math.PI / 180;

    var gpsTimer;
    var gpsLat = 0;
    var gpsLon = 0;
    var gpsLocation = '';
    var gpsAccuracy = 9999999;
    var gpsCounter = 0;
    var gpsOnComplete;
    var gpsAndroidActivity = undefined;
    var locationAdded = false;

    if (laf.device.isiPhone()) {
        Ti.Geolocation.purpose = 'Find Nearby Clubs & Activities'; //Required iOS 3.2+
    }

    function approxZipCode(lat, lon) {
        var closestZIP = '';
        var closestDistance = 100;

        lat = parseFloat(lat);
        lon = parseFloat(lon);

        var zipCodes = laf.data.postalSet('SELECT Latitude, Longitude, PostalCode FROM PostalCodes WHERE Latitude <= \'' + (lat + 1) + '\' AND Latitude >= \'' + (lat - 1) + '\' AND Longitude >= \'' + (lon + 1) + '\' AND Longitude <= \'' + (lon - 1) + '\'', ['Lat', 'Lon', 'PostalCode']);
        if (zipCodes != undefined && zipCodes.length > 0) {
            for (var zipItr = 0, zipLen = zipCodes.length; zipItr < zipLen; zipItr++) {
                var dist = haversineDistance(lat, lon, zipCodes[zipItr].Lat, zipCodes[zipItr].Lon);
                if (dist < closestDistance) {
                    closestDistance = dist;
                    closestZIP = zipCodes[zipItr].PostalCode;
                }
            }

            //Check that it's a reasonable approximation
            if (closestDistance > 15) {
                closestZIP = '';
            }
        }

        return closestZIP;
    };

    function haversineDistance(lat_1, lon_1, lat_2, lon_2) {
        //Reduce math logic by filtering those that are already too far
        //Now filtered in SQL, thus no need to do here for every one
        //if (lat_1 + 1 < lat_2 || lat_1 - 1 > lat_2 || lon_1 + 1 < lon_2 || lon_1 - 1 > lon_2) {
        //    return 100.0;
        //}

        var diffLat = (lat_2 - lat_1) * radConvert;
        var diffLon = (lon_2 - lon_1) * radConvert;
        var a = Math.pow(Math.sin(diffLat / 2.0), 2.0) + Math.cos(lat_1 * radConvert) * Math.cos(lat_2 * radConvert) * Math.pow(Math.sin(diffLon / 2.0), 2.0);
        var d = 7918 * Math.atan2(Math.sqrt(a), Math.sqrt(1.0 - a)); //7918 = 3959 * 2
        return parseFloat(d);
    }

    //GPS Logic broken out to avoid too deep recursion	
    function gpsUpdateLocation(e) {
        try {
            if (!e.success || e.error) {
                return;
            }

            if (e.coords.accuracy != undefined && e.coords.latitude != undefined && e.coords.longitude != undefined) {
                if (e.coords.latitude != 0 && e.coords.longitude != 0) {
                    gpsLat = e.coords.latitude;
                    gpsLon = e.coords.longitude;
                    gpsAccuracy = e.coords.accuracy;
                    gpsLocation = gpsLat.toFixed(4) + ', ' + gpsLon.toFixed(4);
                }
            }
        }
        catch (er) {
        }
    }

    //GPS Logic broken out to avoid too deep recursion	
    function gpsIntervalCheck() {
        gpsCounter++;
        if (gpsCounter < 10 && (gpsAccuracy > 100 || laf.device.isAndroid())) {
            if (gpsCounter < 7) {
                Ti.Geolocation.preferredProvider = Ti.Geolocation.PROVIDER_GPS;
                Ti.Geolocation.accuracy = Ti.Geolocation.ACCURACY_BEST;

                Ti.Geolocation.getCurrentPosition(gpsUpdateLocation);
            }
            else {
                if (gpsLat == undefined || gpsLon == undefined || (gpsLat == 0 && gpsLon == 0)) {
                    //If it's been awhile and we still don't have a position, lower expectations								
                    Ti.Geolocation.preferredProvider = Ti.Geolocation.PROVIDER_NETWORK;
                    Ti.Geolocation.accuracy = Ti.Geolocation.ACCURACY_KILOMETER;

                    Ti.Geolocation.getCurrentPosition(gpsUpdateLocation);
                }
            }
        }
        else {
            removeGeolocationListeners(); //Stop GPS, timer
            if (!Ti.Network.online || gpsLat == undefined || gpsLon == undefined || (gpsLat == 0 && gpsLon == 0)) {
                if (gpsLat != undefined && gpsLon != undefined && (gpsLat != 0 && gpsLon != 0)) {
                    var posLocation = approxZipCode(gpsLat, gpsLon);
                    gpsLocation = (posLocation.length > 0) ? posLocation : gpsLocation;
                }

                if (gpsOnComplete != undefined) {
                    gpsOnComplete(gpsLat, gpsLon, gpsLocation);
                }
            }
            else {
                Ti.Geolocation.reverseGeocoder(gpsLat, gpsLon, function(evt) {
                    if (evt != undefined && evt.places != undefined && evt.places.length > 0) {
                        gpsLocation = (evt.places[0].zipcode == undefined) ? evt.places[0].postalCode : evt.places[0].zipcode;
                    }
                    else {
                        var posLocation = approxZipCode(gpsLat, gpsLon);
                        gpsLocation = (posLocation.length > 0) ? posLocation : gpsLocation;
                    }

                    if (gpsOnComplete != undefined) {
                        gpsOnComplete(gpsLat, gpsLon, gpsLocation);
                    }
                });
            }
        }
    }

    //Function for removing android listeners
    function removeAndroidListeners() {
        if (locationAdded) {
            removeGeolocationListeners();

            if (gpsAndroidActivity != undefined) {
                gpsAndroidActivity.removeEventListener('pause', removeAndroidListeners);
                gpsAndroidActivity.removeEventListener('destroy', removeAndroidListeners);
            }

            if (gpsOnComplete != undefined) {
                gpsOnComplete(gpsLat, gpsLon, gpsLocation);
            }
        }
    }

    //Function for removing geolocation
    function removeGeolocationListeners() {
        if (locationAdded) {
            if (gpsTimer != undefined) {
                clearInterval(gpsTimer);
                gpsTimer = undefined;
            }

            Ti.Geolocation.removeEventListener('location', gpsUpdateLocation);
            locationAdded = false;
        }
    }

    laf.location = {}; //location namespace
    laf.location.addClubDistance = function(clubs, sort) {
        for (var clubItr = 0, clubItrLen = clubs.length; clubItr < clubItrLen; clubItr++) {
            if (clubs[clubItr] != undefined) {
                if (clubs[clubItr].CLUB_ID != undefined) {
                    clubs[clubItr].Distance = clubDistance[parseInt(clubs[clubItr].CLUB_ID, 10)];
                }
                else
                    if (clubs[clubItr].ClubID != undefined) {
                    clubs[clubItr].Distance = clubDistance[parseInt(clubs[clubItr].ClubID, 10)];
                }
                else
                    if (clubs[clubItr].ID != undefined) {
                    clubs[clubItr].Distance = clubDistance[parseInt(clubs[clubItr].ID, 10)];
                }
            }
        }

        if (sort == undefined || sort == true) {
            clubs.sort(laf.location.distanceSort);
        }
    };

    laf.location.clubDistance = function() {
        if (clubDistance.length == 0) {
            laf.location.filterClubs(Ti.App.Properties.getString('Latitude'), Ti.App.Properties.getString('Longitude'), 50);
        }
        return clubDistance;
    };

    laf.location.clubFilterString = function() {
        if (clubFilterString.length == 0) {
            laf.location.filterClubs(Ti.App.Properties.getString('Latitude'), Ti.App.Properties.getString('Longitude'), 50);
        }
        return clubFilterString;
    };

    laf.location.distanceSort = function(a, b) {
        return ((a.Distance < b.Distance) ? -1 : ((a.Distance > b.Distance) ? 1 : 0));
    };

    laf.location.enabled = function() {
        return !(Ti.Geolocation.locationServicesEnabled == undefined || Ti.Geolocation.locationServicesEnabled == false ||
        laf.device.isSimulator() ||
        (laf.device.isiPhone() && Ti.Geolocation.locationServicesAuthorization != undefined &&
        (Ti.Geolocation.locationServicesAuthorization == Ti.Geolocation.AUTHORIZATION_DENIED ||
        Ti.Geolocation.locationServicesAuthorization == Ti.Geolocation.AUTHORIZATION_RESTRICTED)));
    };

    laf.location.filterClubs = function(latitude, longitude, radius) {
        if (latitude != undefined && longitude != undefined && latitude != '' && longitude != '') {
            latitude = parseFloat(latitude);
            longitude = parseFloat(longitude);

            //Don't refilter if we have the same search parameters
            if (latitude != lastLat || longitude != lastLon || radius != lastRadius) {
                lastLat = latitude;
                lastLon = longitude;
                lastRadius = radius;

                var newClubDistace = [];
                var newClubFilter = [];
                radius++; //account for clubs that are 5.1, 5.9 miles away as we truncate the decimal in display 
                var clubs = laf.data.clubSet('SELECT CLUB_ID, LAT, LON FROM Club  WHERE LAT <= \'' + (latitude + 1) + '\' AND LAT >= \'' + (latitude - 1) + '\' AND LON >= \'' + (longitude + 1) + '\' AND LON <= \'' + (longitude - 1) + '\'', ['ClubID', 'Lat', 'Lon']);
                for (var clubsItr = 0, clubsLen = clubs.length; clubsItr < clubsLen; clubsItr++) {
                    if (clubs[clubsItr] != undefined) {
                        var dist = haversineDistance(latitude, longitude, parseFloat(clubs[clubsItr].Lat), parseFloat(clubs[clubsItr].Lon));
                        if (dist < radius) {
                            newClubDistace[parseInt(clubs[clubsItr].ClubID, 10)] = dist;
                            newClubFilter.push(clubs[clubsItr].ClubID);
                        }
                    }
                }

                //Sort so different locations with the same clubs in radius will have different string
                newClubFilter.sort(function(a, b) {
                    return newClubDistace[a] - newClubDistace[b];
                });

                clubDistance = newClubDistace;
                clubFilterString = (newClubFilter.length == 0) ? '' : '\'' + newClubFilter.join('\',\'') + '\'';
            }
        }
    };

    //Get LAT & LON from user entered location
    laf.location.freeEntry = function(strLocation, oncomplete) {
        var lat = 0;
        var lon = 0;
        var location = '';

        if (!laf.network.isConnected(false)) {
            if (oncomplete != undefined) {
                oncomplete(lat, lon, location);
            }
        }
        else {
            var xhrGeocode = Ti.Network.createHTTPClient();
            xhrGeocode.setTimeout(120000);
            xhrGeocode.onload = function(e) {
                var response = JSON.parse(this.responseText);
                if (response.status == 'OK' && response.results != undefined && response.results.length > 0) {
                    lat = response.results[0].geometry.location.lat;
                    lon = response.results[0].geometry.location.lng;
                    location = strLocation;

                    var canadianPostalPattern = /^[A-Z]\d[A-Z][\- |]?\d[A-Z]\d$/;
                    if (canadianPostalPattern.test(strLocation.toUpperCase())) {
                        //Don't reverse GEO canadian postal codes as google just uses the first part 'L6T 3S1' becomes 
                        //the cener of the first part so 'L6T' would remain the same but the second part may not
                        location = location.toUpperCase();
                        if (oncomplete != undefined) {
                            oncomplete(lat, lon, location);
                        }
                    }
                    else {
                        //Get Actual Zip Code if Possible
                        /*Ti.Geolocation.reverseGeocoder(lat, lon, function(evt) {
                        var places = evt.places;
                        if (places != undefined && places.length > 0) {
                        location = (places[0].zipcode == undefined) ? places[0].postalCode : places[0].zipcode;
                        }
                        if (oncomplete != undefined) {
                        oncomplete(lat, lon, location);
                        }
                        });*/
                        if (oncomplete != undefined) {
                            oncomplete(lat, lon, location);
                        }
                    }
                }
                else
                    if (oncomplete != undefined) {
                    oncomplete(lat, lon, location);
                }
            };

            xhrGeocode.onerror = function(e) {
                if (oncomplete != undefined) {
                    oncomplete(lat, lon, location);
                }
            };

            var url = "http://maps.google.com/maps/api/geocode/json?address=" + strLocation.replace(' ', '+');
            url += "&sensor=" + (Ti.Geolocation.locationServicesEnabled == true);
            xhrGeocode.open("GET", url);
            xhrGeocode.setRequestHeader('Content-Type', 'application/json; charset=utf-8');
            xhrGeocode.send();
        }
    };

    //Get LAT & LON from device's GPS
    laf.location.gps = function(oncomplete, androidActivity) {
        gpsLat = 0;
        gpsLon = 0;
        gpsLocation = '';
        gpsAccuracy = 9999999;
        gpsCounter = 0;
        gpsOnComplete = oncomplete;
        gpsAndroidActivity = androidActivity;

        if (!laf.location.enabled()) {
            if (gpsOnComplete != undefined) {
                gpsOnComplete(gpsLat, gpsLon, gpsLocation);
            }
        }
        else {
            try {
                Ti.Geolocation.accuracy = Ti.Geolocation.ACCURACY_BEST;
                Ti.Geolocation.distanceFilter = 1;

                //Try getting one location before forcing GPS				
                Ti.Geolocation.getCurrentPosition(gpsUpdateLocation);
                Ti.Geolocation.addEventListener('location', gpsUpdateLocation);
                locationAdded = true;

                if (gpsAndroidActivity != undefined) {
                    gpsAndroidActivity.addEventListener('pause', removeAndroidListeners);
                    gpsAndroidActivity.addEventListener('destory', removeAndroidListeners);
                }

                gpsTimer = setInterval(gpsIntervalCheck, 1250);
            }
            catch (er) {
                if (timer != undefined) {
                    clearInterval(gpsTimer);
                }

                if (laf.device.isiPhone()) {
                    Ti.Geolocation.removeEventListener('location', gpsUpdateLocation);
                }

                if (laf.device.isAndroid()) {
                    removeGeolocationListeners();
                }

                if (gpsOnComplete != undefined) {
                    gpsOnComplete(gpsLat, gpsLon, gpsLocation);
                }
            }
        }
    };

    //Get LAT & LON from a provided postal code
    laf.location.postalCode = function(strPostalCode) {
        return laf.data.postalRow('SELECT Latitude, Longitude FROM PostalCodes WHERE PostalCode = \'' + strPostalCode + '\'', ['Lat', 'Lon']);
    };

    //On load of app try creating the list of clubs
    laf.location.filterClubs(Ti.App.Properties.getString('Latitude'), Ti.App.Properties.getString('Longitude'), 50);

})();
