//=== object ===================================
(function(){
    //Extend an object with the properties from another (thanks Dojo)
    //public API defined by laf.object.extend - calls private function mixin
    var empty = {};
    function mixin(/*Object*/target, /*Object*/ source){
        var name, s, i;
        for (name in source) {
            if (source.hasOwnProperty(name)) {
                s = source[name];
                if (!(name in target) || (target[name] !== s && (!(name in empty) || empty[name] !== s))) {
                    target[name] = s;
                }
            }
        }
        return target; // Object
    };
    
    laf.object = {}; //object namespace
    
    laf.object.isArray = function(obj){
        return !!(obj && obj.concat && obj.unshift && !obj.callee);
    };
    
    laf.object.isNull = function(obj){
        return (obj == undefined || obj == null);
    };
    
    laf.object.isNullOrEmpty = function(obj){
        return (obj == undefined || obj == null || (obj.length != undefined && obj.length == 0));
    };
    
    laf.object.extend = function(/*Object*/obj, /*Object...*/ props){
        if (!obj) {
            obj = {};
        }
        for (var i = 1, l = arguments.length; i < l; i++) {
            mixin(obj, arguments[i]);
        }
        return obj; // Object
    };
    
    //Flexible wrappers around the properties API for persisting any JavaScript object
    laf.object.isSaved = function( /*String*/key){
        return Ti.App.Properties.hasProperty(key);
    };
    
    laf.object.save = function( /*String*/key, /*Object*/ val){
        Ti.App.Properties.setString(key, JSON.stringify(val));
    };
    
    laf.object.load = function( /*String*/key){
        var value = Ti.App.Properties.getString(key);
        try {
            return JSON.parse(value);
        } 
        catch (e) {
            return value;
        }
    };
    
    laf.object.remove = function( /*String*/key){
        Ti.App.Properties.removeProperty(key);
    };
    
    //Methods for synching data objects
    laf.object.newGUID = function(){
        return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function(c){
            var r = Math.random() * 16 | 0, v = c == 'x' ? r : (r & 0x3 | 0x8);
            return v.toString(16);
        }).toUpperCase();
    };
    
    laf.object.makeSync = function(obj, operation){
        var now = new Date();
        
        obj.ChangeSourceID = 15;
        obj.UpdateUTC = laf.dateTime.toString(now, 'utc');
        
        if (obj.GUID == undefined) {
            obj.GUID = laf.object.newGUID();
        }
        
        if (obj.CreateUTC == undefined) {
            obj.CreateUTC = laf.dateTime.toString(now, 'utc');
        }
        
        if (operation != undefined && operation.toLowerCase() == 'delete') {
            obj.Inactive = 1;
        }
        else 
            if (obj.Inactive == undefined) {
                obj.Inactive = 0;
            }
        
        return obj;
    };
})();
