//=== table ===================================
(function(){
    var rowCounter = 0; //Used to make different rows unique as even different icons may cause display issues.
    laf.table = {}; //table namespace
    laf.table.uniqueClass = function(){
		//Use sparingly, Android has limit of 29 class names in lifetime of a table
        return rowCounter++ + '' + new Date().getTime() % 100000;
    };
    
    laf.table.actionRow = function(text, type, height, image, hasChild){
        var strClassName = 'actionRow';
        if (height != undefined) {
            strClassName += height;
        }
        if (hasChild != undefined) {
            strClassName += hasChild;
        }		
        if (image != undefined) {
            strClassName += image;
        }
        
        var tvRow = Ti.UI.createTableViewRow({
            height: height,
            className: strClassName,
            hasChild: (hasChild == undefined) ? true : hasChild,
            rowType: type,
            borderWidth: 3
        });
        
        if (hasChild != undefined && hasChild == false && laf.device.isiPhone()) {
            tvRow.selectionStyle = Ti.UI.iPhone.TableViewCellSelectionStyle.NONE;
        }
        
        tvRow.add(Ti.UI.createView({
            backgroundImage: laf.path.images + image,
            left: 5,
            width: 29,
            height: 29
        }));
        
        tvRow.add(Ti.UI.createLabel({
            color: 'Black',
            font: {
                fontSize: 16,
                fontFamily: 'Arial'
            },
            left: 45,
            right: 0,
            height: height,
            textAlign: 'left',
            text: text
        }));
        
        laf.table.makeRowSelectable(tvRow);
        return tvRow;
    };
    
    laf.table.detailsRight = (function(){
        return (laf.device.isiPhone()) ? 5 : 30;
    })();
    
    laf.table.groupedHeaderLabel = function(text){
        return Ti.UI.createLabel({
            font: {
                fontSize: 17,
                fontWeight: 'Bold',
                fontFamily: 'Helvetica'
            },
            color: (laf.device.isiPhone()) ? '#4D576D' : '#BDBEBD',
            width: 'auto',
            height: 'auto',
            shadowColor: '#FAFAFA',
            shadowOffset: {
                x: 1,
                y: 1
            },
            text: text
        });
    };
    
    laf.table.headerLabel = function(text){
        return Ti.UI.createLabel({
            font: {
                fontSize: 16,
                fontWeight: 'Bold',
                fontFamily: 'Helvetica'
            },
            color: (laf.device.isiPhone()) ? 'white' : 'black',
            shadowColor: 'gray',
            shadowOffset: {
                x: 1,
                y: 1
            },
            width: 'auto',
            height: 'auto',
            text: text
        });
    };
    
    laf.table.headerRow = function(rowTitle, sectionTitle){
        var tvRow = Ti.UI.createTableViewRow({
            backgroundColor: '#576996',
            backgroundSelectedColor: '#385292',
            className: 'HeaderRow',
            height: (laf.device.isiPhone()) ? 20 : 25,
            editable: false
        });
        
        //Hide un-needed extra black row on android
        if (laf.device.isiPhone() || (sectionTitle != undefined && sectionTitle != '')) {
            tvRow.header = sectionTitle;
        }
        
        if (laf.device.isiPhone()) {
            tvRow.selectionStyle = Ti.UI.iPhone.TableViewCellSelectionStyle.NONE;
        }
        
        tvRow.add(Ti.UI.createLabel({
            color: '#fff',
            textAlign: 'center',
            font: {
                fontSize: 14,
                fontWeight: 'bold'
            },
            width: 250,
            height: 20,
            left: 5,
            right: 5,
            text: rowTitle,
            minimumFontSize: 10
        }));
        
        return tvRow;
    };
    
    laf.table.hideEmptyRows = function(tableView, showSeperator){
        tableView.footerView = Ti.UI.createView({
            height: 1,
            backgroundColor: 'transparent'
        });
        
        if (showSeperator == undefined || showSeperator == false) {
            if (laf.device.isiPhone()) {
                tableView.separatorStyle = Ti.UI.iPhone.TableViewSeparatorStyle.None;
            }
            tableView.separatorColor = 'transparent';
        }
    };
    
    laf.table.showEmptyRows = function(tableView){
        if (tableView.footerView != undefined) {
            if (laf.device.isiPhone()) {
                tableView.footerView = undefined;
            }
            else {
                tableView.remove(tableView.footerView);
            }
        }
        
        if (laf.device.isiPhone()) {
            tableView.separatorStyle = Ti.UI.iPhone.TableViewSeparatorStyle.SINGLE_LINE;
        }
        tableView.separatorColor = '#e1e1e1';
    };
    
    laf.table.ignoreRowSelection = function(tvRow, backgroundColor){
        tvRow.backgroundColor = (backgroundColor == undefined) ? 'transparent' : backgroundColor;
        tvRow.backgroundSelectedColor = (backgroundColor == undefined) ? 'transparent' : backgroundColor;
        
        if (laf.device.isiPhone()) {
            tvRow.selectionStyle = Ti.UI.iPhone.TableViewCellSelectionStyle.NONE;
        }
    };
    
    laf.table.infoRow = function(text, textAlign){
        var tvRow = Ti.UI.createTableViewRow({
            height: 'auto',
            className: 'infoRow',
            backgroundColor: 'transparent',
            backgroundSelectedColor: 'transparent'
        });
        
        if (laf.device.isiPhone()) {
            tvRow.selectionStyle = Ti.UI.iPhone.TableViewCellSelectionStyle.NONE;
        }
        
        tvRow.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 15,
                fontFamily: 'Arial'
            },
            left: 5,
            right: 5,
            top: 5,
            height: 'auto',
            textAlign: (textAlign == undefined) ? 'left' : textAlign,
            text: (laf.device.isiPhone()) ? text + '\n' : text
        }));
        
        return tvRow;
    };
    
    laf.table.makeRowSelectable = function(tvRow){
        //On Android, if a user clicks on a view on top of a row,
        //the row selection color isn't fired, unless you disable
        //the touch events from all of the objects on the row
        if (!laf.device.isiPhone()) {
            try {
                if (tvRow.children) {
                    var childCount = tvRow.children.length - 1;
                    while (childCount >= 0) {
                        tvRow.children[childCount--].touchEnabled = false;
                    }
                }
            } 
            catch (err) {
                Ti.API.info(err);
            }
        }
    };
    
    laf.table.leftDataRightMargin = (function(){
        return (laf.device.isiPhone()) ? 35 : 30;
    })();
    
    laf.table.scrollToTop = function(table, animated){
        if (table != undefined) {
            if (animated == undefined) {
                animated = true;
            }
            
            if (laf.device.isiPhone()) {
                table.scrollToTop(0, {
                    animated: animated
                });
                
            }
            else {
                table.scrollToIndex(0, {
                    animated: animated
                });
            }
        }
    };
    
    laf.table.section = function(title){
        if (title == undefined) {
            return Ti.UI.createTableViewSection({});
        }
        else {
            return Ti.UI.createTableViewSection({
                headerTitle: title
            });
        }
    };
})();
