//=== window ===================================
(function(){
    var windowToOpen = {};
    var windowToOpenURL = '';
    var windowToOpenTitle = '';
    var windowOpening = false;
    var openWindowIDs = [];
    
    function closeWindow(windowID, delay){
        setTimeout(function(){
            Ti.App.fireEvent('WinClose', {
                windowID: windowID
            });
        }, delay);
        
        //Fire again to be more sure it happened
        setTimeout(function(){
            Ti.App.fireEvent('WinClose', {
                windowID: windowID
            });
        }, delay + 1000);
    }
    
    laf.window = {}; //window namespace
    laf.window.create = function(title, url, winData, titleImage){
        if (!windowOpening || windowToOpenURL != url || windowToOpenTitle != title) {
            //Reset loading parameters
            windowOpening = false;
            windowToOpenURL = url;
            windowToOpenTitle = title;
            
            //Create window
            windowToOpen = Ti.UI.createWindow({
                backgroundColor: '#fff',
                title: title,
                url: url,
                fullscreen: false,
                navBarHidden: (laf.device.isiPhone()) ? false : true,
                winData: (winData == undefined) ? {} : winData,
                orientationModes: [Ti.UI.PORTRAIT, Ti.UI.LANDSCAPE_LEFT, Ti.UI.LANDSCAPE_RIGHT],
                titleImage: (titleImage == undefined) ? 'images/lafSwoosh.png' : titleImage,
                windowSoftInputMode: (!laf.device.isAndroid()) ? undefined : (url.indexOf('login') >= 0 || url.indexOf('feedback') >= 0 || url.indexOf('contactUs') >= 0) ? Ti.UI.Android.SOFT_INPUT_ADJUST_PAN : Ti.UI.Android.SOFT_INPUT_ADJUST_UNSPECIFIED
            });
            
            if (laf.device.isiPhone()) {
                var vwSwoosh = Ti.UI.createView({
                    backgroundImage: (titleImage == undefined) ? 'images/lafSwoosh.png' : titleImage,
                    width: 70,
                    height: 35
                });
                if (windowToOpenURL.toLowerCase() != 'views/common/passcode.js') {
                    vwSwoosh.addEventListener('click', function(){
                        laf.window.goHome();
                    });
                }
                windowToOpen.titleControl = vwSwoosh;
            }
            
            return windowToOpen;
        }
        else {
            return windowToOpen;
        }
    };
    
    //Called from winHeader.js, which passes currentTab in open method
    laf.window.openBase = function(currentTab, parentList, animated, modal){
        //prevent user from double clicking & opening same window twice on slow hardware
        if (!windowOpening) {
            windowOpening = true;
            
            var windowID = new Date().getTime() % 100000;
            windowToOpen.windowID = windowID;
            
            windowToOpen.addEventListener('open', function(){
                openWindowIDs.push(windowID);
                windowOpening = false;
                Ti.API.info('Window Opened: ' + windowToOpenTitle);
            });
            
            windowToOpen.addEventListener('close', function(){
                var winIndex = openWindowIDs.indexOf(windowID);
                if (winIndex >= 0) {
                    openWindowIDs.splice(winIndex, 1);
                }
            });
            
            //Modal has issues with acitivityIndicator, which doesn't get placed on top			
            if (modal != undefined && modal == true) {
                windowToOpen.open({
                    animated: animated,
                    modal: true
                });
            }
            else {
                if (currentTab == undefined) {
                    windowToOpen.open({
                        animated: animated
                    });
                }
                else {
                    currentTab.open(windowToOpen, {
                        animated: animated
                    });
                }
            }
        }
    };
    
    laf.window.createHeader = function(height){
        var vwHeader = Ti.UI.createView({
            left: 0,
            right: 0,
            top: 0,
            height: (height != undefined && height > 0) ? height : 48,
            borderColor: '#3D4968',
            borderWidth: 1,
            backgroundColor: '#576996'
        });
        var vwSwoosh = Ti.UI.createView({
            width: 70,
            height: 12,
            top: 0,
            bottom: 0,
            backgroundImage: '../../images/lafSwoosh.png',
            focusable: true
        });
        vwSwoosh.addEventListener('click', function(){
            laf.window.goHome();
        });
        vwHeader.add(vwSwoosh);
        return vwHeader;
    };
    
    laf.window.createFooter = function(height){
        return Ti.UI.createView({
            left: 0,
            right: 0,
            bottom: 0,
            height: (height != undefined && height > 0) ? height : 48,
            backgroundColor: '#576996'
        });
    };
    
    laf.window.removeChildren = function(object){
        try {
            if (object.children) {
                var childCount = object.children.length - 1;
                while (childCount >= 0) {
                    object.remove(object.children[childCount--]);
                }
            }
        } 
        catch (err) {
            Ti.API.info(err);
        }
    };
    
    laf.window.fire = function(eventName, eventData){
        Ti.App.fireEvent(eventName, (eventData != undefined) ? eventData : {});
    };
    
    laf.window.goHome = function(currWindow){
        var openWins = openWindowIDs.slice(0);
        
        //Some screens after network operations have problems
        //closing on iOS, if needed pass the currWindow
        //and we will do an extra push to make sure its cleaned up
        setTimeout(function(){
            if (currWindow != undefined) {
                currWindow.close();
            }
        }, openWins.length * 600);
        
        for (var i = openWins.length - 1; i >= 0; i--) {
            closeWindow(openWins[i], i * 300);
        }
    };
    
    laf.window.search = function(){
        var openWins = openWindowIDs.slice(0);
        for (var i = openWins.length - 1; i >= 0; i--) {
            closeWindow(openWins[i], i * 300);
        }
        
        Ti.App.fireEvent('search');
    };
    
    laf.window.alert = function(title, message, buttonNames, clickListener){
        var vwAlert = Ti.UI.createAlertDialog({});
        if (message != undefined && message.length != 0) {
            vwAlert.message = message;
        }
        else 
            if (title != undefined && title.length != 0) {
                vwAlert.message = title;
                title = undefined;
            }
        
        if (title != undefined && title.length != 0) {
            vwAlert.title = title;
        }
        
        if (buttonNames != undefined && buttonNames.length > 0) {
            vwAlert.buttonNames = buttonNames;
        }
        else {
            vwAlert.buttonNames = ['OK'];
        }
        
        if (clickListener != undefined) {
            vwAlert.addEventListener('click', clickListener);
        }
        
        vwAlert.show();
    };
    
    //e.g. 	width:percentToPixels(25,textfield.width),
    laf.window.percentToPixels = function(percentage, width){
        if (width == null) {
            width = Ti.Platform.displayCaps.platformWidth - 2;
        }
        return parseInt(width * (percentage / 100), 10);
    };
})();
