//=== ACTIVITY INDICATOR ===================================
function activityIndicator() {
    this.showing = false;
    this.actInd = undefined;
    this.iOSActivityWindow = undefined;
    this.androidActivity = undefined;

    if (Ti.Platform.name == 'android' && Ti.Android.currentActivity != undefined) {
        this.androidActivity = Ti.Android.currentActivity;
    }
}

function androidCleanup() {
    if (this != undefined && this.actInd != undefined) {
        this.actInd.hide();
    }
}

activityIndicator.prototype.hide = function() {
    if (this.showing) {
        try {
            if (this.actInd != undefined) {
                this.actInd.hide();
            }

            if (Ti.Platform.name == 'iPhone OS') {
                //Close Activity Window first, so current window is original window
                if (this.iOSActivityWindow != undefined) {
                    this.iOSActivityWindow.close({
                        opacity: 0,
                        duration: 100
                    });
                    this.iOSActivityWindow = undefined;
                }

                //Re-enable touch on the current window
                if (Ti.UI.currentWindow != undefined) {
                    Ti.UI.currentWindow.touchEnabled = true;
                    if (Ti.UI.currentWindow.tabGroup != undefined) {
                        Ti.UI.currentWindow.tabGroup.touchEnabled = true;
                    }
                }
            }

            //Android sometimes gives error about window manager when window below activity closes
            if (Ti.Platform.name == 'android') {
                if (Ti.UI.currentWindow != undefined) {
                    Ti.UI.currentWindow.removeEventListener('close', androidCleanup);
                }

                if (this.androidActivity != undefined) {
                    this.androidActivity.removeEventListener('pause', androidCleanup);
                    this.androidActivity.removeEventListener('stop', androidCleanup);
                    this.androidActivity.removeEventListener('destroy', androidCleanup);
                }
            }

            this.actInd = undefined;
        }
        catch (er) {
            Ti.API.info(er);
        }

        this.showing = false;
    }
};

activityIndicator.prototype.show = function(strMessage) {
    if (!this.showing) {
        try {
            this.showing = true;

            if (this.actInd == undefined) {
                this.actInd = Ti.UI.createActivityIndicator({});
            }

            if (Ti.Platform.name == 'iPhone OS') {
                this.actInd.height = 50;
                this.actInd.width = 10;
                this.actInd.style = Ti.UI.iPhone.ActivityIndicatorStyle.BIG;

                if (Ti.UI.currentWindow != undefined) {
                    Ti.UI.currentWindow.touchEnabled = false;
                    if (Ti.UI.currentWindow.tabGroup != undefined) {
                        Ti.UI.currentWindow.tabGroup.touchEnabled = false;
                    }
                }

                var winWidth, winHeight;
                if (Ti.UI.orientation == 1 || Ti.UI.orientation == 3) {
                    winHeight = Ti.Platform.displayCaps.platformHeight;
                    winWidth = Ti.Platform.displayCaps.platformWidth;
                }
                else {
                    winHeight = Ti.Platform.displayCaps.platformWidth;
                    winWidth = Ti.Platform.displayCaps.platformHeight;
                }

                this.iOSActivityWindow = Ti.UI.createWindow({
                    height: (winHeight != 0) ? winHeight : 320,
                    width: (winWidth != 0) ? winWidth : 320,
                    touchEnabled: true
                });

                var vwBlackBack = Ti.UI.createView({
                    height: 90,
                    width: 200,
                    backgroundColor: '#000',
                    borderRadius: 10,
                    opacity: 0.85,
                    touchEnabled: true
                });

                vwBlackBack.add(Ti.UI.createLabel({
                    text: strMessage,
                    color: '#fff',
                    textAlign: 'center',
                    font: {
                        fontSize: 18,
                        fontWeight: 'bold'
                    },
                    bottom: 5,
                    height: 'auto',
                    width: 'auto'
                }));

                this.actInd.top = 5;
                this.actInd.style = Ti.UI.iPhone.ActivityIndicatorStyle.BIG;
                vwBlackBack.add(this.actInd);
                this.iOSActivityWindow.add(vwBlackBack);
                this.iOSActivityWindow.open({
                    animated: false
                });
            }
            else {
                if (Ti.Platform.name == 'android') {
                    //Sometimes activity indicator called from background threads, causing issues
                    if (Ti.Android.currentActivity == undefined || this.androidActivity != Ti.Android.currentActivity) {
                        this.actInd = undefined;
                        this.showing = false;
                        return;
                    }

                    //Android sometimes gives error about window manager when window below activity closes					
                    if (Ti.UI.currentWindow != undefined) {
                        Ti.UI.currentWindow.addEventListener('close', androidCleanup);
                    }

                    //Add listeners on many events, just in case one doesn't get thrown by Titanium
                    if (this.androidActivity != undefined) {
                        this.androidActivity.addEventListener('pause', androidCleanup);
                        this.androidActivity.addEventListener('stop', androidCleanup);
                        this.androidActivity.addEventListener('destroy', androidCleanup);
                    }
                }

                this.actInd.message = strMessage;
            }

            this.actInd.show();
        }
        catch (er) {
            Ti.API.info(er);
        }
    }
};
