function addArray(value){
    var rows1 = [];
    for (var i = 0; i < value.length; i++) {
        rows1.push(Ti.UI.createPickerRow({
            title: value[i]
        }));
    }
    
    return Ti.UI.createPickerColumn({
        rows: rows1
    });
}

function addCancelButton(){
    return Ti.UI.createButton({
        height: 55,
        color: '#FFFFFF',
        bottom: 5,
        width: 150,
        right: 5,
        backgroundImage: laf.path.images + 'BUTT_red_off.png',
        backgroundSelectedImage: laf.path.images + 'BUTT_red_on.png',
        title: 'Cancel'
    });
}

function addSelectButton(buttonText){
    return Ti.UI.createButton({
        height: 55,
        color: '#FFFFFF',
        bottom: 5,
        left: 5,
        width: 150,
        backgroundImage: laf.path.images + 'BUTT_grn_off.png',
        backgroundSelectedImage: laf.path.images + 'BUTT_grn_on.png',
        title: (buttonText != undefined) ? buttonText : 'Select'
    });
}

function GetPickerWindow(headerText){
    var winPicker = Titanium.UI.createWindow({
        backgroundColor: '#000',
        opacity: 0.85,
        orientationModes: [Titanium.UI.PORTRAIT, Titanium.UI.UPSIDE_PORTRAIT, Titanium.UI.LANDSCAPE_LEFT, Titanium.UI.LANDSCAPE_RIGHT],
        navBarHidden: true
    }, true);
    
    winPicker.add(Titanium.UI.createLabel({
        text: headerText,
        top: 20,
        width: 'auto',
        height: 'auto',
        textAlign: 'center',
        color: 'white',
        font: {
            fontSize: 17,
            fontWeight: 'Bold',
            fontFamily: 'Helvetica'
        }
    }));
    
    if (laf.device.isiPhone()) {
        winPicker.addEventListener('open', function(e){
            Titanium.UI.iPhone.statusBarStyle = Titanium.UI.iPhone.StatusBar.OPAQUE_BLACK;
        });
        
        winPicker.addEventListener('close', function(e){
            Titanium.UI.iPhone.statusBarStyle = Titanium.UI.iPhone.StatusBar.DEFAULT;
        });
    }
    
    return winPicker;
}

function standardPickerForAndroid(headerText, buttonText, value1, value2, value3, defaultValues, oncomplete){
    var selectedValues = [];
    var winPicker = GetPickerWindow(headerText);
    
    var picker = Ti.UI.createPicker({
        useSpinner: true,
        visibleItems: 5,
        type: Ti.UI.PICKER_TYPE_PLAIN,
        top: 150,
        height: 200,
        font: {
            fontSize: "12"
        }
    });
    
    var column1 = addArray(value1);
    
    if (value2 != undefined) {
        var column2 = addArray(value2);
    }
    
    if (value3 != undefined) {
        var column3 = addArray(value3);
    }
    
    picker.columns = (value2 == undefined && value3 == undefined) ? column1 : (value3 == undefined) ? [column1, column2] : [column1, column2, column3];
    
    winPicker.add(picker);
    
    picker.addEventListener('change', function(e){
        selectedValues[e.columnIndex] = e.selectedValue[e.columnIndex];
    });
    
    btnSelect = addSelectButton(buttonText);
    btnCancel = addCancelButton();
    
    btnSelect.addEventListener('click', function(){    
        setTimeout(function(){
            btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
            btnCancel.opacity = btnSelect.opacity = 0.5;
            
            if (oncomplete != undefined) {
                selectedValues = (value2 == undefined && value3 == undefined) ? picker.getSelectedRow(0).title : (value3 == undefined) ? picker.getSelectedRow(0).title  + picker.getSelectedRow(1).title : picker.getSelectedRow(0).title + picker.getSelectedRow(1).title  + picker.getSelectedRow(2).title;
                oncomplete(selectedValues);
            }
            
            winPicker.close({
                opacity: 0,
                duration: 500
            });
        }, 1000);
    });
    
    btnCancel.addEventListener('click', function(){
        btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
        btnCancel.opacity = btnSelect.opacity = 0.5;
        
        if (oncomplete != undefined) {
            oncomplete(undefined);
        }
        
        winPicker.close({
            opacity: 0,
            duration: 500
        });
    });
    
    winPicker.add(btnSelect);
    winPicker.add(btnCancel);
    
    winPicker.open();
    
    if (defaultValues != undefined && defaultValues.length > 0) {
        for (i = 0, len = value1.length; i < len; i++) {
            if (value1[i] == defaultValues[0]) {
                picker.setSelectedRow(0, i);
            }
        }
        if (value2 != undefined) {
            for (i2 = 0, len2 = value2.length; i2 < len2; i2++) {
                if (value2[i2] == defaultValues[1]) {
                    picker.setSelectedRow(1, i2);
                }
            }
        }
        if (value3 != undefined) {
            for (i3 = 0, len3 = value3.length; i3 < len3; i3++) {
                if (value3[i3] == defaultValues[2]) {
                    picker.setSelectedRow(2, i3);
                }
            }
        }
    }
}

function standardPicker(headerText, buttonText, values, defaultValues, oncomplete){
    var winPicker = GetPickerWindow(headerText);
    var selectedValues = [];
    
    var picker = Ti.UI.createPicker({
        left: 5,
        right: 5,
        type: Ti.UI.PICKER_TYPE_PLAIN,
        useSpinner: true
    });
    picker.selectionIndicator = true;
    
    if (laf.device.isiPhone()) {
        picker.columns = [];
    }
    
    var pickerColumns = [];
    for (var x = 0, len = values.length; x < len; x++) {
        var column = Titanium.UI.createPickerColumn();
        var columnValues = values[x].split(',');
        selectedValues[x] = columnValues[0];
        for (var y = 0, len2 = columnValues.length; y < len2; y++) {
            column.addRow(Titanium.UI.createPickerRow({
                title: columnValues[y]
            }));
        }
        pickerColumns.push(column);
    }
    
    picker.add(pickerColumns);
    
    picker.addEventListener('change', function(e){
        selectedValues[e.columnIndex] = e.selectedValue[e.columnIndex];
    });
    
    btnSelect = addSelectButton(buttonText);
    btnCancel = addCancelButton();
    
    btnSelect.addEventListener('click', function(){
        setTimeout(function(){
            btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
            btnCancel.opacity = btnSelect.opacity = 0.5;
            
            if (oncomplete != undefined) {
                oncomplete(selectedValues);
            }
            
            winPicker.close({
                opacity: 0,
                duration: 500
            });
        }, 1000);
    });
    
    btnCancel.addEventListener('click', function(){
        btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
        btnCancel.opacity = btnSelect.opacity = 0.5;
        
        if (oncomplete != undefined) {
            oncomplete(undefined);
        }
        
        winPicker.close({
            opacity: 0,
            duration: 500
        });
    });
    
    winPicker.add(picker);
    
    winPicker.add(btnSelect);
    winPicker.add(btnCancel);
    
    winPicker.open();
    
    if (defaultValues != undefined && defaultValues.length > 0) {
        for (x = 0, len = values.length; x < len; x++) {
            if (defaultValues[x] != undefined) {
                columnValues = values[x].split(',');
                var dftIndex = columnValues.indexOf(defaultValues[x]);
                if (dftIndex != -1) {
                    picker.setSelectedRow(x, dftIndex, true);
                }
            }
        }
    }
}

function datePicker(headerText, buttonText, minDate, maxDate, defaultDate, oncomplete){
    var winDatePicker = GetPickerWindow(headerText);
    
    var pckrDate = Ti.UI.createPicker({
        type: Ti.UI.PICKER_TYPE_DATE,
        height: 200,
        value: defaultDate
        // useSpinner: true //Android date picker seems to work better
    });
    
    if (minDate != undefined) {
		pckrDate.minDate = minDate;
    }
    
    if (maxDate != undefined) {
		pckrDate.maxDate = maxDate;
    }
    
    pckrDate.addEventListener('change', function(e){
        defaultDate = e.value;
    });
    
    btnSelect = addSelectButton(buttonText);
    btnCancel = addCancelButton();
    
    btnSelect.addEventListener('click', function(){
        setTimeout(function(){
            btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
            btnCancel.opacity = btnSelect.opacity = 0.5;
            
            if (oncomplete != undefined) {
                oncomplete(defaultDate);
            }
            
            winDatePicker.close({
                opacity: 0,
                duration: 500
            });
        }, 1000);
    });
    
    btnCancel.addEventListener('click', function(){
        btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
        btnCancel.opacity = btnSelect.opacity = 0.5;
        
        if (oncomplete != undefined) {
            oncomplete(undefined);
        }
        
        winDatePicker.close({
            opacity: 0,
            duration: 500
        });
    });
    
    winDatePicker.add(pckrDate);
    winDatePicker.add(btnSelect);
    winDatePicker.add(btnCancel);
    winDatePicker.open();
}

function timePicker(headerText, buttonText, defaultTime, oncomplete){
    var winTimePicker = GetPickerWindow(headerText);
    
    var pckrTime = Titanium.UI.createPicker({
        type: Titanium.UI.PICKER_TYPE_TIME,
        height: 200,
        value: defaultTime,
        //useSpinner: true, //Spinner AM/PM not perfected yet
        format24: false
    });
    
    pckrTime.addEventListener('change', function(e){
        defaultTime = e.value;
    });
    
    btnSelect = addSelectButton(buttonText);
    btnCancel = addCancelButton();
    
    btnSelect.addEventListener('click', function(){
        setTimeout(function(){
            btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
            btnCancel.opacity = btnSelect.opacity = 0.5;
            
            if (oncomplete != undefined) {
                oncomplete(defaultTime);
            }
            
            winTimePicker.close({
                opacity: 0,
                duration: 500
            });
        }, 1000);
    });
    
    btnCancel.addEventListener('click', function(){
        btnCancel.enabled = btnSelect.enabled = false; //Prevent double clicks
        btnCancel.opacity = btnSelect.opacity = 0.5;
        
        if (oncomplete != undefined) {
            oncomplete(undefined);
        }
        
        winTimePicker.close({
            opacity: 0,
            duration: 500
        });
    });
    
    winTimePicker.add(pckrTime);
    winTimePicker.add(btnSelect);
    winTimePicker.add(btnCancel);
    
    winTimePicker.open();
}
