var laf = Ti.App.laf; //Get alias to global laf instance
var win = Ti.UI.currentWindow;
Ti.include((laf.device.isiPhone()) ? '../../common/utilActivity.js' : 'utilActivity.js');

//Temporary until Titanium fixes http://jira.appcelerator.org/browse/TIMOB-3158
if (laf.device.isAndroid()) {
    Ti.include('utilNetwork.js');
}

var tabGroup = (win != undefined) ? win.tabGroup : undefined;
var winData = (win != undefined && win.winData != undefined) ? win.winData : {};
var vwHeader;
var vwFooter;

var vwMain = Ti.UI.createView({
    top: 0,
    bottom: 0,
    left: 0,
    right: 0,
    backgroundColor: '#fff'
});
win.add(vwMain);
var currTabIndex = 0;

(function(){
    var includedFiles = {};
    var listeners = [];
    var activityListeners = [];
    var footerTabs = [];
    
    if (!laf.device.isiPhone()) {
        vwHeader = laf.window.createHeader();
        vwMain.top = vwHeader.height;
        win.add(vwHeader);
    }
    
    //Call here so main currentTab (the one the whole app runs in) is in context
    laf.window.open = function(animated){
        return laf.window.openBase(Ti.UI.currentTab, win.parentList, (animated == undefined) ? true : animated, false);
    };
    
    //Ensure includes are only included once in this context
    laf.window.include = function(/*String... arguments*/){
        if (arguments != undefined && arguments.length > 0) {
            for (var i = 0; i < arguments.length; i++) {
                if (includedFiles[arguments[i]] == undefined) {
                    includedFiles[arguments[i]] = 1; //loaded
                    Ti.include(arguments[i]);
                }
            }
        }
    };
    
    laf.window.listen = function(eventName, callbackFunction){
        Ti.App.addEventListener(eventName, callbackFunction);
        listeners.push({
            eventName: eventName,
            callbackFunction: callbackFunction
        });
    };
    
    laf.window.activityListen = function(eventName, callbackFunction){
        if (laf.device.isAndroid()) {
            Ti.Android.currentActivity.addEventListener(eventName, callbackFunction);
            activityListeners.push({
                eventName: eventName,
                callbackFunction: callbackFunction
            });
        }
    };
    
    //As event listeners stored in global context, sometimes not cleaned up naturally on window close	
    win.addEventListener('close', function(){
        for (var listenItr = 0, listenItrLen = listeners.length; listenItr < listenItrLen; listenItr++) {
            Ti.App.removeEventListener(listeners[listenItr].eventName, listeners[listenItr].callbackFunction);
        }
        
        if (laf.device.isAndroid()) {
            for (var activityItr = 0, activityItrLen = activityListeners.length; activityItr < activityItrLen; activityItr++) {
                Ti.Android.currentActivity.removeEventListener(activityListeners[activityItr].eventName, activityListeners[activityItr].callbackFunction);
            }
        }
    });
    
    laf.window.footer = function(height){
        if (vwFooter == undefined) {
            vwFooter = laf.window.createFooter(height);
            win.add(vwFooter);
        }
        vwFooter.visible = true;
        vwMain.bottom = vwFooter.height;
        return vwFooter;
    };
    
    laf.window.removeFooter = function(){
        if (vwFooter != undefined) {
            vwMain.bottom = 0;
            vwFooter.visible = false;
        }
    };
    
    laf.window.selectTab = function(tabIndex){
        if (laf.device.isiPhone()) {
            tbFooter.fireEvent('click', {
                index: tabIndex
            });
        }
        else {
            footerTabs[tabIndex].fireEvent('click', {
                source: {
                    tabIndex: tabIndex
                }
            });
        }
    };
    
    laf.window.footerTabs = function(tabArray, changeFunction, selectTabIndex){
        if (vwFooter == undefined) {
            vwFooter = laf.window.createFooter();
            vwMain.bottom = vwFooter.height;
            win.add(vwFooter);
        }
        currTabIndex = 0;
        
        if (laf.device.isiPhone()) {
            tbFooter = Ti.UI.createTabbedBar({
                labels: tabArray,
                backgroundColor: '#336699',
                style: Ti.UI.iPhone.SystemButtonStyle.BAR,
                top: 5,
                bottom: 5,
                left: 5,
                right: 5,
                index: 0
            });
            
            tbFooter.addEventListener('click', function(e){
                if (currTabIndex != e.index) {
                    currTabIndex = e.index;
                    tbFooter.index = currTabIndex;
                    if (changeFunction != undefined) {
                        changeFunction(currTabIndex);
                    }
                }
            });
            
            vwFooter.add(tbFooter);
        }
        else {
            var tabWidth = laf.window.percentToPixels(100 / tabArray.length);
            var vwTabBar = Ti.UI.createView({
                left: 1,
                right: 1,
                top: 5,
                bottom: 5,
                borderRadius: 10,
                backgroundColor: '#1F3D79'
            });
            
            for (var tabItr = 0, tabItrLen = tabArray.length; tabItr < tabItrLen; tabItr++) {
                var currTab = Ti.UI.createLabel({
                    tabIndex: tabItr,
                    text: tabArray[tabItr],
                    textAlign: 'center',
                    backgroundColor: (tabItr == 0) ? '#000F4B' : '#1F3D79',
                    top: 0,
                    bottom: 0,
                    borderColor: '#000F4B',
                    borderWidth: 1,
                    width: tabWidth,
                    font: {
                        fontWeight: 'bold',
                        fontSize: 14
                    },
                    color: 'white',
                    left: (tabWidth * tabItr),
                    focusable: true
                });
                
                //Return called function to avoid JSLint warning & keep tabIndex
                currTab.addEventListener('click', function(){
                    return function(e){
                        if (currTabIndex != e.source.tabIndex) {
                            currTabIndex = e.source.tabIndex;
                            for (ftrTabItr = 0, ftrTabLen = footerTabs.length; ftrTabItr < ftrTabLen; ftrTabItr++) {
                                footerTabs[ftrTabItr].backgroundColor = (ftrTabItr == e.source.tabIndex) ? '#000F4B' : '#1F3D79';
                            }
                            if (changeFunction != undefined) {
                                changeFunction(e.source.tabIndex);
                            }
                        }
                    };
                }());
                
                footerTabs.push(currTab);
                vwTabBar.add(currTab);
            }
            vwFooter.add(vwTabBar);
        }
        
        if (selectTabIndex != undefined) {
            laf.window.selectTab(selectTabIndex);
            
            //If already default tab, won't call change event
            if (selectTabIndex == 0 && tabChange != undefined) {
                tabChange(0);
            }
        }
    };
    
    if (laf.device.isAndroid()) {
        //Android does not have a global app resume property, so check every window
        Ti.Android.currentActivity.addEventListener('resume', function(e){
            Ti.App.fireEvent('AppUpdate');
        });
        
        win.addEventListener('android:search', function(){
            laf.window.search();
        });
    }
    
    Ti.Gesture.addEventListener('orientationchange', function(e){
        if (!laf.device.isiPhone() && footerTabs.length != 0) {
            var tabWidth = laf.window.percentToPixels(100 / footerTabs.length);
            for (var footerItr = 0, footerLen = footerTabs.length; footerItr < footerLen; footerItr++) {
                footerTabs[footerItr].left = (tabWidth * footerItr);
                footerTabs[footerItr].width = tabWidth;
            }
        }
    });
    
    laf.window.listen('WinClose', function(e){
        if (e.windowID != undefined && win.windowID != undefined && e.windowID == win.windowID) {
            win.close();
        }
    });
})();

//Don't attach to laf.window, causes android problems when returning from another window
setLeftNav = function(btnLeft){
    if (laf.device.isiPhone()) {
        win.setLeftNavButton(btnLeft);
    }
    else {
        //Remove any existing left buttons first			
        try {
            if (vwHeader.children) {
                var childCount = vwHeader.children.length - 1;
                while (childCount >= 0) {
                    var currObj = vwHeader.children[childCount--];
                    if (currObj != undefined && currObj.left == 5) {
                        vwHeader.remove(currObj);
                        break;
                    }
                }
            }
        } 
        catch (er) {
            Ti.API.info('Error removing children');
        }
        
        if (btnLeft != undefined) {
            btnLeft.left = 5;
            vwHeader.add(btnLeft);
        }
    }
};

//Don't attach to laf.window, causes android problems when returning from another window
setRightNav = function(btnRight){
    if (laf.device.isiPhone()) {
        win.setRightNavButton(btnRight);
    }
    else {
        //Remove any existing right buttons first
        try {
            if (vwHeader.children) {
                var childCount = vwHeader.children.length - 1;
                while (childCount >= 0) {
                    var currObj = vwHeader.children[childCount--];
                    if (currObj != undefined && currObj.right == 5) {
                        vwHeader.remove(currObj);
                        break;
                    }
                }
            }
        } 
        catch (er) {
            Ti.API.info('Error removing children');
        }
        
        if (btnRight != undefined) {
            btnRight.right = 5;
            vwHeader.add(btnRight);
        }
    }
};

post = function(postObject, serviceEndpoint, callbackOK, callbackFail, background){
    var vwActivity = new activityIndicator();
    
    if (background == undefined || background == false) {
        vwActivity.show('Transferring Data...');
    }
 
    var newCallbackOK = function(responseText){
        if (callbackOK != undefined) {
            callbackOK(responseText);
        }
 
        if (background == undefined || background == false) {
            vwActivity.hide();
        }
    };
 
    var newCallbackFail = function(errorMessage){
        if (callbackFail != undefined) {
            callbackFail(errorMessage);
        }
        else {
            if (background == undefined || background == false) {
                Ti.UI.createAlertDialog({
                    title: 'Unable to Connect',
                    message: 'There was an error connecting to LA Fitness web services.',
                    buttonNames: ['OK']
                }).show();
            }
        }
 
        if (background == undefined || background == false) {
            vwActivity.hide();
        }
    };

    if (laf.device.isAndroid()) {
        //Temporary until Titanium fixes http://jira.appcelerator.org/browse/TIMOB-3158
        androidPost(postObject, serviceEndpoint, newCallbackOK, newCallbackFail);
    }
    else {
        laf.network.post(postObject, serviceEndpoint, newCallbackOK, newCallbackFail);
    }
};
