//=== HEADER & DATA =============================
var laf = Ti.App.laf; //Get alias to global laf instance
var win = Ti.UI.currentWindow;
Ti.include('utilActivity.js');

//=== Version Update ===================================
function checkForNewVersion(){
    var callbackFail = function(error){
        setTimeout(function(){
            win.close(); //Freeup memory
        }, 600);
    };
    
    var callbackOK = function(response){
        if (response.Success && parseFloat(laf.network.clientVersion) < parseFloat(response.Value)) {
            var updateMessage = 'An update to LA Fitness Mobile is now available. Please download as soon as possible.';
            if (response.Message != undefined && response.Message.length > 0) {
                updateMessage += '\n\n' + response.Message;
            }
            
            laf.window.alert('New Version', updateMessage, ['Close', 'View'], function(e){
                if (e.index == 1) {
                    laf.network.openURL((laf.device.isiPhone()) ?
						'http://itunes.apple.com/us/app/la-fitness-mobile/id376098999?mt=8&uo=4' : 
						'market://search?q=pname:com.lafitness.lafitness');
                }
            });
        }
        
        setTimeout(function(){
            win.close(); //Freeup memory
        }, 600);
    };
    
    laf.network.post('', 'Public.svc/VersionCheck', callbackOK, callbackFail);
}

//=== Database Update ===================================
function updateDBData(){
    Ti.API.info('Will Update Database');
    var httpClient = Ti.Network.createHTTPClient();
    httpClient.setTimeout(120000);
    httpClient.onerror = function(error){
        checkForNewVersion();
    };
    
    httpClient.onload = function(){
        //Block user actions with activityIndicator to further reduce SQL usage
        var actInd = new activityIndicator();
        actInd.show('Updating Data...');
        
        var clubDatabase = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, 'clubData.db');
        if (clubDatabase != undefined) {
            clubDatabase.write(this.responseData);
        }
        
        if (clubDatabase != undefined && clubDatabase.exists() && clubDatabase.size > 0) {
            Ti.API.info('Saving New Database');
            laf.data.updateDB('club', clubDatabase.nativePath, function(){
                Ti.App.Properties.setString('LastUpdate', (new Date()).toString());
                clubDatabase.deleteFile();
                actInd.hide();
                
                Ti.API.info('Update Database Completed');
                checkForNewVersion();
            });
            
            setTimeout(function(){
                actInd.hide(); //Make sure a failed update doesn't block user forever
            }, 11000);
        }
        else {
            actInd.hide();
            Ti.API.info('Update Database Failed');
            
            try {
                if (clubDatabase != undefined) {
                    clubDatabase.deleteFile();
                }
            } 
            catch (er) {
            }
            checkForNewVersion();
        }
    };
    
    httpClient.open('GET', laf.network.protocol + laf.network.server + '/ClubData.txt');
    httpClient.send();
}

function checkForDBUpdate(){
    if (!Ti.App.Properties.hasProperty('LastUpdate')) {
        //If never updated before, force update now
        updateDBData();
    }
    else {
        //Check timestamp of data on server
        var callbackOK = function(response){
            if (response.Success) {
                var dataFileDate = laf.dateTime.fromString(response.Value);
                Ti.API.info('Server File: ' + dataFileDate.toString());
                Ti.API.info('Last Update: ' + Ti.App.Properties.getString('LastUpdate'));
                
                if (dataFileDate > new Date(Ti.App.Properties.getString('LastUpdate'))) {
                    updateDBData();
                }
                else {
                    checkForNewVersion();
                }
            }
            else {
                checkForNewVersion();
            }
        };
        
        laf.network.post('', 'Public.svc/ClubDatabaseDate', callbackOK, checkForNewVersion);
    }
}

//=== Update ===================================
if (Ti.Network.online) {
    checkForDBUpdate();
}
else {
    win.close(); //Freeup memory
}
