//=== HEADER & DATA =============================
Ti.include('../../common/winHeader.js');

var fireEvent = (winData.fireEvent == undefined) ? false : winData.fireEvent;
var currLat = parseFloat(Ti.App.Properties.getString('Latitude'));
var currLon = parseFloat(Ti.App.Properties.getString('Longitude'));
var clubLocations = [];

//=== OBJECTS =============================
var vwMap = Ti.Map.createView({
    mapType: Ti.Map.STANDARD_TYPE,
    region: {
        latitude: currLat,
        longitude: currLon,
        latitudeDelta: 0.42, // 15/35
        longitudeDelta: 0.42
    },
    animate: true,
    regionFit: true,
    userLocation: true
});

//=== FUNCTIONS =============================
function tabChange(tabIndex){
    switch (tabIndex) {
        case 0:
            vwMap.mapType = Ti.Map.STANDARD_TYPE;
            break;
        case 1:
            vwMap.mapType = (laf.device.isiPhone()) ? Ti.Map.HYBRID_TYPE : Ti.Map.SATELLITE_TYPE;
            break;
        case 2:
            vwMap.mapType = Ti.Map.SATELLITE_TYPE;
            break;
    }
}

function setClubLocations(){
    if (laf.location.clubFilterString() != '') {
        lastFilteredClubs = laf.location.clubFilterString();
        var clubs = laf.data.clubSet('SELECT CLUB_ID, DESCRIPTION, LAT, LON FROM Club WHERE CLUB_ID IN (' + lastFilteredClubs + ')', ['ClubID', 'Description', 'Lat', 'Lon']);
        for (var clubItr = 0, clubLen = clubs.length; clubItr < clubLen; clubItr++) {
			var locationParams = {
                myid: clubs[clubItr].ClubID,				
                latitude: clubs[clubItr].Lat,
                longitude: clubs[clubItr].Lon,
                title: clubs[clubItr].Description,
                animate: true
			};
			
			if (laf.device.isiPhone()) {
				locationParams.pinColor = Ti.Map.ANNOTATION_RED;
				locationParams.rightButton = Ti.UI.iPhone.SystemButton.DISCLOSURE;
			} else {
				locationParams.pinImage = laf.path.images + 'pin.png';
			}
			clubLocations.push(Ti.Map.createAnnotation(locationParams));
        }
    }
    else {
        clubLocations = [];
    }
    
    vwMap.annotations = clubLocations;
}

//=== EVENTS =============================	
vwMap.addEventListener('click', function(evt){
    if (evt.clicksource == 'rightButton') {
        var myid = (evt.annotation) ? evt.annotation.myid : -1;
        
        if (fireEvent) {
            laf.window.fire('clubSelected', {
                clubID: myid
            });
            setTimeout(function(){
                win.close();
            }, (laf.device.isiPhone()) ? 600 : 0);
        }
        else {
            if (myid >= 0) {
                laf.window.create('Club', '/views/search/club.js', {
                    clubID: myid
                });
                laf.window.open();
            }
        }
    }
});

win.addEventListener('close', function(e){
    vwMap.userLocation = false; //Turn off GPS
});

win.addEventListener('focus', function(e){
    vwMap.userLocation = true; //Ensure GPS is on
});

win.addEventListener('blur', function(e){
    vwMap.userLocation = false; //Turn off GPS
});

laf.window.listen('resume', function(e){
    vwMap.userLocation = true; //Ensure GPS is on
});

laf.window.listen('pause', function(e){
    vwMap.userLocation = false; //Turn off GPS
});

//=== DISPLAY =============================
setClubLocations();
vwMain.add(vwMap);

//Android Hybrid view doesn't really seem to be working
if (laf.device.isiPhone()) {
    laf.window.footerTabs(['Map', 'Hybrid', 'Satellite'], tabChange);
}
else {
	laf.window.footerTabs(['Map', 'Satellite'], tabChange);
}
