//=== HEADER & DATA =============================
Ti.include('../../common/winHeader.js');

var loaded = false;
var showFavorites = true;
var showRacquetballOnly = (winData.showRacquetballOnly == undefined) ? false : winData.showRacquetballOnly;

var zipCode = laf.object.isSaved('ZipCode') ? Ti.App.Properties.getString('ZipCode') : '';
var rowClicked = false;
var lastFilteredClubs = laf.location.clubFilterString();
var clubs = [];

//=== OBJECTS =============================	
var vwActivity = new activityIndicator();

var tvClubList = Ti.UI.createTableView({
    top: 48,
    backgroundColor: 'white',
    rowBackgroundColor: 'transparent',
    separatorColor: '#e1e1e1'
});

var vwLocation = Ti.UI.createView({
    left: 0,
    right: 0,
    top: 0,
    height: 48,
    backgroundColor: '#576996'
});

var tfLocation = Ti.UI.createTextField({
    value: zipCode,
    bottom: 2,
    top: 2,
    left: 5,
    right: (laf.device.isiPhone()) ? 90 : 55,
    hintText: (laf.network.isConnected(false)) ? 'City, State OR ZIP' : 'ZIP/Postal Code',
    autocorrect: false,
    returnKeyType: Ti.UI.RETURNKEY_DONE,
    borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
    clearButtonMode: Ti.UI.INPUT_BUTTONMODE_ONFOCUS,
    autocapitalization: Ti.UI.TEXT_AUTOCAPITALIZATION_WORDS
});
vwLocation.add(tfLocation);

var btnGPS = Ti.UI.createButton({
    title: (laf.device.isiPhone()) ? ' GPS' : 'GPS',
    top: 1,
    height: 45,
    right: 5,
    width: (laf.device.isiPhone()) ? 80 : 47
});

if (laf.device.isiPhone()) {
    btnGPS.image = laf.path.images + 'location.png';
    btnGPS.color = 'black';
    btnGPS.borderWidth = 2.0; //iOS 3.1.3 not displaying full border without this
    btnGPS.borderRadius = 3.5;
    btnGPS.backgroundImage = laf.path.images + 'BUTT_gry_off.png';
    btnGPS.ackgroundSelectedImage = laf.path.images + 'BUTT_gry_on.png';
    btnGPS.backgroundDisabledImage = laf.path.images + 'BUTT_gry_off.png';
}
vwLocation.add(btnGPS);

var btnMap = Ti.UI.createButton({
    title: 'Map'
});

var btnCancel = Ti.UI.createButton({
    title: 'Cancel'
});

function newClubRow(club){
    var tvrClub = Ti.UI.createTableViewRow({
        height: 50,
        className: 'clubPickerClub',
        rowType: 'Club',
        clubID: club.ClubID
    });
    
    tvrClub.add(Ti.UI.createLabel({
        font: {
            fontSize: 16,
            fontWeight: 'bold',
            fontFamily: 'Arial'
        },
        color: 'black',
        top: 5,
        left: 5,
        right: laf.table.leftDataRightMargin,
        height: 20,
        textAlign: 'left',
        text: club.Description
    }));
    
    tvrClub.add(Ti.UI.createLabel({
        color: '#7F7F7F',
        font: {
            fontSize: 14,
            fontFamily: 'Arial'
        },
        top: 25,
        left: 5,
        right: laf.table.leftDataRightMargin,
        height: 20,
        textAlign: 'left',
        text: club.City + ', ' + club.State
    }));
    
    tvrClub.add(Ti.UI.createLabel({
        color: '#576996',
        font: {
            fontSize: 16,
            fontWeight: 'bold',
            fontFamily: 'Arial'
        },
        height: 20,
        textAlign: 'right',
        right: 5,
        text: isNaN(club.Distance) ? '' : parseInt(club.Distance, 10) + ' Mi'
    }));
    
    laf.table.makeRowSelectable(tvrClub);
    return tvrClub;
}

//=== FUNCTIONS =============================	
function getFavoriteClubs(){
    var clubs = [];
    
    var favClubs = Ti.App.Properties.getString('FavoriteClubs').split(',');
    if (favClubs != undefined && favClubs.length != undefined && favClubs.length != 0) {
        var favClubFilter = '';
        for (var clubItr = 0, clubLen = favClubs.length; clubItr < clubLen; clubItr++) {
            favClubFilter += ',\'' + favClubs[clubItr] + '\'';
        }
        favClubFilter = favClubFilter.substring(1);
        
        if (showRacquetballOnly) {
            clubs = laf.data.clubSet('SELECT Club.CLUB_ID, DESCRIPTION, ADDRESS, CITY, STATE, PHONE FROM Club JOIN ClubAmenity ON ClubAmenity.CLUB_ID = Club.CLUB_ID WHERE Club.CLUB_ID IN (' + favClubFilter + ') AND ClubAmenity.AmenityID = \'1\'', ['ClubID', 'Description', 'Address', 'City', 'State', 'Phone']);
        }
        else {
            clubs = laf.data.clubSet('SELECT CLUB_ID, DESCRIPTION, ADDRESS, CITY, STATE, PHONE FROM Club WHERE CLUB_ID IN (' + favClubFilter + ')', ['ClubID', 'Description', 'Address', 'City', 'State', 'Phone']);
        }
        laf.location.addClubDistance(clubs, false);
        
        //Sort by order stored in array
        clubs.sort(function(a, b){
            return favClubs.indexOf(a.ClubID) - favClubs.indexOf(b.ClubID);
        });
    }
    
    return clubs;
}

function getFilteredClubs(){
    var clubs = [];
    
    if (laf.location.clubFilterString() != '') {
        lastFilteredClubs = laf.location.clubFilterString();
        if (showRacquetballOnly) {
            clubs = laf.data.clubSet('SELECT Club.CLUB_ID, DESCRIPTION, ADDRESS, CITY, STATE, PHONE FROM Club JOIN ClubAmenity ON ClubAmenity.CLUB_ID = Club.CLUB_ID WHERE Club.CLUB_ID IN (' + lastFilteredClubs + ') AND ClubAmenity.AmenityID = \'1\'', ['ClubID', 'Description', 'Address', 'City', 'State', 'Phone']);
        }
        else {
            clubs = laf.data.clubSet('SELECT CLUB_ID, DESCRIPTION, ADDRESS, CITY, STATE, PHONE FROM Club WHERE CLUB_ID IN (' + lastFilteredClubs + ')', ['ClubID', 'Description', 'Address', 'City', 'State', 'Phone']);
        }
        laf.location.addClubDistance(clubs);
    }
    else {
        clubs = [];
    }
    
    return clubs;
}

function setClubRows(){
    tvClubList.visible = true;
    
    var data = [];
    
    if (showFavorites) {
        showFavorites = false; //Only show favorites on initial load
        var favClubs = getFavoriteClubs();
        if (favClubs.length > 0) {
            data.push(laf.table.section('Favorites'));
            for (favClubsItr = 0, favClubsLen = favClubs.length; favClubsItr < favClubsLen; favClubsItr++) {
                data.push(newClubRow(favClubs[favClubsItr]));
            }
        }
    }
    
    data.push(laf.table.section('Clubs'));
    var clubs = getFilteredClubs();
    
    if (clubs == undefined || clubs.length == undefined || clubs.length == 0) {
        data.push(laf.table.infoRow('No clubs found within 50 miles,\ncheck your spelling and change\nyour search location above.'));
    }
    else {
        //Create Filtered Club List
        for (var clubItr = 0, clubLen = clubs.length; clubItr < clubLen; clubItr++) {
            data.push(newClubRow(clubs[clubItr]));
        }
    }
    
    tvClubList.setData(data);
    laf.table.scrollToTop(tvClubList, false);
};

function updateLocation(lat, lon, location){
    Ti.App.Properties.setDouble('Latitude', lat);
    Ti.App.Properties.setDouble('Longitude', lon);
    Ti.App.Properties.setString('ZipCode', location);
    tfLocation.value = location;
    
    vwActivity.show('Filtering Clubs...');
    laf.location.filterClubs(lat, lon, 50);
    setClubRows();
    vwActivity.hide();
}

function validateAndLoad(){
    if (laf.verify.isEmpty(tfLocation)) {
        laf.window.alert('Invalid Location', 'Please enter a valid location.');
        tfLocation.focus();
        return;
    }
    
    tfLocation.blur();
    tfLocation.value = laf.verify.trim(tfLocation.value);
    
    if (zipCode != '' && tfLocation.value == zipCode) {
        //Same zipcode no need to recalculate GPS position		
        vwActivity.show('Loading...');
        setClubRows();
        vwActivity.hide();
    }
    else {
        zipCode = tfLocation.value;
        
        var Lat = 0;
        var Lon = 0;
        
        //Try looking up by zip/postal code as we have local db
        var postalLookup = laf.location.postalCode(tfLocation.value);
        if (postalLookup != undefined && postalLookup.Lat != undefined && postalLookup.Lon != undefined) {
            Lat = isNaN(postalLookup.Lat) ? 0 : postalLookup.Lat;
            Lon = isNaN(postalLookup.Lon) ? 0 : postalLookup.Lon;
        }
        
        //Zipcode lookup didn't work, try seeing if coordinates were entered
        if ((Lat == undefined || Lon == undefined || (Lat == 0 && Lon == 0))) {
            var comma = tfLocation.value.indexOf(',', 0);
            if (comma > 0 && comma < tfLocation.value.length - 1) {
                Lat = parseFloat(tfLocation.value.substring(0, comma));
                Lon = parseFloat(tfLocation.value.substring(comma + 1, tfLocation.value.length));
                if (isNaN(Lat) || isNaN(Lon)) {
                    Lat = 0;
                    Lon = 0;
                }
            }
        }
        
        //If we have internet & no results, try doing an online lookup
        if ((Lat == undefined || Lon == undefined || (Lat == 0 && Lon == 0)) && laf.network.isConnected(false)) {
            vwActivity.show('Locating...');
            laf.location.freeEntry(tfLocation.value, function(Lat, Lon, Location){
                vwActivity.hide();
                if (Lat == undefined || Lon == undefined || (Lat == 0 && Lon == 0)) {
                    zipCode = '';
                    laf.window.alert('Could Not Locate', 'Check that you have entered a valid location and try again.');
                }
                else {
                    updateLocation(Lat, Lon, Location);
                }
            });
        }
        else 
            if (Lat == undefined || Lon == undefined || (Lat == 0 && Lon == 0)) {
                zipCode = '';
                if (!laf.network.isConnected(false) && !laf.verify.isZipCode(tfLocation.value)) {
                    laf.window.alert('Cannot Connect', 'You must connect to a Wi-Fi or cellular data network to lookup locations other than US ZIP Codes.');
                }
                else {
                    var locMessage = 'Check that you have entered a valid location and try again.';
                    if (!laf.network.isConnected(false)) {
                        locMessage += ' Connecting to a Wi-Fi or cellular data network may help.';
                    }
                    laf.window.alert('Could Not Locate', locMessage);
                }
            }
            else {
                updateLocation(Lat, Lon, tfLocation.value);
            }
    }
}

//=== EVENTS =============================	
laf.window.listen('clubSelected', function(){
    //Club selection from map, close this window
    if (!rowClicked) {
        win.close();
    }
});

tvClubList.addEventListener('click', function(e){
    if (e.rowData != undefined && e.rowData.rowType != undefined && e.rowData.rowType == 'Club') {
        if (e.rowData.clubID >= 0) {
            tvClubList.touchEnabled = false;
            rowClicked = true;
            
            if (laf.device.isiPhone()) {
                if (e.index > tvClubList.data[0].rows.length - 1) {
                    tvClubList.data[1].rows[e.index - tvClubList.data[0].rows.length].hasCheck = true;
                }
                else {
                    tvClubList.data[0].rows[e.index].hasCheck = true;
                }
            }
            
            laf.window.fire('clubSelected', {
                clubID: e.rowData.clubID
            });
            
            setTimeout(function(){
                win.close();
            }, (laf.device.isiPhone()) ? 700 : 0);
        }
    }
});

btnMap.addEventListener('click', function(e){
    if (laf.verify.isEmpty(tfLocation)) {
        laf.window.alert('Invalid Location', 'Please enter a valid location.');
        tfLocation.focus();
        return;
    }
    
    if (laf.network.isConnected(true)) {
        laf.window.create('Map', '/views/common/clubMap.js', {
            fireEvent: true
        });
        laf.window.open();
    }
});

btnCancel.addEventListener('click', function(e){
    win.close();
});

btnGPS.addEventListener('click', function(e){
    if (!laf.location.enabled()) {
        laf.window.alert('GPS Disabled', 'Your device has GPS location turned off, please enable it.');
        return;
    }
    
    tfLocation.blur();
    vwActivity.show('Locating...');
    
    laf.location.gps(function(lat, lon, location){
        vwActivity.hide();
        if (lat == undefined || lon == undefined || (lat == 0 && lon == 0)) {
            tfLocation.value = '';
        }
        else {
            if (location != undefined && location.length > 0) {
                tfLocation.value = location;
            }
            else {
                tfLocation.value = lat + ', ' + lon;
            }
            validateAndLoad();
        }
    });
});

tfLocation.addEventListener('return', function(){
    validateAndLoad();
});

tfLocation.addEventListener('focus', function(){
    if (loaded && laf.device.isiPhone()) {
        tvClubList.visible = false;
    }
});

tfLocation.addEventListener('blur', function(){
    tvClubList.visible = true;
});

//=== DISPLAY =============================
setLeftNav(btnCancel);
setRightNav(btnMap);
vwMain.add(vwLocation);
vwMain.add(tvClubList);
tfLocation.blur();
setTimeout(function(){
    loaded = true;
    if (laf.verify.isEmpty(tfLocation)) {
        tfLocation.focus();
    }
    else {
        tfLocation.blur();
        validateAndLoad();
    }
}, 125);
