(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    var currPasscode = laf.object.isSaved('Passcode') ? Ti.App.Properties.getString('Passcode') : '';
    var reset = (winData != undefined && winData.reset == true);
    var unlock = (winData != undefined && winData.unlock == true);
    if (reset) {
        currPasscode = '';
    }
    
    //=== OBJECTS =============================
    var tfHidden = Ti.UI.createTextField({
        height: 0,
        width: 0,
        keyboardType: Ti.UI.KEYBOARD_NUMBER_PAD,
        returnKeyType: Ti.UI.RETURNKEY_DONE,
        passwordMask: true,
        suppressReturn: false
    });

    function newTextEntry(left){
        return Ti.UI.createTextField({
            left: left,
            height: 60,
            width: 60,
            borderStyle: Ti.UI.INPUT_BORDERSTYLE_BEZEL,
            color: 'black',
            textAlign: 'center',
            font: {
                fontSize: 30
            },
            backgroundColor: 'white',
            passwordMask: true,
            enabled: false,
            editable: false
        });
    }
    
    var tvPasscode = Ti.UI.createTableView({
        backgroundColor: '#576996',
        rowBackgroundColor: 'transparent',
        separatorColor: 'transparent',
        scrollable: false,
        allowsSelection: false
    });
    
    var data = [];
    
    data.push(Titanium.UI.createTableViewRow({
        height: 20,
        className: 'commonPasscodeRowEmpty'
    }));
    var tvRowInstructions = Ti.UI.createTableViewRow({
        height: 20,
        className: 'commonPasscodeRowInstructions',
        hasChild: false,
        borderWidth: 3
    });
    
    var lblInstructions = Ti.UI.createLabel({
        color: 'White',
        font: {
            fontSize: 18,
            fontFamily: 'Arial'
        },
        height: 20,
        top: 0,
        bottom: 0,
        textAlign: 'center',
        text: (currPasscode.length > 0) ? 'Please enter your passcode' : 'Enter a passcode'
    });
    tvRowInstructions.add(lblInstructions);
    data.push(tvRowInstructions);
    
    var tvRowPasscodeEntry = Ti.UI.createTableViewRow({
        height: 100,
        className: 'commonPasscodeRowEmpty'
    });
    
    var vwPasscodeEntry = Titanium.UI.createView({
        height: 60,
        width: 270 //257
    });
    
    var tfFirst = newTextEntry(0);
    var tfSecond = newTextEntry(70);
    var tfThird = newTextEntry(140);
    var tfFourth = newTextEntry(210);
    
    vwPasscodeEntry.add(tfFirst);
    vwPasscodeEntry.add(tfSecond);
    vwPasscodeEntry.add(tfThird);
    vwPasscodeEntry.add(tfFourth);
    vwPasscodeEntry.add(tfHidden);
    
    tvRowPasscodeEntry.add(vwPasscodeEntry);
    data.push(tvRowPasscodeEntry);
    
    data.push(Titanium.UI.createTableViewRow({
        height: 60,
        className: 'commonPasscodeEntry'
    }));
    tvPasscode.setData(data);
    
    var btnCancel = Ti.UI.createButton({
        title: 'Cancel',
        enabled: !unlock,
        visible: false
    });
    
    var btnForgot = Ti.UI.createButton({
        title: 'Forgot?',
        enabled: !reset
    });
    //=== FUNCTIONS =============================
    function resetEntry(){
        tfHidden.value = tfFirst.value = tfSecond.value = '';
        tfThird.value = tfFourth.value = '';
        tfHidden.focus();
    }
    
    function login(){
        if (laf.verify.isEmpty(tfHidden)) {
            resetEntry();
            return;
        }
                
		var enteredPasscode = tfHidden.value.toString().substring(0, 4);
        
        if (reset) {
            if (laf.verify.isEmpty(currPasscode)) {
                currPasscode = enteredPasscode;
                lblInstructions.text = 'Re-enter your passcode';
                resetEntry();
            }
            else {
                if (currPasscode == enteredPasscode) {
                    tfFourth.blur();
                    Ti.App.Properties.setString('Passcode', enteredPasscode);
                    laf.window.alert('Passcode changed.');
                    laf.window.goHome();
                }
                else {
                    lblInstructions.text = 'Passcodes did not match.  Try again.';
                    currPasscode = '';
                    resetEntry();
                }
            }
        }
        else {
            if (currPasscode == enteredPasscode) {
                if (!unlock) {
                    laf.window.create('Passcode Settings', 'views/home/settingsPasscode.js');
                    laf.window.open();
                }
                
                setTimeout(function(){
                    win.close();
                }, 600);
            }
            else {
                lblInstructions.text = 'Incorrect passcode.  Try again.';
                resetEntry();
            }
        }
    }
    
    //=== EVENTS =============================
    Ti.Gesture.addEventListener('orientationchange', function(e){
        tfHidden.focus();
    });
    
    tfHidden.addEventListener('change', function(e){
        switch (tfHidden.value.length) {
            case 0:
                tfFirst.value = tfSecond.value = tfThird.value = tfFourth.value = '';
                break;
            case 1:
                tfFirst.value = '*';
                tfSecond.value = tfThird.value = tfFourth.value = '';
                break;
            case 2:
                tfFirst.value = tfSecond.value = '*';
                tfThird.value = tfFourth.value = '';
                break;
            case 3:
                tfFirst.value = tfSecond.value = tfThird.value = '*';
                tfFourth.value = '';
                break;
            default:
                tfFirst.value = tfSecond.value = tfThird.value = tfFourth.value = '*';
                login();
                break;
        }
    });
    
    btnCancel.addEventListener('click', function(){
        win.close();
    });
    
    btnForgot.addEventListener('click', function(){
        laf.window.alert('Logout', 'In order to remove your passcode, you will be logged out and all personal information removed from the application.\n\nYou will need to log back in.', ['Logout', 'Cancel'], function(e){
            if (e.index == 0) {
                laf.auth.logOut();
                laf.window.goHome();
            }
        });
    });
    
    //Prevent opening multiple login windows
    laf.window.listen('resumed', function(){
        setTimeout(function(){
            win.close();
        }, 600);
    });
	
	win.addEventListener('open', function(){
        tfHidden.focus();		
	});
    
    //=== DISPLAY =============================
    //Use empty view to hide back button on iPhone
    setLeftNav(unlock ? Ti.UI.createView({
        width: 0,
        height: 0
    }) : btnCancel);
	
    setRightNav(reset ? null : btnForgot);
    
	//Use interval to make sure we always have focus on hidden
	setInterval(function(){
		tfHidden.focus();
	}, 350);
	
    vwMain.add(tvPasscode);
})();
