//=== HEADER & DATA =============================
Ti.include('../../common/winHeader.js');
var selectedContact = winData.selectedContact;
var strRelationship = laf.auth.isAuthenticated(false) ? 'your friend\'s' : 'your';

//=== OBJECTS =============================
var tvContactInfo = Ti.UI.createTableView({
    backgroundColor: 'white',
    rowBackgroundColor: 'transparent',
    separatorColor: 'transparent'
});

var btnCancel = Ti.UI.createButton({
    title: 'Cancel'
});

var btnDone = Ti.UI.createButton({
    title: 'Done',
    style: Ti.UI.iPhone.SystemButtonStyle.DONE
});

var btnFillContacts = Ti.UI.createButton({
    title: 'Fill From Contacts',
    height: 25,
    color: 'black',
    width: 260,
    backgroundImage: laf.path.images + 'BUTT_gry_off.png',
    backgroundSelectedImage: laf.path.images + 'BUTT_gry_on.png'
});

function newEditRow(lblText, control){
    var tvRow = Ti.UI.createTableViewRow({
        height: 45,
        backgroundSelectedColor: 'white',
        className: lblText
    });
    laf.table.ignoreRowSelection(tvRow);
    
    tvRow.add(Ti.UI.createLabel({
        color: 'black',
        font: {
            fontSize: 18,
            fontFamily: 'Arial'
        },
        left: 5,
        height: 25,
        width: 110,
        textAlign: 'left',
        fontWeight: 'bold',
        text: lblText
    }));
    
    tvRow.add(control);
    
    return tvRow;
}

function newTextField(hintText, keyboard, autocapitalization){
    return Ti.UI.createTextField({
        color: '#336699',
        height: 40,
        left: 70,
        right: 10,
        hintText: hintText,
        autocorrect: false,
        borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
        clearButtonMode: Ti.UI.INPUT_BUTTONMODE_ONFOCUS,
        keyboardType: keyboard,
        autocapitalization: autocapitalization,
        returnKeyType: Ti.UI.RETURNKEY_NEXT,
		suppressReturn: false
    });
}

var tfFirst = newTextField('First Name', Ti.UI.KEYBOARD_DEFAULT, Ti.UI.TEXT_AUTOCAPITALIZATION_WORDS);
var tfLast = newTextField('Last Name', Ti.UI.KEYBOARD_DEFAULT, Ti.UI.TEXT_AUTOCAPITALIZATION_WORDS);
var tfPhone = newTextField('Phone Number', Ti.UI.KEYBOARD_NUMBERS_PUNCTUATION, Ti.UI.TEXT_AUTOCAPITALIZATION_ALL);
var tfEmail = newTextField('E-mail Address', Ti.UI.KEYBOARD_EMAIL, Ti.UI.TEXT_AUTOCAPITALIZATION_NONE);
tfEmail.returnKeyType = Ti.UI.RETURNKEY_DONE;

//=== FUNCTIONS =============================
function verifyAndClose(){
    tfFirst.blur();
    tfLast.blur();
    tfPhone.blur();
    tfEmail.blur();
    
    if (laf.verify.isEmpty(tfFirst)) {
        laf.window.alert('Required', 'Please enter ' + strRelationship + ' First Name');
        tfFirst.focus();
        return;
    }
    
    if (laf.verify.isEmpty(tfLast)) {
        laf.window.alert('Required', 'Please enter ' + strRelationship + ' Last Name');
        tfLast.focus();
        return;
    }
    
    if (laf.verify.isEmpty(tfPhone) || !laf.verify.isPhone(tfPhone.value)) {
        laf.window.alert(laf.verify.isEmpty(tfPhone) ? 'Required' : 'Invalid', 'Please enter ' + strRelationship + ' 10-digit Phone Number');
        tfPhone.focus();
        return;
    }
    
    if (laf.verify.isEmpty(tfEmail) || !laf.verify.isEmail(tfEmail.value)) {
        laf.window.alert(laf.verify.isEmpty(tfEmail) ? 'Required' : 'Invalid', 'Please enter ' + strRelationship + ' Email Address');
        tfEmail.focus();
        return;
    }
    
    laf.window.fire('contactEntered', {
        contact: {
            FirstName: tfFirst.value,
            LastName: tfLast.value,
            PhoneNumber: tfPhone.value,
            Email: tfEmail.value
        }
    });
    
    setTimeout(function(){
        win.close();
    }, (laf.device.isiPhone()) ? 600 : 0);
}

function setContactRows(){
    var data = [];
    
    data.push(laf.table.section('Contact Information'));
    
    var tvrDescription = Ti.UI.createTableViewRow({
        height: 65,
        className: 'guestsContactDetails'
    });
    laf.table.ignoreRowSelection(tvrDescription);
    
    tvrDescription.add(Ti.UI.createView({
        backgroundImage: laf.path.images + 'user.png',
        height: 48,
        width: 48,
        top: 5,
        right: 10
    }));
    
    tvrDescription.add(Ti.UI.createLabel({
        color: 'black',
        font: {
            fontSize: 18,
            fontFamily: 'Arial'
        },
        top: 5,
        left: 10,
        right: 68,
        height: 50,
        text: 'Enter contact information.'
    }));
    data.push(tvrDescription);
    
    if (selectedContact != undefined) {
        tfFirst.value = selectedContact.FirstName == undefined ? '' : selectedContact.FirstName;
        tfLast.value = selectedContact.LastName == undefined ? '' : selectedContact.LastName;
        tfPhone.value = selectedContact.PhoneNumber == undefined ? '' : selectedContact.PhoneNumber;
        tfEmail.value = selectedContact.Email == undefined ? '' : selectedContact.Email;
    }
    
    data.push(newEditRow('First:', tfFirst));
    data.push(newEditRow('Last:', tfLast));
    data.push(newEditRow('Phone:', tfPhone));
    data.push(newEditRow('E-mail:', tfEmail));
    
    var tvrFillFromContacts = Ti.UI.createTableViewRow({
        height: 75,
        className: 'guestsContactFill'
    });
    laf.table.ignoreRowSelection(tvrFillFromContacts);
    tvrFillFromContacts.add(btnFillContacts);
    data.push(tvrFillFromContacts);
    
    tvContactInfo.setData(data);
}

//=== EVENTS =============================
btnDone.addEventListener('click', function(){
    verifyAndClose();
});

btnCancel.addEventListener('click', function(){
    win.close();
});

btnFillContacts.addEventListener('click', function(e){
    var values = {
        cancel: function(){
        },
        animated: true,
        selectedPerson: function(e){
            var email = '';
            var phone = '';
            
            //Problems with email & phone on device, works ok in simulator
            if (!laf.object.isNullOrEmpty(e.person.email)) {
                for (var label in e.person.email) {
                    if (e.person.email[label] != undefined && e.person.email[label].length > 0) {
                        email = e.person.email[label][0];
                        break;
                    }
                }
            }
            
            if (!laf.object.isNullOrEmpty(e.person.phone)) {
                for (var label2 in e.person.phone) {
                    if (e.person.phone[label2] != undefined && e.person.phone[label2].length > 0) {
                        phone = e.person.phone[label2][0];
                        break;
                    }
                }
            }
            
            //Some devices don't always have first/last seperated
            var first = e.person.firstName;
            var last = e.person.lastName;
            if (laf.verify.isEmpty(first) && laf.verify.isEmpty(last)) {
                var fullName = laf.verify.trim(e.person.fullName);
                var space = e.person.fullName.lastIndexOf(' ');
                if (space < 0) {
                    first = fullName;
                }
                else {
                    first = laf.verify.trim(fullName.substring(0, space));
                    last = laf.verify.trim(fullName.substring(space));
                }
            }
            
            tfFirst.value = laf.verify.isEmpty(first) ? '' : first;
            tfLast.value = laf.verify.isEmpty(last) ? '' : last;
            tfPhone.value = laf.verify.isEmpty(phone) ? '' : phone;
            tfEmail.value = laf.verify.isEmpty(email) ? '' : email;
        }
    };
    
    Ti.Contacts.showContacts(values);
});

tfFirst.addEventListener('return', function(){
    tfLast.focus();
});
tfLast.addEventListener('return', function(){
    tfPhone.focus();
});
tfPhone.addEventListener('return', function(){
    tfEmail.focus();
});
tfEmail.addEventListener('return', function(){
    verifyAndClose();
});

//=== DISPLAY =============================
setContactRows();
vwMain.add(tvContactInfo);
setLeftNav(btnCancel);
setRightNav(btnDone);
