(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    var hiddenGuests = Ti.App.Properties.getString('VIPGuestsHidden');
    if (hiddenGuests == undefined || hiddenGuests.length == 0) {
        hiddenGuests = [];
    }
    else {
        //Get array of hidden, make sure all are strings
        hiddenGuests = hiddenGuests.split(',');
        for (var hiddenItr = 0, hiddenLen = hiddenGuests.length; hiddenItr < hiddenLen; hiddenItr++) {
            hiddenGuests[hiddenItr] = hiddenGuests[hiddenItr] + '';
        }
    }
    
    //=== OBJECTS =============================
	var vwBackground = Ti.UI.createView({
        backgroundImage: laf.path.images + 'background.png',
        left: 0,
        right:0,
		top: 0,
		bottom: 0,
		opacity: 0.80,
		visible: false
    });
	
    var vwActivity = new activityIndicator();
    
    var btnAdd = Ti.UI.createButton({
        title: 'Add'
    });
    
	if (laf.device.isiPhone()) {
        btnAdd.systemButton = Ti.UI.iPhone.SystemButton.ADD;
    }
    
	var tvGuests = Ti.UI.createTableView({
		backgroundColor: 'transparent',		
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1'
	});
    
    function newGuestRow(guestID, name, status){
        var tvRow = Ti.UI.createTableViewRow({
            height: 50,
            hasChild: (guestID > 0),
            className: 'vipGuestListGuest' + (guestID > 0), //Differentiate className by hasChild
            rowType: 'Guest',
            guestID: guestID
        });
        tvRow.add(Ti.UI.createView({
            backgroundImage: laf.path.images + 'user.png',
            left: 5,
            width: 29,
            height: 29
        }));
        tvRow.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            top: 5,
            left: 45,
            right: 2,
            height: 25,
            minimumFontSize: 10,
            text: name
        }));
        
        tvRow.add(Ti.UI.createLabel({
            color: '#7F7F7F',
            font: {
                fontSize: 12,
                fontFamily: 'Arial'
            },
            top: 30,
            left: 45,
            right: 2,
            bottom: 5,
            height: 15,
            text: status
        }));
        laf.table.makeRowSelectable(tvRow);
        return tvRow;
    }
    
    //=== FUNCTIONS =============================
    function addGuestToContacts(guest){
        var contact = Ti.Contacts.createPerson();
        
        contact.firstName = guest.FirstName;
        contact.lastName = guest.LastName;
        
        if (guest.Email.length > 0) {
            contact.email = {
                'home': [guest.Email]
            };
        }
        
        if (guest.Phone.length > 0 || guest.CellPhone.length > 0) {
            var phone = {};
            if (guest.Phone.length > 0) {
                phone.home = [guest.Phone.replace(/[^\d]/g, '')];
            }
            if (guest.CellPhone.length > 0 && (guest.Phone.length == 0 || guest.Phone.replace(/\D/g, '') != guest.CellPhone.replace(/\D/g, ''))) {
                phone.mobile = [guest.CellPhone.replace(/[^\d]/g, '')];
            }
            contact.phone = phone;
        }
        
        Ti.Contacts.save();
        laf.window.alert('Contacts', guest.FirstName + ' ' + guest.LastName + ' has been added to your contacts.');
    }
    
    function loadVIPGuests(){
        if (laf.network.isConnected(!laf.object.isSaved('VIPGuests'))) {
            var callbackOK = function(response){
                if (response.Success) {
                    var refreshNeeded = !laf.object.isSaved('VIPGuests') || Ti.App.Properties.getString('VIPGuests') != JSON.stringify(response.Value);
                    if (refreshNeeded) {
                        laf.object.save('VIPGuests', response.Value);
                        setVIPGuestRows();
                    }
                }
                else {
                    laf.window.alert('Unable to Update', 'Could not update VIP Guests at this time. Using data stored from last update.');
                }
            };
            
            var callbackFail = function(error){
                if (laf.object.isSaved('VIPGuests')) {
                    laf.window.alert('Unable to Update', 'Could not update VIP Guests at this time. Using data stored from last update.');
                }
                else {
                    laf.window.alert('Unable to Connect', 'There was an error connecting to LA Fitness web services.');
                }
                setVIPGuestRows();
            };
            
            post('', 'Private.svc/GetVIPGuestList', callbackOK, callbackFail, laf.object.isSaved('VIPGuests'));
        }
        else {
            if (laf.object.isSaved('VIPGuests')) {
                laf.window.alert('Unable to Update', 'Could not update VIP Guests at this time. Using data stored from last update.');
            }
            setVIPGuestRows();
        }
    }
    
    function newCheckinRow(strCheckinTime){
        var tvRow = Ti.UI.createTableViewRow({
            height: 30,
            className: 'checkinRow'
        });
        tvRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 30,
            left: 10,
            right: 10,
            text: strCheckinTime
        }));
        return tvRow;
    };
    
    function setVIPGuestRows(){
        var data = [];
        
        data.push(laf.table.section('My VIP Guests'));
        var guests = (laf.object.isSaved('VIPGuests')) ? laf.object.load('VIPGuests') : undefined;
        
        if (!laf.object.isNullOrEmpty(guests)) {
			//if a guest exist then set background image to invisible
			vwBackground.visible = false;
			
            tvGuests.touchEnabled = true;
            laf.table.showEmptyRows(tvGuests);
            
            var now = new Date();
            var status = '';
            var statusDate = '';
            var statusDateStr = '';
            
            for (var guestItr = 0, guestLen = guests.length; guestItr < guestLen; guestItr++) {
            
                var currGuest = guests[guestItr];
                
                if (hiddenGuests.indexOf('' + currGuest.GuestID) < 0) {
                    if (currGuest.ExpireDate != undefined && currGuest.ExpireDate != '/Date(-62135568000000-0800)/') {
                        statusDateStr = currGuest.ExpireDate.toString();
                        statusDateStr = statusDateStr.substring(statusDateStr.indexOf('(') + 1, statusDateStr.indexOf('-'));
                        statusDate = new Date(parseInt(statusDateStr, 10));
                        if (now < statusDate) {
                            status = 'Expires: ' + statusDate.toDateString();
                        }
                        else {
                            status = 'Expired: ' + statusDate.toDateString();
                        }
                    }
                    else 
                        if (currGuest.IssueDate != undefined && currGuest.IssueDate != '/Date(-62135568000000-0800)/') {
                            statusDateStr = currGuest.IssueDate.toString();
                            statusDateStr = statusDateStr.substring(statusDateStr.indexOf('(') + 1, statusDateStr.indexOf('-'));
                            statusDate = new Date(parseInt(statusDateStr, 10));
                            status = 'Issued: ' + statusDate.toDateString();
                        }
                        else {
                            statusDateStr = currGuest.CreateDate.toString();
                            //Date's added by add vip event won't be webservice encoded
                            if (statusDateStr.indexOf('(') > -1) {
                                statusDateStr = statusDateStr.substring(statusDateStr.indexOf('(') + 1, statusDateStr.indexOf('-'));
                            }
                            statusDate = new Date(parseInt(statusDateStr, 10));
                            status = 'Added ' + statusDate.toDateString();
                        }
                    
                    data.push(newGuestRow(currGuest.GuestID, currGuest.FirstName + ' ' + currGuest.LastName, status));
                }
            }
        }
        
        if (laf.object.isNullOrEmpty(guests) || data.length <= 1) {
			//If no guest then set background image visible
			vwBackground.visible = true;
			
            tvGuests.touchEnabled = false;
            laf.table.hideEmptyRows(tvGuests, false);
            
            var strAddGuest = 'You have no VIP Guests.\n\nClick the';
            strAddGuest += (laf.device.isiPhone()) ? ' + ' : ' Add ';
            strAddGuest += 'button in the\nupper right to add one.';
            
            var tvrNoGuests = Ti.UI.createTableViewRow({
                height: 145,
                editable: false,
                moveable: false,
                className: 'vipGuestsListNoGuest'
            });
            tvrNoGuests.add(Ti.UI.createLabel({                
                color: 'white',
                font: {
                    fontSize: 18,
                    fontFamily: 'Arial'
                },
                top: 25,
                left: 5,
                right: 5,
                height: 120,
                textAlign: 'center',
                text: strAddGuest
            }));
            data.push(tvrNoGuests);
        }
        
        tvGuests.setData(data);
    };
    
    function VIPGuestOptionDialog(rowIndex, guest){
        var options = [];
        options.push('Hide');
        if (guest.Email.length > 0) {
            options.push('Email');
        }
        if (guest.Phone.length > 0) {
            options.push('Call');
        }
        if (guest.CellPhone.length > 0 && (guest.Phone.length == 0 || guest.Phone.replace(/\D/g, '') != guest.CellPhone.replace(/\D/g, ''))) {
            options.push('Call Cell');
        }
        if (laf.device.isiPhone() && (guest.Email.length > 0 || guest.Phone.length > 0 || guest.CellPhone.length > 0)) {
            options.push('Add to Contacts');
        }
        
        var dlgVIPGuestOptions;
        if (laf.device.isAndroid()) {
            dlgVIPGuestOptions = Ti.UI.createOptionDialog({
                options: options,
                destructive: 0,
                title: guest.FirstName + ' ' + guest.LastName,
                buttonNames: ['Cancel']
            });
        }
        else {
            options.push('Cancel');
            dlgVIPGuestOptions = Ti.UI.createOptionDialog({
                options: options,
                destructive: 0,
                cancel: options.length - 1,
                title: guest.FirstName + ' ' + guest.LastName
            });
        }
        
        dlgVIPGuestOptions.addEventListener('click', function(e){
            if (e.index == 0 && laf.device.isAndroid() && e.button) {
                return;
            }
            else {
                switch (options[e.index]) {
                    case 'Hide':
                        hiddenGuests.push(guest.GuestID + '');
                        Ti.App.Properties.setString('VIPGuestsHidden', hiddenGuests.toString());
                        tvGuests.deleteRow(rowIndex, {
                            animationStyle: Ti.UI.iPhone.RowAnimationStyle.RIGHT
                        });
                        
                        //Set the no guests label
                        if (tvGuests.data[0].rows.length == 0) {
                            setVIPGuestRows();
                        }
                        break;
                    case 'Email':
                        var emailDialog = Ti.UI.createEmailDialog();
                        emailDialog.setSubject('LA Fitness');
                        emailDialog.setToRecipients([guest.Email]);
                        emailDialog.setMessageBody('I wanted to hear how your experience with LA Fitness was.');
                        emailDialog.open();
                        break;
                    case 'Call':
                        laf.network.openURL('tel:' + guest.Phone.replace(/\D/g, ''), guest.FirstName + ' ' + guest.LastName);
                        break;
                    case 'Call Cell':
                        laf.network.openURL('tel:' + guest.CellPhone.replace(/\D/g, ''), guest.FirstName + ' ' + guest.LastName);
                        break;
                    case 'Add to Contacts':
                        var people = Ti.Contacts.getPeopleWithName(guest.FirstName + ' ' + guest.LastName);
                        if (people != undefined && people.length > 0) {
                            var guestConfirmAdd = Ti.UI.createAlertDialog({
                                title: 'Already Exists',
                                message: guest.FirstName + ' ' + guest.LastName + ' already exists in your contacts, would you still like to add them?',
                                buttonNames: ['Cancel', 'Add']
                            });
                            guestConfirmAdd.addEventListener('click', function(e){
                                if (e.index == 1) {
                                    addGuestToContacts(guest);
                                }
                            });
                            guestConfirmAdd.show();
                        }
                        else {
                            //  Contacts doesn't exist 
                            addGuestToContacts(guest);
                        }
                        break;
                }
            }
        });
        dlgVIPGuestOptions.show();
    }
    
    //=== EVENTS =============================
    tvGuests.addEventListener('click', function(e){
        if (e.rowData.rowType != undefined && e.rowData.rowType == 'Guest' && e.rowData.guestID > 0 && laf.object.isSaved('VIPGuests')) {
            var guests = laf.object.load('VIPGuests');
            if (!laf.object.isNullOrEmpty(guests)) {
                for (var guestItr = 0, guestLen = guests.length; guestItr < guestLen; guestItr++) {
                    if (guests[guestItr].GuestID == e.rowData.guestID) {
                        VIPGuestOptionDialog(e.index, guests[guestItr]);
                    }
                }
            }
        }
    });
    
    btnAdd.addEventListener('click', function(e){
        if (laf.network.isConnected(true)) {
            laf.window.create('Add Guest', '/views/guests/vipGuestsAdd.js');
            laf.window.open();
        }
    });
    
    laf.window.listen('VIPGuestAdded', function(){
        setVIPGuestRows();
		laf.window.alert('Guest Pass Created', 'Your friend has been added to your VIP Guest List and will be sent an email with their free guest pass (check spam folders).');		
    });
    
    //=== DISPLAY =============================
    vwActivity.show('Loading...');
    setVIPGuestRows();
    setRightNav(btnAdd);	
	vwMain.add(vwBackground);
    vwMain.add(tvGuests);	
    vwActivity.hide();
	
	setTimeout(loadVIPGuests, 600); //check for udpated data, delayed for intial load to finish
})();
