(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    var buttonsEnabled = true;
    
    //=== OBJECTS =============================
    vwMain.add(Ti.UI.createView({
        backgroundImage: laf.path.images + 'background.png',
        left: 0,
        right: 0,
        top: 0,
        bottom: 0,
        opacity: 1
    }));
    
    var tvBody = Ti.UI.createTableView({
        backgroundColor: 'transparent',
        rowBackgroundColor: 'transparent',
        separatorColor: 'transparent'
    });
    
    var btnLogin = Ti.UI.createButton({
        title: (laf.auth.isAuthenticated(false)) ? 'Logout' : 'Member Login'
    });
    
    var btnSettings = Ti.UI.createButton({
        title: 'Settings'
    });
    
    function createButton(align, title, image){
        var btnView = Ti.UI.createView({
            height: 90,
            width: 90,
            top: 20,
            borderRadius: 10,
            borderColor: 'transparent', //Avoid some gray lines on refresh,
            backgroundColor: 'transparent',
            borderWidth: 0,
            name: title
        });
        if (align == 0) {
            btnView.left = 5;
        }
        if (align == 2) {
            btnView.right = 5;
        }
        btnView.add(Ti.UI.createView({
            backgroundImage: laf.path.images + image,
            height: 48,
            left: 20,
            width: 48,
            top: 10,
            borderRadius: 10
        }));
        btnView.add(Ti.UI.createLabel({
            color: 'white',
            font: {
                fontSize: 15,
                fontWeight: 'light'
            },
            height: 19,
            left: 0,
            width: 90,
            top: 60,
            text: title,
            textAlign: 'center'
        }));
        btnView.addEventListener('click', function(e){
            buttonClick(btnView);
        });
        return btnView;
    }
    
    //=== FUNCTIONS =============================
    function buttonClick(sourceButton){
        if (buttonsEnabled) { //Prevent multiple clicks
            buttonsEnabled = false;
            sourceButton.backgroundColor = '#576996'; //'#53508B';
            var winToOpen;
            switch (sourceButton.name) {
                case 'About':
                    winToOpen = laf.window.create('About', '/views/about/default.js');
                    break;
                case 'Buzz':
                    if (laf.network.isConnected(true)) {
                        winToOpen = laf.window.create('Buzz', '/views/buzz/default.js');
                    }
                    break;
                case 'Favorites':
                    winToOpen = laf.window.create('Favorites', '/views/favorites/default.js');
                    break;
                case 'Free Pass':
                    if (laf.network.isConnected(true)) {
                        winToOpen = laf.window.create('Free Pass', '/views/guests/default.js');
                    }
                    break;
                case 'Gallery':
                    winToOpen = laf.window.create('Gallery', '/views/gallery/default.js');
                    winToOpen.backgroundColor = 'black';
                    winToOpen.hideNavBar = true;
                    winToOpen.orientationModes = [Ti.UI.LANDSCAPE_LEFT, Ti.UI.LANDSCAPE_RIGHT];
                    break;
                case 'Guests':
                    winToOpen = laf.window.create('Guests', '/views/guests/default.js');
                    break;
                case 'Search':
                    winToOpen = laf.window.create('Search', '/views/search/default.js');
                    break;
                case 'Membership':
                    winToOpen = laf.window.create('Membership', '/views/membership/default.js');
                    break;
                case 'Reserve':
                    winToOpen = laf.window.create('Reservations', '/views/reservations/default.js');
                    break;
                case 'Track':
                    winToOpen = laf.window.create('Track', '/views/track/default.js');
                    //winToOpen = laf.window.create('Track','/views/track/statistics.js');                    
                    break;
                case 'Why Join?':
                    winToOpen = laf.window.create('Why Join', '/views/whyJoin/default.js');
                    break;
            }
            
            setTimeout(function(){
                if (winToOpen != undefined) {
                    laf.window.open();
                }
                sourceButton.backgroundColor = 'transparent';
                buttonsEnabled = true;
            }, 600);
        }
    };
    
    function setData(){
        buttonsEnabled = true;
        var buttons = [];
        
        if (laf.auth.isAuthenticated(false)) {
            btnLogin.title = 'Logout';
            buttons = [{
                title: 'Favorites',
                image: 'favorite.png'
            }, {
                title: 'Search',
                image: 'search.png'
            }, {
                title: 'Buzz',
                image: 'globe.png'
            }, {
                title: 'Membership',
                image: 'edit2.png'
            }, {
                title: 'Reserve',
                image: 'calendar2.png'
            }, {
                title: 'Guests',
                image: 'guest.png'
            }, {
                title: 'About',
                image: 'info.png'
            }];
        }
        else {
            btnLogin.title = 'Member Login';
            buttons = [{
                title: 'Why Join?',
                image: 'question.png'
            }, {
                title: 'Search',
                image: 'search.png'
            }, {
                title: 'Buzz',
                image: 'globe.png'
            }, {
                title: 'Gallery',
                image: 'photo.png'
            }, {
                title: 'Free Pass',
                image: 'pass.png'
            }, {
                title: 'About',
                image: 'info.png'
            }];
        }
        
        var tvRow = Ti.UI.createTableViewRow({
            height: 120,
            backgroundColor: 'transparent',
            className: buttons[0].image
        });
        laf.table.ignoreRowSelection(tvRow, 'transparent');
        
        var data = [];
        for (var buttonItr = 0, buttonLen = buttons.length; buttonItr < buttonLen; buttonItr++) {
            if (tvRow == undefined) {
                tvRow = Ti.UI.createTableViewRow({
                    height: 120,
                    className: buttons[buttonItr].title,
                    backgroundColor: 'transparent',
                    backgroundSelectedColor: 'transparent'
                });
                laf.table.ignoreRowSelection(tvRow, 'transparent');
            }
            tvRow.add(createButton(buttonItr % 3, buttons[buttonItr].title, buttons[buttonItr].image));
            
            if ((buttonItr + 1) % 3 == 0) {
                data.push(tvRow);
                tvRow = undefined;
            }
        }
        if (tvRow != undefined) {
            data.push(tvRow);
        }
        
        tvBody.setData(data);
        laf.table.scrollToTop(tvBody);
    }
    
    //=== EVENTS =============================
    btnLogin.addEventListener('click', function(e){
        if (buttonsEnabled) {
            buttonsEnabled = false;
            if (btnLogin.title == 'Logout') {
                laf.window.alert('Logout', 'Are you sure that you would like to logout of your LAFitness.com account?', ['Logout', 'Cancel'], function(e){
                    if (e.index == 0) {
                        laf.auth.logOut();
                        setLeftNav(null);
                    }
                });
            }
            else 
                if (laf.network.isConnected(true)) {
                    laf.window.create('Login', 'views/home/login.js');
                    laf.window.open();
                }
            buttonsEnabled = true;
        }
    });
    
    btnSettings.addEventListener('click', function(e){
        if (buttonsEnabled) {
			laf.window.create('Settings', 'views/home/settings.js');
			laf.window.open();
		}
    });
    
    laf.window.listen('authenticationChange', setData);

    if (laf.device.isiPhone()) {
		//Android update events called in winHeader since there is no global resume
        win.addEventListener('open', function(){
            Ti.App.fireEvent('AppUpdate');
        });
        
        laf.window.listen('resumed', function(){
            if (laf.auth.isAuthenticated(false) && laf.object.isSaved('Passcode')) {
                laf.window.create('Passcode', 'views/common/passcode.js', {
                    unlock: true
                });
                laf.window.open();
            }
        });
    }
    
    //Android search button
    laf.window.listen('search', function(){
        laf.window.create('Search', '/views/search/default.js');
        laf.window.open();
    });
	
    //=== DISPLAY =============================
    setData();
    vwMain.add(tvBody);
    setRightNav(btnLogin);
    
    if (!laf.auth.isAuthenticated(false) && laf.network.isConnected(false)) {
        laf.window.alert('Welcome', 'Welcome to LA Fitness Mobile.\n\nAre you an LA Fitness member?', ['Member', 'Guest'], function(e){
            if (e.index == 0) {
                laf.window.create('Login', 'views/home/login.js');
                laf.window.open();
            }
        });
    }
    
    if (laf.device.isiPhone()) {
        if (laf.auth.isAuthenticated(false) && laf.object.isSaved('Passcode')) {
            laf.window.create('Passcode', 'views/common/passcode.js', {
                unlock: true
            });
            laf.window.open();
        }
    }
})();
