(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    var accountSummary = (laf.object.isSaved('AccountSummary')) ? laf.object.load('AccountSummary') : undefined;
    
    //=== OBJECTS =============================
    var tfBarcode;
    
    var tvLogin = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1'
    });
    
    var btnCancel = Ti.UI.createButton({
        title: 'Cancel'
    });
    
    var btnSearch = Ti.UI.createButton({
        title: 'Search',
        style: Ti.UI.iPhone.SystemButtonStyle.DONE
    });
    
    //=== FUNCTIONS =============================
    function locateAccount(){
        tfBarcode.blur();
        
        if (laf.verify.isEmpty(tfBarcode)) {
            laf.window.alert('Invalid Key Tag', 'Please enter the letters and numbers beneath the barcode on your membership key tag.');
            tfBarcode.focus();
            return;
        }
        
        if (laf.network.isConnected(true)) {
            var callbackOK = function(response){
                if (response.Success && response.Value.BarcodeID != undefined && response.Value.BarcodeID.length > 0 && response.Value.IsFitness) {
                    accountSummary = response.Value;
                    laf.object.save('AccountSummary', accountSummary);
                    setOptionRows();
                }
                else {
                    laf.window.alert('Invalid Account', 'Please try again using the key tag from your primary fitness account.');
                    tfBarcode.focus();
                }
            };
            
            post({
                BarcodeID: tfBarcode.value
            }, 'Public.svc/GetAccountSummary', callbackOK);
        }
    }
    
    function refresh(){
        if (laf.network.isConnected(false)) {
            var callbackOK = function(response){
				if (response.Success && accountSummary != response.Value) {
					if (response.Value.BarcodeID != undefined && response.Value.BarcodeID.length > 0 && response.Value.IsFitness) {
                    	accountSummary = response.Value;
                    	laf.object.save('AccountSummary', accountSummary);
                    	setOptionRows();							
					}	
				}
            };

            post({
                BarcodeID: accountSummary.BarcodeID
            }, 'Public.svc/GetAccountSummary', callbackOK, undefined, true);
        }
    }
    
    function setOptionRows(){
        setRightNav(null);
        tvLogin.separatorColor = (laf.device.isiPhone()) ? undefined : 'black';
        
        var data = [];
        
        data.push(laf.table.section('Account'));
        
        var tvrBarcode = Ti.UI.createTableViewRow({
            height: 160,
            className: 'loginOptionRows'
        });
        laf.table.ignoreRowSelection(tvrBarcode);
        
        var vwBarcode = Ti.UI.createView({
            height: 60,
            top: 10,
            left: 10,
            right: 10,
            borderWidth: 1,
            borderRadius: 10,
            borderColor: '#E0E0E0'
        });
        
        vwBarcode.add(Ti.UI.createView({
            backgroundImage: laf.path.images + 'keytag.png',
            height: 48,
            width: 48,
            top: 2,
            left: 10
        }));
        
        vwBarcode.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 20,
                fontFamily: 'Arial'
            },
            left: 68,
            right: 68,
            height: 55,
            text: accountSummary.BarcodeID.toUpperCase()
        }));
        
        var vwCancel = Ti.UI.createView({
            backgroundImage: laf.path.images + 'x.png',
            height: 28,
            width: 27,
            right: 10
        });
        vwBarcode.add(vwCancel);
        
        //Required for cancel button to work, why?
        vwBarcode.addEventListener('click', function(e){
        });
        
        vwCancel.addEventListener('click', function(e){
            setBarcodeRows();
        });
        
        tvrBarcode.add(vwBarcode);
        
        tvrBarcode.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            top: 65,
            left: 10,
            right: 10,
            height: 100,
            text: 'We need to confirm that you are the owner of this account. Please select a method below.'
        }));
        
        data.push(tvrBarcode);
        
        data.push(laf.table.section('Authorization Options'));
        
        if (accountSummary.HasLogin) {
            data.push(laf.table.actionRow('Use your existing\nLAFitness.com account.', 'Login', 60, 'user.png'));
        }
        else {
            data.push(laf.table.actionRow('Create a new\n LAFitness.com account.', 'New', 60, 'userAdd.png'));
        }
        if (accountSummary.HasEmail) {
            data.push(laf.table.actionRow('Activate by email with the\naddress we have on file.', 'Email', 60, 'mailSend.png'));
        }
        
        tvLogin.setData(data);
        laf.table.scrollToTop(tvLogin, false);
    }
    
    function setBarcodeRows(){
        setRightNav(btnSearch);
        tvLogin.separatorColor = 'white';
        Ti.App.Properties.removeProperty('AccountSummary');
        Ti.App.Properties.removeProperty('DeviceToken');
        
        var data = [];
        
        data.push(laf.table.section('Membership Key Tag'));
        
        var tvrBarcode = Ti.UI.createTableViewRow({
            height: 320,
            className: 'loginBarcodeRows'
        });
        laf.table.ignoreRowSelection(tvrBarcode);
        
        tvrBarcode.add(Ti.UI.createView({
            backgroundImage: laf.path.images + 'keytag.png',
            height: 48,
            width: 48,
            top: 25,
            right: 10
        }));
        
        tvrBarcode.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            top: 5,
            left: 10,
            right: 68,
            height: 107,
            text: 'In order to locate your account, please enter the letters & numbers found on your membership key tag.'
        }));
        
        tfBarcode = Ti.UI.createTextField({
            color: '#336699',
            height: 40,
            left: 10,
            right: 10,
            top: 120,
            hintText: 'Membership Key Tag',
            autocorrect: false,
            borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
            keyboardType: Ti.UI.KEYBOARD_DEFAULT,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_SENTENCES,
            //autocapitalization: Ti.UI.TEXT_AUTOCAPITALIZATION_ALL,
            returnKeyType: Ti.UI.RETURNKEY_DONE,
            clearButtonMode: Ti.UI.INPUT_BUTTONMODE_ONFOCUS
        });
        tfBarcode.addEventListener('return', locateAccount);
        tvrBarcode.add(tfBarcode);
        
        data.push(tvrBarcode);
        
        tvLogin.setData(data);
        laf.table.scrollToTop(tvLogin, false);
        
        setTimeout(function(){
            tfBarcode.focus();
        }, 400);
    }
    
    //=== EVENTS =============================	
    tvLogin.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.rowType != undefined) {
            switch (e.rowData.rowType) {
                case 'Email':
                    laf.window.create('Email', 'views/home/loginEmail.js', {
                        accountSummary: accountSummary
                    });
                    laf.window.open();
                    break;
                case 'Login':
                    laf.window.create('Account', 'views/home/loginAccount.js', {
                        accountSummary: accountSummary
                    });
                    laf.window.open();
                    break;
                case 'New':
                    laf.window.create('Create', 'views/home/loginCreateReset.js', {
                        accountSummary: accountSummary
                    });
                    laf.window.open();
                    break;
            }
        }
    });
    
    btnCancel.addEventListener('click', function(e){
        win.close();
    });
    
    btnSearch.addEventListener('click', function(e){
        locateAccount();
    });
    
    //=== DISPLAY =============================
    setLeftNav(btnCancel);
    
    if (accountSummary == undefined) {
        setBarcodeRows();
        setTimeout(function(){
            tfBarcode.focus();
        }, 400);
    }
    else {
		setOptionRows();		
        setTimeout(function(){
            refresh();
        }, 400);
    }
    
    vwMain.add(tvLogin);
})();
