//=== HEADER & DATA =============================
Ti.include('../../common/winHeader.js');

//=== OBJECTS =============================
var tvLogin = Ti.UI.createTableView({
    backgroundColor: 'white',
    rowBackgroundColor: 'transparent',
    separatorColor: 'transparent'
});

var btnLogin = Ti.UI.createButton({
    title: 'Login',
    style: Ti.UI.iPhone.SystemButtonStyle.DONE
});

var btnCancel = Ti.UI.createButton({
    title: 'Cancel'
});

var tfUsername = Ti.UI.createTextField({
    color: '#336699',
    height: 40,
    left: 10,
    right: 10,
    top: 65,
    hintText: 'Username',
    autocapitalization: Ti.UI.TEXT_AUTOCAPITALIZATION_NONE,
    keyboardType: Ti.UI.KEYBOARD_DEFAULT,
    returnKeyType: Ti.UI.RETURNKEY_NEXT,
    autocorrect: false,
    borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
    clearButtonMode: Ti.UI.INPUT_BUTTONMODE_ONFOCUS,
    suppressReturn: false
});

var tfPassword = Ti.UI.createTextField({
    color: '#336699',
    height: 40,
    left: 10,
    right: 10,
    top: 110,
    hintText: 'Password',
    passwordMask: true,
    autocorrect: false,
    autocapitalization: Ti.UI.TEXT_AUTOCAPITALIZATION_NONE,
    returnKeyType: Ti.UI.RETURNKEY_DONE,
    keyboardType: Ti.UI.KEYBOARD_DEFAULT,
    borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
    clearButtonMode: Ti.UI.INPUT_BUTTONMODE_ONFOCUS,
    suppressReturn: false
});

var btnForgot = Ti.UI.createButton({
    title: 'Forgot Username/Password?',
    height: 25,
    color: 'black',
    width: 260,
    top: 180,
    backgroundImage: laf.path.images + 'BUTT_gry_off.png',
    backgroundSelectedImage: laf.path.images + 'BUTT_gry_on.png'
});

//=== FUNCTIONS =============================
function login(){
    tfUsername.blur();
    tfPassword.blur();
    
    if (laf.verify.isEmpty(tfUsername)) {
        laf.window.alert('Required', 'Please enter your username.');
        tfUsername.focus();
        return;
    }
    
    if (laf.verify.isEmpty(tfPassword)) {
        laf.window.alert('Required', 'Please enter your password.');
        tfPassword.focus();
        return;
    }
    
    var memberaccount = {
        Username: laf.verify.trim(tfUsername.value),
        Password: laf.verify.trim(tfPassword.value)
    };
    
    var callbackFail = function(error){
        laf.window.alert('Unable to Connect', 'There was an error connecting to LA Fitness web services.');
        
        if (Ti.App.Properties.hasProperty('MemberAccount')) {
            Ti.App.fireEvent('authenticationChange');
            
            setTimeout(function(){
                laf.window.goHome();
            }, 600);
        }
    };
    
    var callbackOKMembership = function(response){
        if (response.Success) {
            var member = response.Value;
            laf.object.save('Member', member);
            var favoriteClubs = Ti.App.Properties.getString('FavoriteClubs').split(',');
            var isFavoriteClub = (favoriteClubs.toString().indexOf(member.ClubID) >= 0);
            if (!isFavoriteClub) {
                favoriteClubs.push(member.ClubID);
                Ti.App.Properties.setString('FavoriteClubs', favoriteClubs.toString());
                Ti.App.fireEvent('favChange');
            }
        }
        
        laf.window.fire('authenticationChange');
        
        setTimeout(function(){
            laf.window.goHome();
        }, 600);
    };
    
    var callbackOK = function(response){
        if (response.Success) {
            laf.object.save('MemberAccount', memberaccount);
            Ti.App.Properties.removeProperty('AccountSummary');
            Ti.App.Properties.removeProperty('DeviceToken');
            post('', 'Private.svc/GetCustomer', callbackOKMembership, callbackFail);
        }
        else {
            laf.window.alert('Login Failed', response.Message);
            tfUsername.blur();
            tfPassword.blur();
        }
    };
    
    post(memberaccount, 'Public.svc/AuthenticateAccount', callbackOK, callbackFail);
}

function setLoginRows(){
    var data = [];
    
    data.push(laf.table.section('Login'));
    
    var tvrLogin = Ti.UI.createTableViewRow({
        height: 320,
        className: 'loginAccount'
    });
    laf.table.ignoreRowSelection(tvrLogin);
    
    tvrLogin.add(Ti.UI.createView({
        backgroundImage: laf.path.images + 'lock.png',
        height: 48,
        width: 48,
        top: 5,
        right: 10
    }));
    
    tvrLogin.add(Ti.UI.createLabel({
        color: 'black',
        font: {
            fontSize: 18,
            fontFamily: 'Arial'
        },
        top: 5,
        left: 10,
        right: 68,
        height: 50,
        text: 'Login using your primary LAFitness.com account.'
    }));
    
    tvrLogin.add(tfUsername);
    tvrLogin.add(tfPassword);
    tvrLogin.add(btnForgot);
    
    data.push(tvrLogin);
    tvLogin.setData(data);
    laf.table.scrollToTop(tvLogin, false);
}

//=== EVENTS =============================
btnForgot.addEventListener('click', function(e){
    laf.window.create('Reset', 'views/home/loginCreateReset.js', {
        accountSummary: winData.accountSummary
    });
    laf.window.open();
});

tfUsername.addEventListener('return', function(e){
    tfPassword.focus();
});

tfPassword.addEventListener('return', function(e){
    login();
});

btnLogin.addEventListener('click', function(e){
    login();
});

btnCancel.addEventListener('click', function(e){
    laf.window.goHome();
});

//=== DISPLAY =============================
setLoginRows();
setRightNav(btnLogin);
setLeftNav(btnCancel);
vwMain.add(tvLogin);

if (laf.device.isAndroid()) {
    setTimeout(function(){
        tfUsername.focus();
    }, 400);
}
