(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    var accountSummary = winData.accountSummary;
    
    //=== OBJECTS =============================
    var tvLogin = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: 'transparent'
    });
    
    var btnRightNav = Ti.UI.createButton({
        title: 'Continue',
        style: Ti.UI.iPhone.SystemButtonStyle.DONE
    });
    
    var btnCancel = Ti.UI.createButton({
        title: 'Cancel'
    });
    
    function newPromptField(hintText, top){
        return Ti.UI.createTextField({
            color: '#336699',
            height: 40,
            left: 10,
            right: 10,
            top: top,
            hintText: hintText,
            autocorrect: false,
            borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Ti.UI.INPUT_BUTTONMODE_ONFOCUS,
            keyboardType: Ti.UI.KEYBOARD_DEFAULT,
            autocapitalization: Ti.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Ti.UI.RETURNKEY_NEXT,
			suppressReturn: false
		
        });
    }
    
    var tfLastName = newPromptField('Last Name', 90);
    var tfEmail = newPromptField('Email Address', 135);
    var tfZipCode = newPromptField('ZIP/Postal Code', 180);
    var tfUsername = newPromptField('Username', 90);
    var tfPassword = newPromptField('Password', 135);
    var tfConfirm = newPromptField('Confirm Password', 180);
    
    //Setting numbers keyboard on Android may break its ability to enter letters
    tfZipCode.keyboardType = (laf.device.isiPhone()) ? Ti.UI.KEYBOARD_NUMBERS_PUNCTUATION : Ti.UI.KEYBOARD_DEFAULT;
    tfLastName.autocapitalization = Ti.UI.TEXT_AUTOCAPITALIZATION_WORDS;
    tfEmail.keyboardType = Ti.UI.KEYBOARD_EMAIL;
    tfZipCode.autocapitalization = Ti.UI.TEXT_AUTOCAPITALIZATION_ALL;
    tfPassword.passwordMask = tfConfirm.passwordMask = true;
    tfZipCode.returnKeyType = tfConfirm.returnKeyType = Ti.UI.RETURNKEY_DONE;
    
    //=== FUNCTIONS =============================
    function createResetAccount(){
        tfUsername.blur();
        tfPassword.blur();
        tfConfirm.blur();
        
        var memberaccount = {
            Username: tfUsername.value,
            Password: tfPassword.value,
            LastName: tfLastName.value,
            FirstName: '',
            BarcodeID: accountSummary.BarcodeID,
            Zipcode: tfZipCode.value,
            Email: tfEmail.value
        };
        
        var callbackFail = function(error){
            laf.window.alert('Unable to Connect', 'There was an error connecting to LA Fitness web services.');
            
            if (Ti.App.Properties.hasProperty('MemberAccount')) {
                Ti.App.fireEvent('authenticationChange');
                
                setTimeout(function(){
                    laf.window.goHome();
                }, 600);
            }
        };
        
        var callbackOKMembership = function(response){
            if (response.Success) {
                var member = response.Value;
                laf.object.save('Member', member);
                var favoriteClubs = Ti.App.Properties.getString('FavoriteClubs').split(',');
                var isFavoriteClub = (favoriteClubs.toString().indexOf(member.ClubID) >= 0);
                if (!isFavoriteClub) {
                    favoriteClubs.push(member.ClubID);
                    Ti.App.Properties.setString('FavoriteClubs', favoriteClubs.toString());
                }
            }
            
            Ti.App.fireEvent('authenticationChange');
            
            setTimeout(function(){
                laf.window.goHome();
            }, 600);
        };
        
        var callbackOK = function(response){
            if (response.Success) {
                laf.object.save('MemberAccount', memberaccount);
                post('', 'Private.svc/GetCustomer', callbackOKMembership, callbackFail);
            }
            else {
                laf.window.alert('Login Failed', response.Message);
                if (response.Message == 'Zip/Postal Code or Email does not match what we have on file, which is required for account reset.' ||
                response.Message == 'Zip/Postal Code or Last Name does not match what we have on file. Please verify your information.') {
                    setAccountRows();
                }
            }
        };
        
        if (accountSummary.HasLogin) {
            post(memberaccount, 'Public.svc/ResetAccount', callbackOK, callbackFail);
        }
        else {
            post(memberaccount, 'Public.svc/CreateAccount', callbackOK, callbackFail);
        }
    }
    
    function validateLogin(){
        tfUsername.value = laf.verify.trim(tfUsername.value);
        tfPassword.value = laf.verify.trim(tfPassword.value);
        tfConfirm.value = laf.verify.trim(tfConfirm.value);
        
        if (laf.verify.isEmpty(tfUsername)) {
            laf.window.alert('Required', 'Please enter a username.');
            tfUsername.focus();
            return;
        }
        
        if (laf.verify.isEmpty(tfPassword)) {
            laf.window.alert('Required', 'Please enter a password.');
            tfPassword.focus();
            return;
        }
        
        if (laf.verify.isEmpty(tfConfirm)) {
            laf.window.alert('Required', 'Please enter your password confirmation.');
            tfConfirm.focus();
            return;
        }
        
        if (tfConfirm.value != tfPassword.value) {
            laf.window.alert('Invalid', 'Password & confirmation did not match');
            tfPassword.value = tfConfirm.value = '';
            tfPassword.focus();
            return;
        }
        
        createResetAccount();
    }
    
    function setLoginRows(){
        btnRightNav.title = (accountSummary.HasLogin) ? 'Reset' : 'Create';
        
        var data = [];
        
        data.push(laf.table.section('Login'));
        
        var tvrLogin = Ti.UI.createTableViewRow({
            height: 320,
            className: 'loginResetLogin'
        });
        
        tvrLogin.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            top: 2,
            left: 10,
            right: 68,
            height: 85,
            text: (accountSummary.HasLogin) ? 'Create new login credentials. You can use your current username or a new one.' : 'Create new login credentials to use when logging into the app or LAFitness.com.'
        }));
        
        tvrLogin.add(Ti.UI.createView({
            backgroundImage: laf.path.images + 'lock.png',
            height: 48,
            width: 48,
            top: 25,
            right: 10
        }));
        
        tvrLogin.add(tfUsername);
        tvrLogin.add(tfPassword);
        tvrLogin.add(tfConfirm);
        
        data.push(tvrLogin);
        
        tvLogin.setData(data);
        
        laf.table.scrollToTop(tvLogin, false);
    }
    
    function validateAccount(){
        tfLastName.value = laf.verify.trim(tfLastName.value);
        tfEmail.value = laf.verify.trim(tfEmail.value);
        tfZipCode.value = laf.verify.trim(tfZipCode.value);
        
        if (laf.verify.isEmpty(tfLastName)) {
            laf.window.alert('Required', 'Please enter your last name.');
            tfLastName.focus();
            return;
        }
        
        if (laf.verify.isEmpty(tfEmail) || !laf.verify.isEmail(tfEmail.value)) {
            laf.window.alert(laf.verify.isEmpty(tfEmail) ? 'Required' : 'Invalid', 'Please enter your email address.');
            tfEmail.focus();
            return;
        }
        
        if (laf.verify.isEmpty(tfZipCode) || (!laf.verify.isZipCode(tfZipCode.value) && !laf.verify.isPostalCode(tfZipCode.value))) {
            laf.window.alert(laf.verify.isEmpty(tfZipCode) ? 'Required' : 'Invalid', 'Please enter your zip/postal code.');
            tfZipCode.focus();
            return;
        }
        
        setLoginRows();
    }
    
    function setAccountRows(){
        var data = [];
        btnRightNav.title = 'Continue';
        
        data.push(laf.table.section('Account'));
        
        var tvrAccount = Ti.UI.createTableViewRow({
            height: 320,
            className: 'loginResetAccount'
        });
        laf.table.ignoreRowSelection(tvrAccount);
        
        tvrAccount.add(Ti.UI.createView({
            backgroundImage: laf.path.images + 'user.png',
            height: 48,
            width: 48,
            top: 25,
            right: 10
        }));
        
        tvrAccount.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            top: 5,
            left: 10,
            right: 68,
            height: 80,
            text: 'Provide the following account information to verify your identity.'
        }));
        
        tvrAccount.add(tfLastName);
        tvrAccount.add(tfEmail);
        tvrAccount.add(tfZipCode);
        
        data.push(tvrAccount);
        tvLogin.setData(data);
        laf.table.scrollToTop(tvLogin, false);
    }
    
    //=== EVENTS =============================
    btnRightNav.addEventListener('click', function(e){
        if (btnRightNav.title == 'Continue') {
            validateAccount();
        }
        else {
            validateLogin();
        }
    });
    
    btnCancel.addEventListener('click', function(e){
        win.close();
    });
    
    tfLastName.addEventListener('return', function(e){
        tfEmail.focus();
    });
    
    tfEmail.addEventListener('return', function(e){
        tfZipCode.focus();
    });
    
    tfZipCode.addEventListener('return', function(e){
        validateAccount();
    });
    
    tfUsername.addEventListener('return', function(e){
        tfPassword.focus();
    });
    tfPassword.addEventListener('return', function(e){
        tfConfirm.focus();
    });
    tfConfirm.addEventListener('return', function(e){
        validateLogin();
    });
    
    //=== DISPLAY =============================
    setAccountRows();
    setRightNav(btnRightNav);
    setLeftNav(btnCancel);
    vwMain.add(tvLogin);
})();
