//=== HEADER & DATA =============================
Ti.include('../../common/winHeader.js');
var now;
var deviceToken;
var accountSummary = winData.accountSummary;

//=== OBJECTS =============================
var tfActivationKey;

var tvLogin = Ti.UI.createTableView({
    backgroundColor: 'white',
    rowBackgroundColor: 'transparent',
    separatorColor: 'transparent'
});

var btnActivate = Ti.UI.createButton({
    title: 'Activate',
    style: Ti.UI.iPhone.SystemButtonStyle.DONE
});

var btnCancel = Ti.UI.createButton({
    title: 'Cancel'
});

var btnResend = Ti.UI.createButton({
    title: 'Send Activation Email Again',
    height: 25,
    color: 'black',
    width: 260,
    top: 190,
    backgroundImage: laf.path.images + 'BUTT_gry_off.png',
    backgroundSelectedImage: laf.path.images + 'BUTT_gry_on.png'
});

//=== FUNCTIONS =============================
function getDeviceToken(){
    now = new Date(); //Update for creation time
    var deviceToken;
    if (!laf.object.isSaved('DeviceToken')) {
        deviceToken = {
            token: Ti.Platform.createUUID(),
            createDate: now
        };
        laf.object.save('DeviceToken', deviceToken);
    }
    else {
        var regenerateDate = new Date();
        regenerateDate.setDate(regenerateDate.getDate() - 2);
        deviceToken = laf.object.load('DeviceToken');
        if (deviceToken.createDate < regenerateDate) {
            deviceToken.token = Ti.Platform.createUUID();
            deviceToken.createDate = now;
            laf.object.save('DeviceToken', deviceToken);
        }
    }
    return deviceToken;
}

function sendAuthEmail(successMessage){
    var callbackOK = function(response){
        if (!response.Success) {
            laf.window.alert('E-Mail Error', 'Try re-sending again. ' + response.Message);
        }
        else 
            if (successMessage) {
                laf.window.alert('E-Mail Sent', 'We have sent an email to the address we had on file. The message contains the activation code you will need to enter.');
            }
    };
    
    post({
        BarcodeID: accountSummary.BarcodeID,
        Username: deviceToken.token
    }, 'Public.svc/SendEmailForTokenActivation', callbackOK);
}

function login(){
    tfActivationKey.blur();
    
    if (laf.verify.isEmpty(tfActivationKey)) {
        laf.window.alert('Required', 'Please enter the activation code you received in your email.');
        tfActivationKey.focus();
        return;
    }
    
    var memberaccount = {
        Username: laf.verify.trim(deviceToken.token),
        Password: laf.verify.trim(tfActivationKey.value.toUpperCase())
    };
    
    var callbackFail = function(error){
        laf.window.alert('Unable to Connect', 'There was an error connecting to LA Fitness web services.');
        
        if (Ti.App.Properties.hasProperty('MemberAccount')) {
            Ti.App.fireEvent('authenticationChange');
            
            setTimeout(function(){
                laf.window.goHome();
            }, 600);
        }
    };
    
    var callbackOKMembership = function(response){
        if (response.Success) {
            //Set local property so data is available offline			
            var member = response.Value;
            laf.object.save('Member', member);
            var favoriteClubs = Ti.App.Properties.getString('FavoriteClubs').split(',');
            var isFavoriteClub = (favoriteClubs.toString().indexOf(member.ClubID) >= 0);
            if (!isFavoriteClub) {
                favoriteClubs.push(member.ClubID);
                Ti.App.Properties.setString('FavoriteClubs', favoriteClubs.toString());
            }
        }
        
        if (Ti.App.Properties.hasProperty('MemberAccount')) {
            Ti.App.fireEvent('authenticationChange');
            
            setTimeout(function(){
                laf.window.goHome(win);
            }, 600);
        }
    };
    
    var callbackOK = function(response){
        if (response.Success) {
            laf.object.save('MemberAccount', memberaccount);
            Ti.App.Properties.removeProperty('AccountSummary');
            Ti.App.Properties.removeProperty('DeviceToken');
            
            post('', 'Private.svc/GetCustomer', callbackOKMembership, callbackFail);
        }
        else {
            laf.window.alert('Login Failed', 'Please try again. ' + response.Message);
        }
    };
    
    post(memberaccount, 'Public.svc/AuthenticateAccount', callbackOK, callbackFail);
}

function setEmailRows(){
    var data = [];
    
    var emailDomain = '';
    if (accountSummary.EmailDomain != undefined && accountSummary.EmailDomain != '') {
        emailDomain = '(Sent to ****' + accountSummary.EmailDomain + ')';
    }
    
    data.push(laf.table.section('Activation'));
    
    var tvrActivation = Ti.UI.createTableViewRow({
        height: 320,
        className: 'loginEmail'
    });
    laf.table.ignoreRowSelection(tvrActivation);
    
    tvrActivation.add(Ti.UI.createView({
        backgroundImage: laf.path.images + 'mailSend.png',
        height: 48,
        width: 48,
        top: 25,
        right: 10
    }));
    
    tvrActivation.add(Ti.UI.createLabel({
        color: 'black',
        font: {
            fontSize: 18,
            fontFamily: 'Arial'
        },
        top: 5,
        left: 10,
        right: 68,
        height: 100,
        text: 'We have sent an email to the address we had on file. Enter the activation code it contains below.'
    }));
    
    tfActivationKey = Ti.UI.createTextField({
        color: '#336699',
        height: 40,
        left: 10,
        right: 10,
        top: 110,
        hintText: 'Activation Code',
        autocorrect: false,
        borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
        clearButtonMode: Ti.UI.INPUT_BUTTONMODE_ONFOCUS,
        keyboardType: Ti.UI.KEYBOARD_DEFAULT,
        autocapitalization: Ti.UI.TEXT_AUTOCAPITALIZATION_ALL,
        returnKeyType: Ti.UI.RETURNKEY_DONE
    });
    tfActivationKey.addEventListener('return', login);
    tvrActivation.add(tfActivationKey);
    
    tvrActivation.add(Ti.UI.createLabel({
        color: 'black',
        font: {
            fontSize: 14,
            fontWeight: 'light',
            fontFamily: 'Arial'
        },
        top: 155,
        left: 10,
        right: 10,
        height: 20,
        textAlign: 'center',
        text: emailDomain
    }));
    
    tvrActivation.add(btnResend);
    data.push(tvrActivation);
    tvLogin.setData(data);
}

//=== EVENTS =============================
btnResend.addEventListener('click', function(e){
    tfActivationKey.blur();
    sendAuthEmail(true);
});

btnActivate.addEventListener('click', function(e){
    login();
});

btnCancel.addEventListener('click', function(e){
    laf.window.goHome(win);
});

//=== DISPLAY =============================
deviceToken = getDeviceToken();
if (deviceToken.createDate == now) {
    sendAuthEmail();
}
setEmailRows();
setRightNav(btnActivate);
setLeftNav(btnCancel);
vwMain.add(tvLogin);
