(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    //Used for dialog boxes
    var rowIndex = -1;
    var apptID = -1;
    var clubID = -1;
    var apptStartTime;
    var apptEndTime;
    var apptDetails;
    
    //=== OBJECTS =============================		
	var tvBackground = Ti.UI.createView({
        backgroundImage: laf.path.images + 'background.png',
        left: 0,
        right:0,
		top: 0,
		bottom: 0,
		opacity: 0.80,
		visible: false
    });
	
	var vwActivity = new activityIndicator();
	
    var tvUpcoming = Ti.UI.createTableView({
        top: 0,
        bottom: 0,
        backgroundColor: 'transparent',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1'
    });
    
    var btnAdd = Ti.UI.createButton({
        title: 'Add'
    });
    if (laf.device.isiPhone()) {
        btnAdd.systemButton = Ti.UI.iPhone.SystemButton.ADD;
    }
    
    function newApptRow(isTraining, appointmentID, startTime, endTime, clubID, clubDescription, details){
        var tvRow = Ti.UI.createTableViewRow({
            height: 80,
            hasChild: true,
            className: (isTraining) ? 'upcomingTrainingRow' : 'upcomingRacquetballRow',
            rowType: 'Appointment',
            isTraining: isTraining,
            appointmentID: appointmentID,
            startTime: startTime,
            endTime: endTime,
            clubID: clubID,
            details: details
        });
        
        tvRow.add(Ti.UI.createView({
            backgroundImage: (isTraining) ? laf.path.images + 'weightLift.png' : laf.path.images + 'racquetball.png',
            left: 5,
            width: 29,
            height: 29
        }));
        
        tvRow.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 16,
                fontFamily: 'Arial'
            },
            top: 3,
            left: 45,
            height: 45,
            textAlign: 'left',
            text: startTime.toDateString() + '\n' + laf.dateTime.toTimeString(startTime) + ' to ' + laf.dateTime.toTimeString(endTime)
        }));
        
        tvRow.add(Ti.UI.createLabel({
            color: '#7F7F7F',
            font: {
                fontSize: 12,
                fontFamily: 'Arial'
            },
            top: 48,
            left: 45,
            right: 5,
            bottom: 5,
            height: 30,
            textAlign: 'left',
            text: clubDescription + '\n' + details
        }));
        
        laf.table.makeRowSelectable(tvRow);
        return tvRow;
    }
    
    var dlgTrainingAppt;
    if (laf.device.isAndroid()) {
        dlgTrainingAppt = Ti.UI.createOptionDialog({
            options: ['Cancel Reservation', 'Share Details'],
            destructive: 0,
            title: 'Reservation Options',
            buttonNames: ['Close']
        });
    }
    else {
        dlgTrainingAppt = Ti.UI.createOptionDialog({
            options: ['Cancel Reservation', 'Share Details', 'Close'],
            destructive: 0,
            cancel: 2,
            title: 'Reservation Options'
        });
    }
    
    var dlgRacquetballAppt;
    if (laf.device.isAndroid()) {
        dlgRacquetballAppt = Ti.UI.createOptionDialog({
            options: ['Cancel Reservation', 'Change Court', 'Share Details'],
            destructive: 0,
            title: 'Reservation Options',
            buttonNames: ['Close']
        });
    }
    else {
        dlgRacquetballAppt = Ti.UI.createOptionDialog({
            options: ['Cancel Reservation', 'Change Court', 'Share Details', 'Close'],
            destructive: 0,
            cancel: 3,
            title: 'Reservation Options'
        });
    }
    
    //=== FUNCTIONS =============================
    function load(){
        if (!laf.network.isConnected(false)) {
            laf.window.alert('Unable to Update', 'Could not retrieve upcoming reservations at this time. Using data stored from last update.');
            setUpcomingRows();
        }
        else {
            var lookupFailure = false;
            
            var callbackOKMembership = function(response){
                if (response.Success) {
                    laf.object.save('Member', response.Value);
                }
            };
            
            var callbackFailTraining = function(){
                laf.window.alert('Unable to Update', 'Could not retrieve upcoming reservations at this time. Using data stored from last update.');
                setUpcomingRows();
                post('', 'Private.svc/GetCustomer', callbackOKMembership, function(){
                }, true);
            };
            
            var callbackOKTraining = function(response){
                if (response.Success) {
                    laf.object.save('TrainingAppointments', response.Value);
                }
                
                if (!response.Success || lookupFailure) {
                    laf.window.alert('Unable to Update', 'Could not retrieve upcoming reservations at this time. Using data stored from last update.');
                }
                
                setUpcomingRows();
                post('', 'Private.svc/GetCustomer', callbackOKMembership, function(){
                }, true);
            };
            
            var callbackFailRacquetball = function(){
                lookupFailure = true;
                post('', 'Private.svc/GetScheduledAppointments', callbackOKTraining, callbackFailTraining);
            };
            
            var callbackOKRacquetball = function(response){
                if (response.Success) {
                    laf.object.save('AmenitiesAppointments', response.Value);
                }
                else {
                    lookupFailure = true;
                }
                post('', 'Private.svc/GetScheduledAppointments', callbackOKTraining, callbackFailTraining);
            };
            
            post('', 'Private.svc/GetAmenityAppointmentsUpcoming', callbackOKRacquetball, callbackFailRacquetball);
        }
    }
    
    function setUpcomingRows(){
        var allAppointments = [];
        var rAppts = [];
        var tAppts = [];
        var now = new Date();
        var data = [];
        
        data.push(laf.table.section('Upcoming Reservations'));
        
        var currAppt, endTime;
        
        if (laf.object.isSaved('AmenitiesAppointments')) {
            rAppts = laf.object.load('AmenitiesAppointments');
            if (laf.object.isNullOrEmpty(rAppts)) {
                laf.object.remove('AmenitiesAppointments');
            }
            else {
                for (var racquetballItr = 0, racquetballLen = rAppts.length; racquetballItr < racquetballLen; racquetballItr++) {
                    currAppt = rAppts[racquetballItr];
                    
                    //Old style schedule time, remove property so user refreshes
                    if (currAppt.EndTime.indexOf('(') > -1) {
                        laf.object.remove('AmenitiesAppointments');
                        break;
                    }
                    
                    endTime = laf.dateTime.fromString(currAppt.EndTime);
                    if (now < endTime) {
                        allAppointments.push(currAppt);
                    }
                }
            }
        }
        
        if (laf.object.isSaved('TrainingAppointments')) {
            tAppts = laf.object.load('TrainingAppointments');
            if (laf.object.isNullOrEmpty(tAppts)) {
                laf.object.remove('TrainingAppointments');
            }
            else {
                for (var trainingItr = 0, trainingLen = tAppts.length; trainingItr < trainingLen; trainingItr++) {
                    currAppt = tAppts[trainingItr];
                    
                    //Old style schedule time, remove property so user refreshes
                    if (currAppt.EndDateTime.indexOf('(') > -1) {
                        laf.object.remove('TrainingAppointments');
                        break;
                    }
                    
                    endTime = laf.dateTime.fromString(currAppt.EndDateTime);
                    if (now < endTime) {
                        allAppointments.push(currAppt);
                    }
                }
            }
        }
        
        //Sort in order of date		
        allAppointments.sort(function(a, b){
            return laf.dateTime.fromString((a.StartTime != undefined) ? a.StartTime : a.StartDateTime) -
            laf.dateTime.fromString((b.StartTime != undefined) ? b.StartTime : b.StartDateTime);
        });
        
        //Add sorted rows
        if (laf.object.isNullOrEmpty(allAppointments)) {
            //If no reservation exist, set background image visible
			tvBackground.visible = true;

            tvUpcoming.touchEnabled = false;
            laf.table.hideEmptyRows(tvUpcoming, false);
            
            var strAddReservation = 'You have no upcoming reservations.\n\nClick the';
            strAddReservation += (laf.device.isiPhone()) ? ' + ' : ' Add ';
            strAddReservation += 'button in the upper right to add a racquetball or personal training reservation.';
            
            var tvrNoUpcoming = Ti.UI.createTableViewRow({
                height: 145,
                className: 'UpcomingNoUpcoming'
            });
            tvrNoUpcoming.add(Ti.UI.createLabel({
                color: 'white',
                font: {
                    fontSize: 18,
                    fontFamily: 'Arial'
                },
                top: 25,
                left: 5,
                right: 5,
                height: 120,
                textAlign: 'left',
                text: strAddReservation
            }));
            data.push(tvrNoUpcoming);
        }
        else {
			//If a reservation do exist, set background image invisible
			tvBackground.visible = false;	
			
            tvUpcoming.touchEnabled = true;
            laf.table.showEmptyRows(tvUpcoming);
            
            for (var allItr = 0, allLen = allAppointments.length; allItr < allLen; allItr++) {
                currAppt = allAppointments[allItr];
                
                if (allAppointments[allItr].AmenititesAppointmentID != undefined) {
                    data.push(newApptRow(false, currAppt.AmenititesAppointmentID, laf.dateTime.fromString(currAppt.StartTime), laf.dateTime.fromString(currAppt.EndTime), currAppt.ClubID, currAppt.ClubDescription, currAppt.AmenityDescription));
                }
                else {
                    data.push(newApptRow(true, currAppt.ID, laf.dateTime.fromString(currAppt.StartDateTime), laf.dateTime.fromString(currAppt.EndDateTime), currAppt.Club.ID, currAppt.Club.Description, currAppt.Trainer.Name));
                }
            }
        }
        
        tvUpcoming.setData(data);
        laf.table.scrollToTop(tvUpcoming, false);
    }
    
    //=== EVENTS =============================
    dlgTrainingAppt.addEventListener('click', function(e){
        if (e.index == 0 && (!laf.device.isAndroid() || !e.button)) {
            var adConfirmCancel = Ti.UI.createAlertDialog({
                title: 'Cancel Reservation',
                message: 'Are you sure you want to cancel this reservation?',
                buttonNames: ['Yes', 'No']
            });
            adConfirmCancel.addEventListener('click', function(e){
                if (e.index == 0) {
                    var callbackFailDelete = function(error){
                        laf.window.alert('Unable to Cancel', 'There was an error cancelling your reservation. Please try again.');
                    };
                    
                    var callbackOKDelete = function(response){
                        if (!response.Success) {
                            laf.window.alert('Unable to Cancel', response.Message);
                        }
                        else {
                            tvUpcoming.deleteRow(rowIndex, {
                                animationStyle: Ti.UI.iPhone.RowAnimationStyle.UP
                            });
                            
                            //Remove from local cache of reservation
                            if (laf.object.isSaved('TrainingAppointments')) {
                                var tAppts = laf.object.load('TrainingAppointments');
                                if (!laf.object.isNullOrEmpty(tAppts)) {
                                    for (var apptInd = 0; apptInd < tAppts.length; apptInd++) {
                                        if (tAppts[apptInd].ID == apptID) {
                                            tAppts.splice(apptInd, 1);
                                            laf.object.save('TrainingAppointments', tAppts);
                                            break;
                                        }
                                    }
                                    
                                    if (laf.object.isNullOrEmpty(tAppts)) {
                                        laf.object.remove('TrainingAppointments');
                                        setUpcomingRows();
                                    }
                                }
                            }
                        }
                    };
                    
                    post({
                        AppointmentID: apptID
                    }, 'Private.svc/CancelTrainingAppointment', callbackOKDelete, callbackFailDelete);
                }
            });
            
            adConfirmCancel.show();
        }
        else 
            if (e.index == 1) {
                var currClub = laf.data.clubRow('SELECT DESCRIPTION, ADDRESS, CITY, STATE, ZIP, PHONE FROM Club WHERE CLUB_ID = \'' + clubID + '\'', ['Description', 'Address', 'City', 'State', 'Zip', 'Phone']);
                var emailDialog = Ti.UI.createEmailDialog();
                emailDialog.setSubject('LA Fitness: Personal Training Reservation');
                emailDialog.setMessageBody('Personal Training Reservation\n\n' + apptStartTime.toDateString() + ' @ ' + laf.dateTime.toTimeString(apptStartTime) + ' to ' + laf.dateTime.toTimeString(apptEndTime) + '\n' + apptDetails + '\n\nLA Fitness: ' + currClub.Description + '\n' + currClub.Address + '\n' + currClub.City + ', ' + currClub.State + ' ' + laf.verify.padZip(currClub.Zip) + '\n' + currClub.Phone);
                emailDialog.open();
            }
    });
    
    dlgRacquetballAppt.addEventListener('click', function(e){
        if (e.index == 0 && (!laf.device.isAndroid() || !e.button)) {
            var adConfirmCancel = Ti.UI.createAlertDialog({
                title: 'Cancel Reservation',
                message: 'Are you sure you want to cancel this reservation?',
                buttonNames: ['Yes', 'No']
            });
            adConfirmCancel.addEventListener('click', function(e){
                if (e.index == 0) {
                    var callbackFailDelete = function(error){
                        laf.window.alert('Unable to Cancel', 'There was an error cancelling your reservation. Please try again.');
                    };
                    
                    var callbackOKDelete = function(response){
                        if (response.Success) {
                            tvUpcoming.deleteRow(rowIndex, {
                                animationStyle: Ti.UI.iPhone.RowAnimationStyle.UP
                            });
                            
                            //Remove from local cache of reservations 
                            if (laf.object.isSaved('AmenitiesAppointments')) {
                                var rAppts = laf.object.load('AmenitiesAppointments');
                                for (var apptInd = 0; apptInd < rAppts.length; apptInd++) {
                                    if (rAppts[apptInd].AmenititesAppointmentID == apptID) {
                                        rAppts.splice(apptInd, 1);
                                        laf.object.save('AmenitiesAppointments', rAppts);
                                        break;
                                    }
                                }
                                
                                if (laf.object.isNullOrEmpty(rAppts)) {
                                    laf.object.remove('AmenitiesAppointments');
                                    setUpcomingRows();
                                }
                            }
                        }
                        else {
                            laf.window.alert('Unable to Cancel', 'There was an error cancelling your reservation. Please try again.');
                        }
                    };
                    
                    post({
                        AmenititesAppointmentID: apptID
                    }, 'Private.svc/DeleteAmenityAppointment', callbackOKDelete, callbackFailDelete);
                }
            });
            adConfirmCancel.show();
        }
        else 
            if (e.index == 1) {
                var callbackFailCourtAvail = function(error){
                    laf.window.alert('Unable to Get Availability', 'There was an error getting court availability. Please try again.');
                };
                
                var callbackOKCourtAvail = function(response){
                    if (response.Success) {
                        var availability = response.Value;
                        if (availability != undefined && availability.length > 0) {
                            var options = [];
                            for (var x = 0, len = availability.length; x < len; x++) {
                                var currAvail = availability[x];
                                options.push(currAvail.Description);
                            }
                            
                            if (!laf.device.isAndroid()) {
                                options.push('Cancel');
                            }
                            
                            var dlgCourtSelect = Ti.UI.createOptionDialog({
                                options: options,
                                cancel: options.length - 1,
                                title: 'Select a Different Court'
                            });
                            
                            if (laf.device.isAndroid()) {
                                dlgCourtSelect.buttonNames = ['Cancel'];
                            }
                            
                            dlgCourtSelect.addEventListener('click', function(e){
                                if ((laf.device.isAndroid() && e.index == 0 && e.button) ||
                                (!laf.device.isAndroid() && e.index === options.length - 1)) {
                                    return; //Cancel Button
                                }
                                
                                var callbackFailCourtChange = function(error){
                                    laf.window.alert('Unable to Change Courts', 'There was an error changing courts. Please try again.');
                                };
                                
                                var callbackOKCourtChange = function(response){
                                    if (response.Success) {
                                        var newAppt = response.Value;
                                        tvUpcoming.updateRow(rowIndex, newApptRow(false, newAppt.AmenititesAppointmentID, laf.dateTime.fromString(newAppt.StartTime), laf.dateTime.fromString(newAppt.EndTime), newAppt.ClubID, newAppt.ClubDescription, newAppt.AmenityDescription), {
                                            animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                        });
                                    }
                                    else {
                                        laf.window.alert('Unable to Change Courts', 'There was an error changing courts. Please try again.');
                                    }
                                };
                                
                                post({
                                    AmenititesAppointmentID: apptID,
                                    NewAmenityID: availability[e.index].AmenitiesID
                                }, 'Private.svc/ChangeAppointmentCourt', callbackOKCourtChange, callbackFailCourtChange);
                            });
                            
                            dlgCourtSelect.show();
                        }
                        else {
                            laf.window.alert('No Courts Available', 'There are no other courts available at the time of your reservation.');
                        }
                    }
                    else {
                        laf.window.alert('Unable to Get Availability', 'There was an error getting court availability. Please try again.');
                    }
                };
                
                post({
                    AmenititesAppointmentID: apptID
                }, 'Private.svc/GetAlternateCourtsForAppointment', callbackOKCourtAvail, callbackFailCourtAvail);
            }
            else 
                if (e.index == 2) {
                    var currClub = laf.data.clubRow('SELECT DESCRIPTION, ADDRESS, CITY, STATE, ZIP, PHONE FROM Club WHERE CLUB_ID = \'' + clubID + '\'', ['Description', 'Address', 'City', 'State', 'Zip', 'Phone']);
                    var emailDialog = Ti.UI.createEmailDialog();
                    emailDialog.setSubject('LA Fitness: Racquetball Court Reservation');
                    emailDialog.setMessageBody('Racquetball Court Reservation\n\n' + apptStartTime.toDateString() + ' @ ' + laf.dateTime.toTimeString(apptStartTime) + ' to ' + laf.dateTime.toTimeString(apptEndTime) + '\n' + apptDetails + '\n\nLA Fitness: ' + currClub.Description + '\n' + currClub.Address + '\n' + currClub.City + ', ' + currClub.State + ' ' + laf.verify.padZip(currClub.Zip) + '\n' + currClub.Phone);
                    emailDialog.open();
                }
    });
    
    tvUpcoming.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.rowType != undefined && e.rowData.rowType == 'Appointment' && e.rowData.isTraining != undefined) {
            if (e.rowData.startTime < new Date()) {
                laf.window.alert('Past Reservation', 'You cannot modify/share a reservation in the past.');
                return;
            }
            
            rowIndex = e.index;
            apptID = e.rowData.appointmentID;
            clubID = e.rowData.clubID;
            apptStartTime = e.rowData.startTime;
            apptEndTime = e.rowData.endTime;
            apptDetails = e.rowData.details;
            
            if (e.rowData.isTraining) {
                dlgTrainingAppt.show();
            }
            else {
                dlgRacquetballAppt.show();
            }
        }
    });
    
    btnAdd.addEventListener('click', function(e){
        if (laf.network.isConnected(true)) {
            var dlgAddReservation;
            if (laf.device.isAndroid()) {
                dlgAddReservation = Ti.UI.createOptionDialog({
                    options: ['Racquetball Court', 'Personal Training'],
                    title: 'What would you like to reserve?',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgAddReservation = Ti.UI.createOptionDialog({
                    options: ['Racquetball Court', 'Personal Training', 'Cancel'],
                    cancel: 2,
                    title: 'What would you like to reserve?'
                });
            }
            
            dlgAddReservation.addEventListener('click', function(e){
                if (e.index == 0 && (!laf.device.isAndroid() || !e.button)) {
                    laf.window.create('Raquetball', '/views/reservations/racquetball.js');
                    laf.window.open();
                    return;
                }
                if (e.index == 1) {
                    laf.window.create('Personal Training', '/views/reservations/training.js');
                    laf.window.open();
                    return;
                }
            });
            
            dlgAddReservation.show();
        }
    });
    
    laf.window.listen('newReservation', function(){
        //Reservation Added to object on other screens, refresh display
        setUpcomingRows();
    });
    
    //=== DISPLAY =============================
    vwActivity.show('Loading...');
    load();
	vwMain.add(tvBackground);
    vwMain.add(tvUpcoming);
    setRightNav(btnAdd);
    vwActivity.hide();
})();
