(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    var selectedTrainerDexRowID = (winData.selectedTrainerDexRowID == undefined) ? '' : winData.selectedTrainerDexRowID;
	var data = [];
    
    //=== OBJECTS =============================
    var vwBackground = Ti.UI.createView({
        backgroundImage: laf.path.images + 'background.png',
        left: 0,
        right: 0,
        top: 0,
        bottom: 0,
        opacity: 0.80,
        visible: false
    });
    
    var tvTrainer = Ti.UI.createTableView({
        top: 0,
        backgroundColor: 'transparent',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1'
    });
    
    var btnCancel = Ti.UI.createButton({
        title: 'Cancel'
    });
    
    function newTrainerRow(trainerName, trainerDexRowID){
        var tvrTrainer = Ti.UI.createTableViewRow({
            height: 40,
            trainerName: trainerName,
            trainerDexRowID: trainerDexRowID,
			className: 'tvTrainerRow',
            hasCheck: (selectedTrainerDexRowID == trainerDexRowID)
        });
        
        tvrTrainer.add(Ti.UI.createLabel({
            font: {
                fontSize: 14,
                fontFamily: 'Arial'
            },
            color: 'black',
            top: 12,
            left: 10,
            right: 5,
            height: 20,
            textAlign: 'left',
            text: trainerName
        }));
        
        laf.table.makeRowSelectable(tvrTrainer);
        return tvrTrainer;
    }
    
    //=== FUNCTIONS =============================
	function loadTrainers(){
        if (laf.network.isConnected(true)) {
            var callbackFail = function(error){
                laf.window.alert('Unable to Get Trainers', 'There was an error retrieving the trainers scheduled at this club. Please try again or contact the club directly.');
            };
			
            var callbackOK = function(response){
                if (response.Success) {
                    var trainers = response.Value;
					
					if (trainers == undefined || trainers.length == 0) {
						data.push(laf.table.infoRow('There are no personal trainers available at this club. Please return to the previous screen and change the club.'));
					}
					else {
						for (var trainerItr = 0, trainerLen = trainers.length; trainerItr < trainerLen; trainerItr++) {
							data.push(newTrainerRow(trainers[trainerItr].Name, trainers[trainerItr].ID));
						}
					}
                    tvTrainer.setData(data);
                    laf.table.scrollToTop(tvTrainer, false);
                }
                else {
                    laf.window.alert('Unable to Get Trainers', 'There was an error retrieving the trainers scheduled at this club. Please try again or contact the club directly.');
                }
            };			
            
            var scheduleQuery = {
                ClubID: winData.selectedClubID,
                AppointmentDate: laf.dateTime.toString((new Date()), 'unspecified')
            };			
			
			laf.network.post(scheduleQuery, 'Private.svc/GetScheduledTrainers', callbackOK, callbackFail);
        }	
	}
	
    function setTrainerRows(){
        data.push(laf.table.section('Available Trainers'));
		
        if (winData.selectedClubID >= 0) {
            //A club is selected, make the background image invisible
            vwBackground.visible = false;
            tvTrainer.touchEnabled = true;
			tvTrainer.setData(data);
            laf.table.scrollToTop(tvTrainer, false);			
        }
        else {
            //user did not selected a club, show message
            vwBackground.visible = true;
            
            tvTrainer.touchEnabled = false;
            laf.table.hideEmptyRows(tvTrainer, false);
            
            var strSelectClub = 'No club has been selected.\n\nReturn to the previous screen\nand select a club.';
            var tvrNoClub = Ti.UI.createTableViewRow({
                height: 150
            });
            tvrNoClub.add(Ti.UI.createLabel({
                color: 'white',
                font: {
                    fontSize: 20,
                    fontFamily: 'Arial'
                },
                top: 10,
                left: 5,
                right: 5,
                height: 150,
                textAlign: 'center',
                text: strSelectClub
            }));
            
            data.push(tvrNoClub);
            tvTrainer.setData(data);
            laf.table.scrollToTop(tvTrainer, false);
        }
    }
    
    //=== EVENTS =============================
    tvTrainer.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.trainerName != undefined) {
            tvTrainer.touchEnabled = false;
            
            if (laf.device.isiPhone()) {
                for (var i = 0; i < tvTrainer.data[0].rows.length; i++) {                
                    tvTrainer.data[0].rows[i].hasCheck = (e.index == i);
                }
            }
            
            laf.window.fire('trainerSelected', {
                trainerName: e.rowData.trainerName,
                trainerDexRowID: e.rowData.trainerDexRowID
            });
            
            setTimeout(function(){
                win.close();
            }, (laf.device.isiPhone()) ? 700 : 0);
        }
    });
    
    btnCancel.addEventListener('click', function(e){
        win.close();
    });
    
    //=== DISPLAY =============================
    setTrainerRows();
    vwMain.add(vwBackground);
    vwMain.add(tvTrainer);
    setLeftNav(btnCancel);
	
	if (winData.selectedClubID >= 0) {
		setTimeout(loadTrainers, 300);
	}
})();
