function clubDetails(){
    //=== HEADER & DATA =============================	
    var club, amenities, leagues;
    var buttonsEnabled = true;
    var testStr = 'Add\nFavorite';
    var leagueNames = [];
    leagueNames.BB = 'Basketball';
    leagueNames.RB = 'Racquetball';
    leagueNames.SQ = 'Squash';
    leagueNames.VB = 'Volleyball';
    
    //=== OBJECTS =============================
    var vwActivity = new activityIndicator();
    
    var tvDetails = Ti.UI.createTableView({
        top: 48,
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1'
    });
    
    //=== FUNCTIONS =============================    
    function addClubToContacts(contact){
        if (contact != undefined) {
            Ti.Contacts.removePerson(contact);
			Ti.Contacts.save(); //Must save before creating new
        }
        contact = Ti.Contacts.createPerson();
        
        var address = {};
        address.Street = addressShorten(club.Address);
        address.City = club.City;
        address.State = club.State;
        address.ZIP = laf.verify.padZip(club.Zip);
        
        contact.organization = 'LA Fitness: ' + club.Description;
        
        contact.image = Ti.UI.createImageView({
            url: laf.path.images + 'mobileIcon512.png'
        }).toBlob();
        
        contact.address = {
            'home': [address]
        };
        contact.phone = {
            'main': [club.Phone.replace(/[^\d]/g, '')]
        };
        contact.URL = {
            'homepage': ['https://www.lafitness.com/Pages/clubhome.aspx?clubid=' + clubID + '&clubStatusID=1']
        };
        contact.kind = Ti.Contacts.CONTACTS_KIND_ORGANIZATION;
        Ti.Contacts.save();
        
        laf.window.alert('Contacts', 'LA Fitness: ' + club.Description + ' has been stored on your device\'s contact list.');
    }
    
    function buttonClick(sourceButton){
        if (buttonsEnabled) { //Prevent multiple clicks
            buttonsEnabled = false;
            sourceButton.backgroundColor = '#C5CCD4';
            
            setTimeout(function(){
                switch (sourceButton.name) {
                    case 'Share\nInfo':
                        var edClubInfo = Ti.UI.createEmailDialog();
                        edClubInfo.setSubject('LA Fitness: ' + club.Description);
                        edClubInfo.setMessageBody('LA Fitness: ' + club.Description + '\n' + club.Address + '\n' + club.City + ', ' + club.State + ' ' + laf.verify.padZip(club.Zip) + '\n' + club.Phone);
                        edClubInfo.open();
                        break;
                    case 'Add\nFavorite':
                    case 'Remove\nFavorite':
                        var favoriteClubs = Ti.App.Properties.getString('FavoriteClubs').split(',');
                        var isFavoriteClub = favoriteClubs.indexOf(clubID) >= 0;
                        if (isFavoriteClub) {
                            favoriteClubs.splice(favoriteClubs.indexOf(clubID), 1);
                        }
                        else {
                            favoriteClubs.push(clubID);
                        }
                        Ti.App.Properties.setString('FavoriteClubs', favoriteClubs.toString());
                        tvDetails.updateRow(0, newButtonRow(), {
                            animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                        });
                        break;
                    case 'Add to\nContacts':
                        //See if the club already exists in contacts
                        var people = Ti.Contacts.getPeopleWithName('LA Fitness: ' + club.Description);
                        if (people != undefined && people.length > 0) {
                            var adConfirmAdd = Ti.UI.createAlertDialog({
                                title: 'Already Exists',
                                message: 'This club\'s information is already in your contacts, would you like to update it?',
                                buttonNames: ['Yes', 'No']
                            });
                            adConfirmAdd.addEventListener('click', function(e){
                                if (e.index == 0) {
                                    addClubToContacts(people[0]);
                                }
                            });
                            adConfirmAdd.show();
                        }
                        else {
                            addClubToContacts();
                        }
                        break;
                }
                sourceButton.backgroundColor = 'white';
                buttonsEnabled = true;
            }, 600);
        }
    }
    
    function createButton(align, title, image){
        var btnView = Ti.UI.createView({
            height: 80,
            width: 90,
            top: 2,
            borderRadius: 10,
            name: title,
            align: align
        });
        if (align == 0) {
            btnView.left = 5;
        }
        if (align == 2) {
            btnView.right = 5;
        }
        btnView.add(Ti.UI.createView({
            backgroundImage: laf.path.images + image,
            height: 32,
            left: 28,
            width: 32,
            top: 8,
            borderRadius: 10
        }));
        btnView.add(Ti.UI.createLabel({
            color: '#777',
            font: {
                fontSize: 14,
                fontWeight: 'bold'
            },
            height: 40,
            left: 0,
            width: 90,
            top: 39,
            text: title,
            textAlign: 'center'
        }));
        btnView.addEventListener('click', function(e){
            buttonClick(btnView);
        });
        return btnView;
    }
    
    function newButtonRow(){
        var tvRow = Ti.UI.createTableViewRow({
            height: 90,
            className: laf.table.uniqueClass(),
            hasChild: false
        });
        laf.table.ignoreRowSelection(tvRow);
        
        var favoriteClubs = Ti.App.Properties.getString('FavoriteClubs').split(',');
        var isFavoriteClub = favoriteClubs.indexOf(clubID) >= 0;
        
        
        if (laf.device.isiPhone()) {
            tvRow.add(createButton(0, 'Share\nInfo', 'chat.png'));
            tvRow.add(createButton(2, 'Add to\nContacts', 'contact.png'));
            
            if (laf.auth.isAuthenticated(false)) {
                if (isFavoriteClub) {
                    tvRow.add(createButton(1, 'Remove\nFavorite', 'favoriteRemove.png'));
                }
                else {
                    tvRow.add(createButton(1, 'Add\nFavorite', 'favoriteAdd.png'));
                }
            }
        }
        else {
            if (laf.auth.isAuthenticated(false)) {
                tvRow.add(createButton(0, 'Share\nInfo', 'chat.png'));
                
                if (isFavoriteClub) {
                    tvRow.add(createButton(2, 'Remove\nFavorite', 'favoriteRemove.png'));
                }
                else {
                    tvRow.add(createButton(2, 'Add\nFavorite', 'favoriteAdd.png'));
                }
            }
            else {
                tvRow.add(createButton(1, 'Share\nInfo', 'chat.png'));
            }
        }
        
        return tvRow;
    }
    
    function loadDetails(clubID){
        club = laf.data.clubRow('SELECT CLUB_ID, DESCRIPTION, ADDRESS, CITY, STATE, ZIP, PHONE, LAT, LON FROM Club WHERE CLUB_ID = \'' + clubID + '\'', ['ClubID', 'Description', 'Address', 'City', 'State', 'Zip', 'Phone', 'Lat', 'Lon']);
        amenities = laf.data.clubSet('SELECT DISTINCT Amenity.Description FROM ClubAmenity INNER JOIN Amenity ON ClubAmenity.AmenityID = Amenity.AmenityID WHERE ClubAmenity.CLUB_ID = \'' + clubID + '\' ORDER BY Amenity.Description', ['Description']);
        leagues = laf.data.clubSet('SELECT DISTINCT League.SPORT FROM League WHERE LEAGUE.CLUB_ID = \'' + clubID + '\' ORDER BY League.SPORT', ['Sport']);
    }
    
    function addressShorten(strAddress){
        if (strAddress == undefined) {
            return '';
        }
        strAddress = strAddress.toUpperCase() + ' ';
        strAddress = strAddress.replace(' AVENUE ', ' AVE. ').replace(' BOULEVARD ', ' BLVD. ').replace(' BUILDING ', ' BLDG. ').replace(' CIRCLE ', ' CIR. ').replace(' COURT ', ' CRT. ').replace(' DRIVE ', ' DR. ').replace(' EAST ', ' E. ').replace(' FLOOR ', ' FL. ').replace(' FORT ', ' FT. ').replace(' FREEWAY ', ' FWY. ').replace(' JUNCTION ', ' JCT. ').replace(' LANE ', ' LN. ').replace(' NORTH ', ' N. ').replace(' NORTHEAST ', ' N.E. ').replace(' NORTHWEST ', ' N.W. ').replace(' PARKWAY ', ' PKWY. ').replace(' ROAD ', ' RD. ').replace(' SOUTH ', ' S. ').replace(' SOUTHEAST ', ' S.E. ').replace(' SOUTHWEST ', ' S.W. ').replace(' STREET ', ' ST. ').replace(' SUITE ', ' STE. ').replace(' TERRACE ', ' TER. ').replace(' TURNPIKE ', ' TPKE. ').replace(' WEST ', ' W. ');
        return laf.verify.trim(strAddress);
    };
    
    function setDetailRows(){
        var data = [];
        
        data.push(laf.table.section('Location'));
        data.push(newButtonRow());
        data.push(laf.table.actionRow(addressShorten(club.Address) + '\n' + club.City + ', ' + club.State, 'Address', 55, 'magnify.png'));
        data.push(laf.table.actionRow(club.Phone, 'Phone', 48, 'phone.png'));
        
        data.push(laf.table.section('Amenities'));
        if (amenities == undefined || amenities.length == 0) {
            data.push(laf.table.infoRow('No amenities at this location.'));
        }
        else {
            var amenitiesStr = '';
            for (var amenityItr = 0, amenityLen = amenities.length; amenityItr < amenityLen; amenityItr++) {
                amenitiesStr += ', ' + amenities[amenityItr].Description;
            }
            if (amenitiesStr.length > 2) {
                amenitiesStr = amenitiesStr.substring(2);
            }
            data.push(laf.table.infoRow(amenitiesStr));
        }
        
        data.push(laf.table.section('Leagues'));
        if (leagues == undefined || leagues.length == 0) {
            data.push(laf.table.infoRow('No leagues at this location.'));
        }
        else {
            var leaguesStr = '';
            for (var leaguesItr = 0, leaguesLen = leagues.length; leaguesItr < leaguesLen; leaguesItr++) {
                leaguesStr += ', ' + (leagueNames[leagues[leaguesItr].Sport] || 'League');
            }
            if (leaguesStr.length > 2) {
                leaguesStr = leaguesStr.substring(2);
            }
            data.push(laf.table.infoRow(leaguesStr));
        }
        
        tvDetails.setData(data);
    }
    
    //=== EVENTS =============================
    tvDetails.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.rowType != undefined) {
            switch (e.rowData.rowType) {
                case 'Phone':
                    laf.network.openURL('tel:1-' + club.Phone, 'LA FITNESS\n' + club.Description);
                    break;
                case 'Address':
                    if (laf.network.isConnected(true)) {
                        laf.window.create('Map', '/views/search/clubMap.js', {
                            lat: club.Lat,
                            lon: club.Lon,
                            description: club.Description,
                            address: club.Address,
                            city: club.City,
                            state: club.State,
                            zip: club.Zip
                        });
                        laf.window.open();
                    }
                    break;
            }
        }
    });
    
    //=== DISPLAY =============================
    this.hide = function(){
        tvDetails.visible = false;
    };
    
    this.refresh = function(){
        if (club == undefined || amenities == undefined || leagues == undefined) {
            vwActivity.show('Loading...');
            loadDetails(clubID);
            setDetailRows();
            vwActivity.hide();
        }
    };
    
    this.show = function(){
        tvDetails.visible = true;
    };
    
    this.view = function(){
        return tvDetails;
    };
};
