//=== HEADER & DATA =============================
Ti.include('../../common/winHeader.js');

var clubLat = win.winData.lat;
var clubLon = win.winData.lon;
var description = win.winData.description;
var address = win.winData.address;
var city = win.winData.city;
var state = win.winData.state;
var zip = win.winData.zip;

//=== OBJECTS =============================
var clubLocation = [];

var locationParams = {
    latitude: clubLat,
    longitude: clubLon,
    title: description,
    subtitle: address,
    animate: true
};

if (laf.device.isiPhone()) {
    locationParams.pinColor = Ti.Map.ANNOTATION_RED;
}
else {
    locationParams.pinImage = laf.path.images + 'pin.png';
}

clubLocation.push(Ti.Map.createAnnotation(locationParams));

var vwMap = Ti.Map.createView({
    mapType: Ti.Map.STANDARD_TYPE,
    region: {
        latitude: clubLat,
        longitude: clubLon,
        latitudeDelta: 0.05,
        longitudeDelta: 0.05
    },
    animate: true,
    regionFit: true,
    userLocation: true,
    annotations: clubLocation
});

var btnDirections = Ti.UI.createButton({
    title: 'Directions'
});

//=== FUNCTIONS =============================
function tabChange(tabIndex){
    switch (tabIndex) {
        case 0:
            vwMap.mapType = Ti.Map.STANDARD_TYPE;
            break;
        case 1:
            vwMap.mapType = (laf.device.isiPhone()) ? Ti.Map.HYBRID_TYPE : Ti.Map.SATELLITE_TYPE;
            break;
        case 2:
            vwMap.mapType = Ti.Map.SATELLITE_TYPE;
            break;
    }
};

//=== EVENTS =============================
btnDirections.addEventListener('click', function(){
    var vwActivity = new activityIndicator();
    vwActivity.show('Locating...');
    
    laf.location.gps(function(lat, lon, location){
        vwActivity.hide();
        
        var mapUrl = 'http://maps.google.com/maps?';
        if (lat != undefined && lon != undefined && lat != 0 && lon != 0) {
            mapUrl += 'saddr=' + lat + ',' + lon + '&';
        }
        
        var daddr = address + ', ' + city + ' ' + state + ' ' + laf.verify.padZip(zip);
        mapUrl += 'daddr=' + daddr.replace(' ', '+');
        
        laf.network.openURL(mapUrl);
    }, (laf.device.isAndroid()) ? Ti.Android.currentActivity : undefined);
});

win.addEventListener('close', function(e){
    vwMap.userLocation = false; //Turn off GPS
});

win.addEventListener('focus', function(e){
    vwMap.userLocation = true; //Ensure GPS is on
});

win.addEventListener('blur', function(e){
    vwMap.userLocation = false; //Turn off GPS
});

laf.window.listen('resume', function(e){
    vwMap.userLocation = true; //Ensure GPS is on
});

laf.window.listen('pause', function(e){
    vwMap.userLocation = false; //Turn off GPS
});

//=== DISPLAY =============================
if (!laf.device.isAndroid()) {
    laf.location.gps(); //User may start maps app, get best position for starting location
}
vwMain.add(vwMap);
setRightNav(btnDirections);

//Android Hybrid view doesn't really seem to be working
if (laf.device.isiPhone()) {
    laf.window.footerTabs(['Map', 'Hybrid', 'Satellite'], tabChange, 0);
}
else {
    laf.window.footerTabs(['Map', 'Satellite'], tabChange, 0);
}
vwMap.selectAnnotation(vwMap.annotations[0].title, true);
