function history(){
    //=== HEADER & DATA =============================   
    
    //=== OBJECTS ===================================
    var vwHistory = Ti.UI.createView({
        top: 0,
        bottom: 0
    });
    
    var vwBackground = Ti.UI.createView({
        backgroundImage: laf.path.images + 'background.png',
        left: 0,
        right: 0,
        top: 0,
        bottom: 0,
        opacity: 0.85,
        visible: false
    });
    vwHistory.add(vwBackground);
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996',
        visible: false
    });
    vwHeader.add(Ti.UI.createView({
        backgroundImage: laf.path.images + 'calendar.png',
        left: 5,
        width: 29,
        height: 29
    }));
    var btnRemoveFilter = Ti.UI.createView({
        backgroundImage: laf.path.images + 'x.png',
        right: 5,
        width: 29,
        height: 29
    });
    vwHeader.add(btnRemoveFilter);
    var lblHeaderText = Ti.UI.createLabel({
        color: '#FFFFFF',
        font: {
            fontSize: 18,
            fontWeight: 'bold',
            fontFamily: 'Arial'
        },
        left: 45,
        height: 'auto',
        width: 'auto',
        text: ''
    });
    vwHeader.add(lblHeaderText);
    vwHistory.add(vwHeader);
    
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'transparent',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1'
    });
    vwHistory.add(tvHistory);
    
    function newWorkoutDateRow(date){
        var tvRow = Ti.UI.createTableViewRow({
            height: 48,
            className: 'WorkoutDate',
            hasChild: true,
            rowType: 'WorkoutDate',
            date: laf.dateTime.toDateString(date),
            borderWidth: 3
        });
        
        tvRow.add(Ti.UI.createLabel({
            color: 'Black',
            font: {
                fontSize: 16,
                fontFamily: 'Arial'
            },
            left: 10,
            right: laf.table.leftDataRightMargin,
            height: 48,
            textAlign: 'left',
            text: date
        }));
        
        laf.table.makeRowSelectable(tvRow);
        return tvRow;
    }
    
    //=== FUNCTIONS =================================
    function getWorkoutDays(numDays){
        if (numDays > 0) {
            var minDate = new Date(laf.dateTime.toDateString());
            minDate.setDate(minDate.getDate() - numDays);
            minDate = laf.dateTime.toString(minDate, 'unspecified');
            
            return laf.data.workoutSet('SELECT DISTINCT strftime("%Y-%m-%d", LogDate) AS LogDate FROM WorkoutHistory WHERE Inactive = "0" AND LogDate >= "' + minDate + '" ORDER BY LogDate DESC', ['LogDate']);
        }
        else {
            return laf.data.workoutSet('SELECT DISTINCT strftime("%Y-%m-%d", LogDate) AS LogDate FROM WorkoutHistory WHERE Inactive = "0" ORDER BY LogDate DESC', ['LogDate']);
        }
    }
    
    function getWorkoutByDate(workoutDate){
        var maxDate = new Date();
        var minDate = new Date(workoutDate);
        maxDate.setDate(minDate.getDate() + 1);
        minDate = laf.dateTime.toString(minDate, 'unspecified');
        maxDate = laf.dateTime.toString(maxDate, 'unspecified');
        
        return laf.data.workoutSet('SELECT GUID, LogDate, ExerciseID, Calories, Distance, Duration, Reps, Weight FROM WorkoutHistory WHERE Inactive = "0" AND LogDate >= "' + minDate + '" AND LogDate < "' + maxDate + '" ORDER BY LogDate DESC', ['GUID', 'LogDate', 'ExerciseID', 'Calories', 'Distance', 'Duration', 'Reps', 'Weight']);
    }
    
    function getExerciseByID(exerciseID){
        return laf.data.exerciseRow('SELECT Name, LogTypeID FROM Exercise WHERE ExerciseID = "' + exerciseID + '"', ['Name', 'LogTypeID']);
    }
    
    function setHeader(text){
        if (text == undefined || text == '') {
            tvHistory.top = 0;
            vwHeader.visible = false;
        }
        else {
            lblHeaderText.text = text;
            vwHeader.visible = true;
            tvHistory.top = 48;
        }
    }
    
    function setHistoryRows(){
        var data = [];
        
        vwBackground.visible = false;
        tvHistory.touchEnabled = true;
        laf.table.showEmptyRows(tvHistory, false);
        
        setHeader('');
        data.push(laf.table.section('History'));
        data.push(laf.table.actionRow('Today', 'Today', 48, 'calendar.png'));
        data.push(laf.table.actionRow('Past Workout', 'Past', 48, 'calendar.png'));
        data.push(laf.table.actionRow('Past 7 Days', 'Past7', 48, 'calendar.png'));
        data.push(laf.table.actionRow('Past 14 Days', 'Past14', 48, 'calendar.png'));
        data.push(laf.table.actionRow('Past 30 Days', 'Past30', 48, 'calendar.png'));
        data.push(laf.table.actionRow('Complete History', 'Complete', 48, 'calendar.png'));
        
        tvHistory.setData(data);
        laf.table.scrollToTop(tvHistory, false);
    }
    
    function noHistoryRows(data){
        vwBackground.visible = true;
        tvHistory.touchEnabled = false;
		btnRemoveFilter.enabled = true;
        laf.table.hideEmptyRows(tvHistory, false);
        
        var tvrNoPastDays = Ti.UI.createTableViewRow({
            height: 145,
            className: 'NoHistory'
        });
        tvrNoPastDays.add(Ti.UI.createLabel({
            color: 'white',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            top: 25,
            left: 5,
            right: 5,
            height: 100,
            textAlign: 'center',
            text: 'You have no history for this period.\nClick the X on the right to change.'
        }));
        data.push(tvrNoPastDays);
    }
    
    function setPastDayRows(numOfDays){
        var data = [];
        var days = getWorkoutDays(numOfDays);
        
        setHeader((numOfDays > 0) ? 'Past ' + numOfDays + ' Days' : 'Complete History');
        data.push(laf.table.section());
        if (days == undefined || days.length == 0) {
            noHistoryRows(data);
        }
        else {
            vwBackground.visible = false;
            tvHistory.touchEnabled = true;
            laf.table.showEmptyRows(tvHistory, false);
            
            for (var dayItr = 0, dayLen = days.length; dayItr < dayLen; dayItr++) {
                data.push(newWorkoutDateRow(days[dayItr].LogDate));
            }
        }
        
        tvHistory.setData(data);
        laf.table.scrollToTop(tvHistory, false);
    }
    
    function setWorkoutRows(workoutDate){
        var data = [];
        var workout = getWorkoutByDate(workoutDate);
        
        setHeader(workoutDate.replace(/\//g, '-'));
        if (workout == undefined || workout.length == 0) {
            noHistoryRows(data);
        }
        else {
            vwBackground.visible = false;
            tvHistory.touchEnabled = true;
            laf.table.showEmptyRows(tvHistory, false);
            
            var currExerciseID = -1;
            for (var workoutItr = 0, workoutLen = workout.length; workoutItr < workoutLen; workoutItr++) {
                var currWorkout = workout[workoutItr];
                
                if (currExerciseID != currWorkout.ExerciseID) {
                    var currExercise = getExerciseByID(currWorkout.ExerciseID);
                    data.push(laf.table.section(currExercise.Name));
                    currExerciseID = currWorkout.ExerciseID;
                }
                
                data.push(laf.table.actionRow(JSON.stringify(currWorkout), '', 48, 'calendar.png', false));
            }
        }
        
        tvHistory.setData(data);
        laf.table.scrollToTop(tvHistory, false);
    }
    
    //=== EVENTS ====================================    
    tvHistory.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.rowType != undefined) {
            switch (e.rowData.rowType) {
                case 'Today':
                    setWorkoutRows(laf.dateTime.toDateString());
                    break;
                case 'Past':
                    setWorkoutRows(laf.dateTime.toDateString(laf.data.workoutScalar('SELECT strftime("%Y-%m-%d", LogDate) AS LogDate FROM WorkoutHistory ORDER BY LogDate DESC LIMIT 1')));
                    break;
                case 'Past7':
                    setPastDayRows(7);
                    break;
                case 'Past14':
                    setPastDayRows(14);
                    break;
                case 'Past30':
                    setPastDayRows(30);
                    break;
                case 'Complete':
                    setPastDayRows(-1);
                    break;
                case 'WorkoutDate':
                    setWorkoutRows(e.rowData.date);
                    break;
            }
        }
    });
    
    btnRemoveFilter.addEventListener('click', setHistoryRows);
    
    //=== DISPLAY ===================================
    this.hide = function(){
        vwHistory.visible = false;
    };
    
    this.show = function(){
        vwHistory.visible = true;
    };
    
    this.view = function(){
        return vwHistory;
    };
    
    this.refresh = function(){
        setHistoryRows();
    };
};
