function progress(){
    //=== HEADER & DATA =============================    
    Ti.include('../../common/utilPicker.js');
    
    //=== OBJECTS ===================================
    var vwActivity = new activityIndicator();
    
    var btnPhotos = Ti.UI.createButton({
        title: 'Photos'
    });
    
    if (laf.device.isiPhone()) {
        btnPhotos.systemButton = Ti.UI.iPhone.SystemButton.CAMERA;
    }
    
    var tvProgress = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1'
    });
    
    function newInfoRow(rowType, description, detailLabel){
        var tvRow = Titanium.UI.createTableViewRow({
            hasChild: true,
            rowType: rowType,
            className: 'trackProgressInfoRow'
        });
        tvRow.add(Titanium.UI.createLabel({
            color: 'black',
            text: description,
            font: {
                fontSize: 16,
                fontFamily: 'Arial'
            },
            textAlign: 'left',
            right: laf.table.leftDataRightMargin,
            left: 10
        }));
        tvRow.add(detailLabel);
        laf.table.makeRowSelectable(tvRow);
        return tvRow;
    }
    
    function newDetailLabel(){
        return Ti.UI.createLabel({
            color: '#576996',
            font: {
                fontSize: 16,
                fontFamily: 'Arial'
            },
            height: 20,
            textAlign: 'right',
            right: laf.table.detailsRight,
            text: '----'
        });
    }
    
    var lblWeight = newDetailLabel();
    var lblBodyFat = newDetailLabel();
    var lblBMI = newDetailLabel();
    var lblRMR = newDetailLabel();
    var lblTHR = newDetailLabel();
    
    var lblBiceps = newDetailLabel();
    var lblCalves = newDetailLabel();
    var lblChest = newDetailLabel();
    var lblHips = newDetailLabel();
    var lblNeck = newDetailLabel();
    var lblThighs = newDetailLabel();
    var lblWaist = newDetailLabel();
    
    var lblAge = newDetailLabel();
    var lblHeight = newDetailLabel();
    var lblGender = newDetailLabel();
    
    //=== FUNCTIONS =================================    
    function setProgressRows(){
        var data = [];
        
        data.push(laf.table.section('Vitals'));
        data.push(newInfoRow('Weight', 'Weight', lblWeight));
        data.push(newInfoRow('BodyFat', 'Body Fat', lblBodyFat));
        data.push(newInfoRow('BMI', 'BMI', lblBMI));
        data.push(newInfoRow('RMR', 'RMR', lblRMR));
        data.push(newInfoRow('THR', 'THR', lblTHR));
        
        data.push(laf.table.section('Measurements'));
        data.push(newInfoRow('Neck', 'Neck', lblNeck));
        data.push(newInfoRow('Chest', 'Chest', lblChest));
        data.push(newInfoRow('Biceps', 'Biceps', lblBiceps));
        data.push(newInfoRow('Waist', 'Waist', lblWaist));
        data.push(newInfoRow('Hips', 'Hips', lblHips));
        data.push(newInfoRow('Thighs', 'Thighs', lblThighs));
        data.push(newInfoRow('Calves', 'Calves', lblCalves));
        
        data.push(laf.table.section('Demographics'));
        data.push(newInfoRow('Age', 'Age', lblAge));
        data.push(newInfoRow('Height', 'Height', lblHeight));
        data.push(newInfoRow('Gender', 'Gender', lblGender));
        
        tvProgress.setData(data);
    }
    
    //Items that a change to effect other values
    function refreshStats(){
        var currWeight = 0;
        var currAge = 0;
        var currHeight = 0;
        var currGender = '';
        
        var currentValue = laf.data.workoutScalar('SELECT Weight FROM WeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            currWeight = parseInt(currentValue, 10);
            lblWeight.text = currentValue + ' lbs';
        }
        else {
            lblWeight.text = '----';
        }
        
        currentValue = laf.data.workoutScalar('SELECT Age FROM AgeOnDate WHERE OnDate = "' + laf.dateTime.toDateString() + '" ');
        if (!laf.verify.isEmpty(currentValue)) {
            currAge = parseInt(currentValue, 10);
            lblAge.text = currentValue;
            var maxHeartRate = 191.5 - (0.007 * currAge * currAge);
            lblTHR.text = parseInt(maxHeartRate * 0.7, 10) + '-' + parseInt(maxHeartRate * 0.8, 10) + ' BPM';
        }
        else {
            lblAge.text = '----';
            lblTHR.text = '----';
        }
        
        currentValue = laf.data.workoutScalar('SELECT Height FROM HeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            currHeight = parseInt(currentValue, 10);
            lblHeight.text = parseInt(currHeight / 12, 10) + '\' ';
            lblHeight.text += parseInt(currHeight % 12, 10) + '"';
        }
        else {
            lblHeight.text = '----';
        }
        
        currentValue = laf.data.workoutScalar('SELECT Gender FROM BasicStats WHERE Inactive = 0 ORDER BY UpdateUTC DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            currGender = currentValue;
            lblGender.text = (currentValue == 'F') ? 'Female' : 'Male';
        }
        else {
            lblGender.text = '----';
        }
        
		//Since we have all the values it is quicker to calculate than hit the BMIOnDate, RMROnDate tables
        if (currWeight > 0 && currHeight > 0) {
            lblBMI.text = ((currWeight * 703.0) / (currHeight * currHeight)).toFixed(2);

            if (currAge > 0 && !laf.verify.isEmpty(currGender)) {
                var RMR = (10 * (currWeight / 2.2) + (6.25 * (currHeight * 2.54)) - (5 * currAge));
                RMR = (currGender == 'F') ? RMR - 161 : RMR + 5;
                lblRMR.text = RMR.toFixed(0) + ' Cal';
            }
            else {
                lblRMR.text = '----';
            }
        }
        else {
            lblBMI.text = '----';
            lblRMR.text = '----';
        }
    }
    
    //Items that a change to do not effect other values
    function refreshMeasurements(){
        var currentValue = laf.data.workoutScalar('SELECT BodyFat FROM BodyFatHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            lblBodyFat.text = currentValue + '%';
        }
        
        currentValue = laf.data.workoutScalar('SELECT Neck FROM NeckHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            lblNeck.text = currentValue + '"';
        }
        
        currentValue = laf.data.workoutScalar('SELECT Chest FROM ChestHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            lblChest.text = currentValue + '"';
        }
        
        var currentResult = laf.data.workoutRow('SELECT LeftBiceps, RightBiceps FROM BicepsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentResult.LeftBiceps) && currentResult.LeftBiceps > 0 && !laf.verify.isEmpty(currentResult.RightBiceps) && currentResult.RightBiceps > 0) {
            lblBiceps.text = currentResult.LeftBiceps + '" L   ' + currentResult.RightBiceps + '" R';
        }
        
        currentValue = laf.data.workoutScalar('SELECT Waist FROM WaistHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            lblWaist.text = currentValue + '"';
        }
        
        currentValue = laf.data.workoutScalar('SELECT Hips FROM HipsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            lblHips.text = currentValue + '"';
        }
        
        currentResult = laf.data.workoutRow('SELECT LeftThighs, RightThighs FROM ThighsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentResult.LeftThighs) && currentResult.LeftThighs > 0 && !laf.verify.isEmpty(currentResult.RightThighs) && currentResult.RightThighs > 0) {
            lblThighs.text = currentResult.LeftThighs + '" L   ' + currentResult.RightThighs + '" R';
        }
        
        currentResult = laf.data.workoutRow('SELECT LeftCalfs, RightCalfs FROM CalvesHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentResult.LeftCalfs) && currentResult.LeftCalfs > 0 && !laf.verify.isEmpty(currentResult.RightCalfs) && currentResult.RightCalfs > 0) {
            lblCalves.text = currentResult.LeftCalfs + '" L   ' + currentResult.RightCalfs + '" R';
        }
    }
    
    function updateStatsHistory(sqlQuery, fieldTable, fieldNames, fieldValues){
        laf.data.workoutMakeSync(fieldTable, laf.data.workoutScalar(sqlQuery), false, fieldNames, fieldValues);
    }
    
    //=== EVENTS ====================================		
    tvProgress.addEventListener('click', function(e){
        if (e.rowData.rowType) {
            switch (e.rowData.rowType) {
                case 'Age':
                    var defaultDate = laf.data.workoutScalar('SELECT Birthday FROM BasicStats WHERE Inactive = 0 ORDER BY UpdateUTC DESC LIMIT 1');
                    defaultDate = (defaultDate == undefined || defaultDate == null) ? new Date() : new Date(laf.dateTime.toDateString(defaultDate));
                    
                    datePicker('Select your birthday:', 'Select Birthday', undefined, undefined, defaultDate, function(selectedDate){
                        if (selectedDate != undefined) {
                            if (selectedDate > new Date()) {
                                laf.window.alert('Birthday in Future', 'Error: You cannot have been born in the future.');
                            }
                            else {
                                updateStatsHistory('SELECT GUID FROM BasicStats WHERE Inactive = 0', 'BasicStats', ['Birthday'], [laf.dateTime.toDateString(selectedDate, '-')]);
                                refreshStats();
                            }
                        }
                    });
                    break;
                case 'Biceps':
                    laf.window.create('Biceps', '/views/track/progressBiceps.js');
                    laf.window.open();
                    break;
                case 'BMI':
                    laf.window.create('BMI', '/views/track/progressBMI.js', {
                        BMI: lblBMI.text
                    });
                    laf.window.open();
                    break;
                case 'BodyFat':
                    laf.window.create('Body Fat', '/views/track/progressBodyFat.js');
                    laf.window.open();
                    break;
                case 'Calves':
                    laf.window.create('Calves', '/views/track/progressCalf.js');
                    laf.window.open();
                    break;
                case 'Chest':
                    laf.window.create('Chest', '/views/track/progressChest.js');
                    laf.window.open();
                    break;
                case 'Gender':
                    var tkGender = laf.data.workoutScalar('SELECT Gender FROM BasicStats WHERE Inactive = 0 ORDER BY UpdateUTC DESC LIMIT 1');
                    tkGender = (tkGender != undefined && tkGender == 'F') ? 'Female' : 'Male';
                    
                    if (laf.device.isiPhone()) {
                        standardPicker('Select your gender:', 'Select Gender', ['Male,Female'], [tkGender], function(selectedValues){
                            if (selectedValues != undefined && selectedValues.length > 0 && selectedValues[0].length > 0) {
                                updateStatsHistory('SELECT GUID FROM BasicStats WHERE Inactive = 0 ORDER BY UpdateUTC DESC LIMIT 1', 'BasicStats', ['Gender'], [selectedValues[0].substring(0, 1)]);
                                refreshStats();
                            }
                        });
                    }
                    else {
                        standardPickerForAndroid('Select your gender:', 'Select Gender', ['Male', 'Female'], undefined, undefined, [tkGender], function(selectedValues){
                            if (selectedValues != undefined && selectedValues.length > 0) {
                                updateStatsHistory('SELECT GUID FROM BasicStats WHERE Inactive = 0 ORDER BY UpdateUTC DESC LIMIT 1', 'BasicStats', ['Gender'], [selectedValues.substring(0, 1)]);
                                refreshStats();
                            }
                        });
                    }
                    break;
                case 'Height':
                    laf.window.create('Height', '/views/track/progressHeight.js');
                    laf.window.open();
                    break;
                case 'Hips':
                    laf.window.create('Hips', '/views/track/progressHips.js');
                    laf.window.open();
                    break;
                case 'Neck':
                    laf.window.create('Neck', '/views/track/progressNeck.js');
                    laf.window.open();
                    break;
                case 'RMR':
                    laf.window.create('RMR', '/views/track/progressRMR.js', {
                        RMR: lblRMR.text
                    });
                    laf.window.open();
                    break;
                case 'Thighs':
                    laf.window.create('Thighs', '/views/track/progressThighs.js');
                    laf.window.open();
                    break;
                case 'THR':
                    laf.window.create('THR', '/views/track/progressTHR.js', {
                        Age: lblAge.text
                    });
                    laf.window.open();
                    break;
                case 'Waist':
                    laf.window.create('Waist', '/views/track/progressWaist.js');
                    laf.window.open();
                    break;
                case 'Weight':
                    laf.window.create('Weight', '/views/track/progressWeight.js');
                    laf.window.open();
                    break;
            }
        }
    });
    
    laf.window.listen('statsChange', function(e){
        refreshStats();
    });
    
    laf.window.listen('measurementsChange', function(e){
        refreshMeasurements();
    });
    
    btnPhotos.addEventListener('click', function(){
        laf.window.create('Progress Photos', '/views/track/progressPhotos.js');
        laf.window.open();
    });
    
    //=== DISPLAY ===================================	
    this.hide = function(){
        tvProgress.visible = false;
        setRightNav(null);
    };
    
    this.show = function(){
        tvProgress.visible = true;
        setRightNav(btnPhotos);
    };
    
    this.view = function(){
        return tvProgress;
    };
    
    this.refresh = function(){
        vwActivity.show('Loading...');
        setProgressRows();
        refreshMeasurements();
        vwActivity.hide();
        
        //Do not hold up loading for data
        //Refresh when available
        setTimeout(function(){
            refreshStats();
        }, 50);
    };
};
