(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    var history = [];
    var guid;
    
    //=== OBJECTS =============================			
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    function newLabel(text){
        return Titanium.UI.createLabel({
            color: '#FFFFFF',
            font: {
                fontSize: 16,
                fontWeight: 'bold',
                fontFamily: 'Arial'
            },
            text: text,
            height: 'auto',
            width: 'auto'
        });
    }
    
    function newTextField(hintText){
        return Titanium.UI.createTextField({
            color: '#336699',
            height: (Titanium.Platform.name == 'iPhone OS') ? 35 : 40,
            width: 80,
            autocorrect: false,
            borderStyle: Titanium.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Titanium.UI.INPUT_BUTTONMODE_ONFOCUS,
            hintText: hintText,
            keyboardType: Titanium.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Titanium.UI.RETURNKEY_DONE
        });
    }
    
    var lblLeftBiceps = newLabel('Left:');
    lblLeftBiceps.left = 5;
    vwHeader.add(lblLeftBiceps);
    
    var tfLeftBiceps = newTextField('Bicep');
    tfLeftBiceps.left = 41;
    vwHeader.add(tfLeftBiceps);
    
    var lblRightBiceps = newLabel('Right:');
    lblRightBiceps.right = 85;
    vwHeader.add(lblRightBiceps);
    
    var tfRightBiceps = newTextField('Bicep');
    tfRightBiceps.right = 5;
    vwHeader.add(tfRightBiceps);
    
    var btnGraph = Ti.UI.createButton({        
		title: 'Graph'
    });
    
    if (laf.device.isiPhone()) {
        btnGraph.style = Ti.UI.iPhone.SystemButtonStyle.BORDERED;
		btnGraph.image = laf.path.images + 'graph.png';
    }
    setRightNav(btnGraph);
    
    //=== FUNCTIONS =============================
    function newHistoryRow(date, leftBiceps, rightBiceps, guid){
        var tvrRow = Ti.UI.createTableViewRow({
            height: 35,
            className: 'trackProgressBicepsHistoryRow',
            rowType: 'historyRow',
            guid: (guid != undefined) ? guid : undefined
        });
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            text: date.replace(/\//g, '-'),
            textAlign: 'left'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: parseFloat(leftBiceps).toFixed(1) + '" L',
            textAlign: 'center'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: parseFloat(rightBiceps).toFixed(1) + '" R',
            textAlign: 'right'
        }));
        
        return tvrRow;
    }
    
    function setHistoryRows(){
        var data = [];
        data.push(laf.table.section('Biceps History'));
        
        history = laf.data.workoutSet('SELECT LeftBiceps, RightBiceps, StatsDate, GUID FROM BicepsHistory WHERE LeftBiceps IS NOT NULL AND RightBiceps IS NOT NULL AND StatsDate IS NOT NULL AND GUID IS NOT NULL AND Inactive = 0 ORDER BY StatsDate DESC', ['LeftBiceps', 'RightBiceps', 'StatsDate', 'GUID']);
        if (history != undefined && history.length > 0) {
            for (var historyItr = 0, historyLen = history.length; historyItr < historyLen; historyItr++) {
                data.push(newHistoryRow(history[historyItr].StatsDate, history[historyItr].LeftBiceps, history[historyItr].RightBiceps, history[historyItr].GUID));
            }
        }
        else {
            laf.window.alert('How To', 'Measure midway between the top of your shoulder and elbow.');
        }
        
        tvHistory.setData(data);
    }
    
    function refreshStats(){
        var result = laf.data.workoutRow('SELECT LeftBiceps, RightBiceps FROM BicepsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        
        if (result.LeftBiceps != undefined && !laf.verify.isEmpty(result.LeftBiceps) && result.RightBiceps != undefined && !laf.verify.isEmpty(result.RightBiceps)) {
            tfLeftBiceps.value = result.LeftBiceps.toString();
            tfRightBiceps.value = result.RightBiceps.toString();
        }
        
        setHistoryRows();
    }
    
    function saveStats(){
        tfLeftBiceps.value = laf.verify.trim(tfLeftBiceps.value);
        tfRightBiceps.value = laf.verify.trim(tfRightBiceps.value);
        
        if (!laf.verify.isNumeric(tfLeftBiceps.value) && !laf.verify.isEmpty(tfLeftBiceps)) {
            laf.window.alert('Invalid', 'Please enter a numeric value for your left bicep.');
            tfLeftBiceps.focus();
            return;
        }
        
        if (!laf.verify.isNumeric(tfRightBiceps.value) && !laf.verify.isEmpty(tfRightBiceps)) {
            laf.window.alert('Invalid', 'Please enter a numeric value for your right bicep.');
            tfRightBiceps.focus();
            return;
        }
        
        tfLeftBiceps.value = (tfLeftBiceps.value.toString().length > 0) ? parseFloat(tfLeftBiceps.value).toString() : (tfRightBiceps.value.toString().length > 0) ? parseFloat(tfRightBiceps.value).toString() : 0;
        tfRightBiceps.value = (tfRightBiceps.value.toString().length > 0) ? parseFloat(tfRightBiceps.value).toString() : (tfLeftBiceps.value.toString().length > 0) ? parseFloat(tfLeftBiceps.value).toString() : 0;
        
        updateStatsHistory();
        laf.window.fire('measurementsChange');
        
        if (history.length == 0 || history[0].StatsDate != laf.dateTime.toDateString()) {
            guid = laf.data.workoutScalar('SELECT GUID FROM BicepsHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
            if (guid == undefined) {
                guid = laf.object.newGUID();
            }
            
            if (history.length == 0) {
                tvHistory.appendRow(newHistoryRow(laf.dateTime.toDateString(), tfLeftBiceps.value, tfRightBiceps.value, guid));
            }
            else {
                tvHistory.insertRowBefore(0, newHistoryRow(laf.dateTime.toDateString(), tfLeftBiceps.value, tfRightBiceps.value, guid));
            }
            
            history.splice(0, 0, {
                LeftBiceps: tfLeftBiceps.value,
                RightBiceps: tfRightBiceps.value,
                StatsDate: laf.dateTime.toDateString(),
                GUID: guid
            });
        }
        else {
            if (history.length > 0) {
                history[0].LeftBiceps = tfLeftBiceps.value;
                history[0].RightBiceps = tfRightBiceps.value;
            }
            
            if (laf.device.isiPhone()) {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].LeftBiceps, history[0].RightBiceps, history[0].GUID), {
                    animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                });
            }
            else {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].LeftBiceps, history[0].RightBiceps, history[0].GUID));
            }
        }
    }
    
    function updateStatsHistory(){
        guid = laf.data.workoutScalar('SELECT GUID FROM BicepsHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
        if (guid == undefined) {
            guid = laf.object.newGUID();
        }
        laf.data.workoutMakeSync('BicepsHistory', guid, false, ['StatsDate', 'LeftBiceps', 'RightBiceps'], [laf.dateTime.toDateString(), tfLeftBiceps.value, tfRightBiceps.value]);
    }
    //=== EVENTS =============================
    btnGraph.addEventListener('click', function(e){        
		laf.window.create('Biceps', '/views/track/progressBicepsGraph.js');
        laf.window.open();
    });
    
    tfLeftBiceps.addEventListener('return', function(e){
        saveStats();
        tfLeftBiceps.blur();
    });
    
    tfRightBiceps.addEventListener('return', function(e){
        saveStats();
        tfRightBiceps.blur();
    });
    
    tvHistory.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.guid != undefined) {
            var dlgProgressOptions;
            
            if (laf.device.isAndroid()) {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share'],
                    title: 'Options',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share', 'Cancel'],
                    destructive: 0,
                    cancel: 2
                });
            }
            
            dlgProgressOptions.addEventListener('click', function(data){
                if (data.index == 0 && (!laf.device.isAndroid() || !data.button)) {
                    if (history.length == 1) {
                        laf.window.alert('Must keep at least one entry.');
                        return;
                    }
                    
                    laf.window.alert('Delete Record', 'Are you sure you want to delete?', ['Delete', 'Cancel'], function(msg){
                        if (msg.index == 0) {
                            laf.data.workoutMakeSync('BicepsHistory', e.rowData.guid, true);
                            if (e.index == 0) {
                                history.splice(0, 1);
                                tvHistory.deleteRow(0);
                                var result = laf.data.workoutRow('SELECT LeftBiceps, RightBiceps FROM BicepsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
                                
                                if (result.LeftBiceps != undefined && !laf.verify.isEmpty(result.LeftBiceps) && result.RightBiceps != undefined && !laf.verify.isEmpty(result.RightBiceps)) {
                                    tfLeftBiceps.value = result.LeftBiceps.toString();
                                    tfRightBiceps.value = result.RightBiceps.toString();
                                }
                                
                                laf.window.fire('measurementsChange');
                            }
                            else {
                                history.splice(e.index, 1);
                                tvHistory.deleteRow(e.index);
                                
                                if (laf.device.isiPhone()) {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].LeftBiceps, history[e.index - 1].RightBiceps, history[e.index - 1].GUID), {
                                        animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                    });
                                }
                                else {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].LeftBiceps, history[e.index - 1].RightBiceps, history[e.index - 1].GUID));
                                }
                            }
                        }
                    });
                }
            });
            
            tfLeftBiceps.blur();
            tfRightBiceps.blur();
            dlgProgressOptions.show();
        }
    });
    
    //=== DISPLAY =============================
    refreshStats();
    vwMain.add(tvHistory);
    vwMain.add(vwHeader);
})();
