(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    Ti.include('../../common/utilPicker.js');
    
    var history = [];
    var currentValue;
    var guid;
    
    //=== OBJECTS =============================			
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    function newLabel(text){
        return Titanium.UI.createLabel({
            color: '#FFFFFF',
            font: {
                fontSize: 16,
                fontWeight: 'bold',
                fontFamily: 'Arial'
            },
            text: text,
            height: 'auto',
            width: 'auto'
        });
    }
    
    function newTextField(hintText){
        return Titanium.UI.createTextField({
            color: '#336699',
            height: (Titanium.Platform.name == 'iPhone OS') ? 35 : 40,
            width: 80,
            autocorrect: false,
            borderStyle: Titanium.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Titanium.UI.INPUT_BUTTONMODE_ONFOCUS,
            hintText: hintText,
            keyboardType: Titanium.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Titanium.UI.RETURNKEY_DONE
        });
    }
    
    var lblCurrent = newLabel('Current:');
    lblCurrent.left = 5;
    vwHeader.add(lblCurrent);
    
    var tfCurrent = newTextField('Fat %');
    tfCurrent.left = 70;
    vwHeader.add(tfCurrent);
    
    var lblGoal = newLabel('Goal:');
    lblGoal.right = 85;
    vwHeader.add(lblGoal);
    
    var tfGoal = newTextField('Goal');
    tfGoal.right = 5;
    vwHeader.add(tfGoal);
    
    if (laf.device.isAndroid()) {
        tfCurrent.softKeyboardOnFocus = Ti.UI.Android.SOFT_KEYBOARD_HIDE_ON_FOCUS;
        tfGoal.softKeyboardOnFocus = Ti.UI.Android.SOFT_KEYBOARD_HIDE_ON_FOCUS;
    }
    
    var btnGraph = Ti.UI.createButton({
        title: 'Graph'
    });
    
    if (laf.device.isiPhone()) {
        btnGraph.style = Ti.UI.iPhone.SystemButtonStyle.BORDERED;
        btnGraph.image = laf.path.images + 'graph.png';
    }
    setRightNav(btnGraph);
    
    //=== FUNCTIONS =============================    
    function newHistoryRow(date, bodyFat, prevBodyFat, guid){
        bodyFat = parseFloat(bodyFat);
        prevBodyFat = parseFloat(prevBodyFat);
        
        var tvrRow = Ti.UI.createTableViewRow({
            height: 35,
            className: 'trackProgressBodyFatHistoryRow',
            rowType: 'historyRow',
            guid: (guid != undefined) ? guid : undefined
        });
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            text: date.replace(/\//g, '-'),
            textAlign: 'left'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: bodyFat.toFixed(1) + '%',
            textAlign: 'center'
        }));
        
        if (prevBodyFat != undefined) {
            var change = bodyFat - prevBodyFat;
            if (change != 0 && !isNaN(change)) {
                tvrRow.add(Ti.UI.createLabel({
                    color: 'black',
                    height: 22,
                    right: 25,
                    text: (isNaN(change) == false) ? change.toFixed(1) : '',
                    textAlign: 'right'
                }));
                
                tvrRow.add(Ti.UI.createView({
                    backgroundImage: (change > 0) ? laf.path.images + 'arrowUpRed.png' : laf.path.images + 'arrowDownGreen.png',
                    top: 11,
                    right: 5,
                    width: 16,
                    height: 16
                }));
            }
        }
        
        return tvrRow;
    }
    
    function setHistoryRows(){
        var data = [];
        data.push(laf.table.section('Body Fat History'));
        
        history = laf.data.workoutSet('SELECT BodyFat, StatsDate, GUID FROM BodyFatHistory WHERE BodyFat IS NOT NULL AND StatsDate IS NOT NULL AND GUID IS NOT NULL AND Inactive = 0 ORDER BY StatsDate DESC', ['BodyFat', 'StatsDate', 'GUID']);
        if (history != undefined && history.length > 0) {
            for (var historyItr = 0, historyLen = history.length; historyItr < historyLen; historyItr++) {
                data.push(newHistoryRow(history[historyItr].StatsDate, history[historyItr].BodyFat, (historyItr + 1 < historyLen) ? history[historyItr + 1].BodyFat : undefined, history[historyItr].GUID));
            }
        }
        else {
            laf.window.alert('Body Fat %', 'Entering body fat % is optional. If you do not know your body fat % you can leave it blank or see the training desk at your local club to have it measured.');
        }
        
        tvHistory.setData(data);
    }
    
    function refreshStats(){
        currentValue = laf.data.workoutScalar('SELECT BodyFat FROM BodyFatHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        
        if (currentValue != undefined && !laf.verify.isEmpty(currentValue)) {
            tfCurrent.value = parseFloat(currentValue).toFixed(1) + '%';
        }
        
        currentValue = laf.data.workoutScalar('SELECT BodyFatGoal FROM BasicStats ORDER BY UpdateUTC DESC LIMIT 1');
        
        if (currentValue != undefined && !laf.verify.isEmpty(currentValue)) {
            tfGoal.value = parseFloat(currentValue).toFixed(1) + '%';
        }
        
        setHistoryRows();
    }
    
    function saveStats(){
        tfCurrent.value = laf.verify.trim(tfCurrent.value);
        tfGoal.value = laf.verify.trim(tfGoal.value);
        
        if (!laf.verify.isEmpty(tfCurrent) && tfCurrent.value.substring(0, 1) == ' ') {
            laf.window.alert((laf.verify.isEmpty(tfCurrent)) ? 'Required' : 'Invalid', 'Please enter a numeric value for body fat.');
            tfCurrent.focus();
            return;
        }
        
        if (!laf.verify.isEmpty(tfGoal) && tfGoal.value.substring(0, 1) == ' ') {
            laf.window.alert('Invalid', 'Please enter a numeric value for body fat goal or leave blank.');
            tfGoal.focus();
            return;
        }
        
        // Update bodyfat goal from basic stats table         
        if (!laf.verify.isEmpty(tfGoal) && tfGoal.value.toString().length > 0) {
            updateStatsHistory('SELECT GUID FROM BasicStats WHERE Inactive = 0', 'BasicStats', ['BodyFatGoal'], [tfGoal.value.toString().substring(0, tfGoal.value.toString().indexOf('%'))]);
        }
        
        // Update body fat from body fat history
        updateStatsHistory('SELECT GUID FROM BodyFatHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0', 'BodyFatHistory', ['BodyFat', 'StatsDate'], [tfCurrent.value.toString().substring(0, tfCurrent.value.toString().indexOf('%')), laf.dateTime.toDateString()]);
        
        laf.window.fire('measurementsChange');
        
        if (history.length == 0 || history[0].StatsDate != laf.dateTime.toDateString()) {
            guid = laf.data.workoutScalar('SELECT GUID FROM BodyFatHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
            if (guid == undefined) {
                guid = laf.object.newGUID();
            }
            
            if (history.length == 0) {
                tvHistory.appendRow(newHistoryRow(laf.dateTime.toDateString(), tfCurrent.value, undefined, guid));
            }
            else {
                tvHistory.insertRowBefore(0, newHistoryRow(laf.dateTime.toDateString(), tfCurrent.value, history[0].BodyFat, guid));
            }
            
            history.splice(0, 0, {
                BodyFat: tfCurrent.value,
                StatsDate: laf.dateTime.toDateString(),
                GUID: guid
            });
        }
        else {
            if (history.length > 0) {
                history[0].BodyFat = (tfCurrent.value.length > 0) ? tfCurrent.value.toString().substring(0, tfCurrent.value.toString().indexOf('%')) : 0;
            }
            
            if (laf.device.isiPhone()) {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].BodyFat, (history.length > 1) ? history[1].BodyFat : undefined, history[0].GUID), {
                    animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                });
            }
            else {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].BodyFat, (history.length > 1) ? history[1].BodyFat : undefined, history[0].GUID));
            }
        }
    }
    
    function updateStatsHistory(sqlQuery, fieldTable, fieldNames, fieldValues){
        guid = laf.data.workoutScalar(sqlQuery);
        if (guid == undefined) {
            guid = laf.object.newGUID();
        }
        laf.data.workoutMakeSync(fieldTable, guid, false, fieldNames, fieldValues);
    }
    
    //=== EVENTS =============================
    btnGraph.addEventListener('click', function(e){
        laf.window.create('BodyFat', '/views/track/progressBodyFatGraph.js');
        laf.window.open();
    });
    
    tfCurrent.addEventListener('focus', function(e){
        var dftOne;
        var dftTwo;
        
        if (history.length > 0 && history[0].BodyFat != undefined) {
            var firstValue = history[0].BodyFat.toString();
            dftOne = (firstValue.indexOf('.') == -1) ? firstValue : firstValue.substring(0, firstValue.indexOf('.'));
            dftTwo = ((firstValue.indexOf('.') == -1) ? '.0' : firstValue.substring(firstValue.indexOf('.'))) + '%';
        }
        
        if (laf.device.isiPhone()) {
            standardPicker('Select your body fat %:', 'Select Body Fat', [',5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50', ',.0%,.1%,.2%,.3%,.4%,.5%,.6%,.7%,.8%,.9%'], [dftOne, dftTwo], function(selectedValues){
                if (selectedValues != undefined && selectedValues.length > 0 && selectedValues[0].length > 0) {
                    tfCurrent.value = '';
                    for (var i = 0; i < selectedValues.length; i++) {
                        tfCurrent.value += selectedValues[i];
                    }
                    saveStats();
                    laf.table.scrollToTop(tvHistory, false);
                }
            });
        }
        else {
            standardPickerForAndroid('Select your body fat %:', 'Select Body Fat', ['5', '6', '7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31', '32', '33', '34', '35', '36', '37', '38', '39', '40', '41', '42', '43', '44', '45', '46', '47', '48', '49', '50'], ['.0%', '.1%', '.2%', '.3%', '.4%', '.5%', '.6%', '.7%', '.8%', '.9%'], undefined, [dftOne, dftTwo], function(selectedValues){
                if (selectedValues != undefined && selectedValues.length > 0) {
                    tfCurrent.value = selectedValues;
                    saveStats();
                    laf.table.scrollToTop(tvHistory, false);
                }
            });
        }
        
        tfCurrent.blur();
    });
    
    tfGoal.addEventListener('focus', function(e){
        var dftOne;
        var dftTwo;
        
        currentValue = laf.data.workoutScalar('SELECT BodyFatGoal FROM BasicStats ORDER BY UpdateUTC DESC LIMIT 1');
        if (currentValue != undefined && currentValue != null) {
            var firstValue = currentValue.toString();
            dftOne = (firstValue.indexOf('.') == -1) ? firstValue : firstValue.substring(0, firstValue.indexOf('.'));
            dftTwo = ((firstValue.indexOf('.') == -1) ? '.0' : firstValue.substring(firstValue.indexOf('.'))) + '%';
        }
        
        var oncomplete = function(selectedValues){
            if (selectedValues != undefined && selectedValues.length > 0 && selectedValues[0].length > 0) {
                tfGoal.value = '';
                for (var i = 0; i < selectedValues.length; i++) {
                    tfGoal.value += selectedValues[i];
                }
                saveStats();
                laf.table.scrollToTop(tvHistory, false);
            }
        };
        
        if (laf.device.isiPhone()) {
            standardPicker('Select your body fat %:', 'Select Body Fat', [',5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50', ',.0%,.1%,.2%,.3%,.4%,.5%,.6%,.7%,.8%,.9%'], [dftOne, dftTwo], oncomplete);
        }
        else {
            standardPickerForAndroid('Select your body fat %:', 'Select Body Fat', ['5', '6', '7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31', '32', '33', '34', '35', '36', '37', '38', '39', '40', '41', '42', '43', '44', '45', '46', '47', '48', '49', '50'], ['.0%', '.1%', '.2%', '.3%', '.4%', '.5%', '.6%', '.7%', '.8%', '.9%'], undefined, [dftOne, dftTwo], oncomplete);
        }
        
        tfGoal.blur();
    });
    
    tvHistory.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.guid != undefined) {
            var dlgProgressOptions;
            
            if (laf.device.isAndroid()) {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share'],
                    title: 'Options',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share', 'Cancel'],
                    destructive: 0,
                    cancel: 2
                });
            }
            
            dlgProgressOptions.addEventListener('click', function(data){
                if (data.index == 0 && (!laf.device.isAndroid() || !data.button)) {
                    if (history.length == 1) {
                        laf.window.alert('Must keep at least one entry.');
                        return;
                    }
                    
                    laf.window.alert('Delete Record', 'Are you sure you want to delete?', ['Delete', 'Cancel'], function(msg){
                        if (msg.index == 0) {
                            laf.data.workoutMakeSync('BodyFatHistory', e.rowData.guid, true);
                            if (e.index == 0) {
                                history.splice(0, 1);
                                tvHistory.deleteRow(0);
                                tfCurrent.value = laf.data.workoutScalar('SELECT BodyFat FROM BodyFatHistory WHERE Inactive = 0 ORDER BY StatsDate DESC') + '%';
                                laf.window.fire('measurementsChange');
                            }
                            else {
                                history.splice(e.index, 1);
                                tvHistory.deleteRow(e.index);
                                
                                if (laf.device.isiPhone()) {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].BodyFat, (history.length > 1) ? history[e.index].BodyFat : undefined, history[e.index - 1].GUID), {
                                        animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                    });
                                }
                                else {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].BodyFat, (history.length > 1) ? history[e.index].BodyFat : undefined, history[e.index - 1].GUID));
                                }
                            }
                        }
                    });
                }
            });
            
            tfCurrent.blur();
            tfGoal.blur();
            dlgProgressOptions.show();
        }
    });
    //=== DISPLAY =============================
    refreshStats();
    vwMain.add(tvHistory);
    vwMain.add(vwHeader);
})();
