(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    var history = [];
    
    //=== OBJECTS =============================			
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    function newLabel(text){
        return Titanium.UI.createLabel({
            color: '#FFFFFF',
            font: {
                fontSize: 16,
                fontWeight: 'bold',
                fontFamily: 'Arial'
            },
            text: text,
            height: 'auto',
            width: 'auto'
        });
    }
    
    function newTextField(hintText){
        return Titanium.UI.createTextField({
            color: '#336699',
            height: (Titanium.Platform.name == 'iPhone OS') ? 35 : 40,
            width: 80,
            autocorrect: false,
            borderStyle: Titanium.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Titanium.UI.INPUT_BUTTONMODE_ONFOCUS,
            hintText: hintText,
            keyboardType: Titanium.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Titanium.UI.RETURNKEY_DONE
        });
    }
    
    var lblLeftCalfs = newLabel('Left:');
    lblLeftCalfs.left = 5;
    vwHeader.add(lblLeftCalfs);
    
    var tfLeftCalfs = newTextField('Calf');
    tfLeftCalfs.left = 41;
    vwHeader.add(tfLeftCalfs);
    
    var lblRightCalfs = newLabel('Right:');
    lblRightCalfs.right = 85;
    vwHeader.add(lblRightCalfs);
    
    var tfRightCalfs = newTextField('Calf');
    tfRightCalfs.right = 5;
    vwHeader.add(tfRightCalfs);
    
    var btnGraph = Ti.UI.createButton({
        title: 'Graph'
    });
    
    if (laf.device.isiPhone()) {
        btnGraph.style = Ti.UI.iPhone.SystemButtonStyle.BORDERED;
        btnGraph.image = laf.path.images + 'graph.png';
    }
    setRightNav(btnGraph);
    
    //=== FUNCTIONS =============================       
    function newHistoryRow(date, leftCalfs, rightCalfs, guid){
        var tvrRow = Ti.UI.createTableViewRow({
            height: 35,
            className: 'trackProgressCalvessHistoryRow',
            rowType: 'historyRow',
            guid: (guid != undefined) ? guid : undefined
        });
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            text: date.replace(/\//g, '-'),
            textAlign: 'left'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: parseFloat(leftCalfs).toFixed(1) + '" L',
            textAlign: 'center'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: parseFloat(rightCalfs).toFixed(1) + '" R',
            textAlign: 'right'
        }));
        
        return tvrRow;
    }
    
    function setHistoryRows(){
        var data = [];
        data.push(laf.table.section('Calves History'));
        
        history = laf.data.workoutSet('SELECT LeftCalfs, RightCalfs, StatsDate, GUID FROM CalvesHistory WHERE LeftCalfs IS NOT NULL AND RightCalfs IS NOT NULL AND StatsDate IS NOT NULL AND GUID IS NOT NULL AND Inactive = 0 ORDER BY StatsDate DESC', ['LeftCalfs', 'RightCalfs', 'StatsDate', 'GUID']);
        if (history != undefined && history.length > 0) {
            for (var historyItr = 0, historyLen = history.length; historyItr < historyLen; historyItr++) {
                data.push(newHistoryRow(history[historyItr].StatsDate, history[historyItr].LeftCalfs, history[historyItr].RightCalfs, history[historyItr].GUID));
            }
        }
        else {
            laf.window.alert('How To', 'Calves are measured separately.  Stand with your legs slightly apart.  Measure straight around your calves at the largest circumference.');
        }
        
        tvHistory.setData(data);
    }
    function refreshStats(){
        var result = laf.data.workoutRow('SELECT LeftCalfs, RightCalfs FROM CalvesHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        
        if (result.LeftCalfs != undefined && !laf.verify.isEmpty(result.LeftCalfs) && result.RightCalfs != undefined && !laf.verify.isEmpty(result.RightCalfs)) {
            tfLeftCalfs.value = result.LeftCalfs.toString();
            tfRightCalfs.value = result.RightCalfs.toString();
        }
        
        setHistoryRows();
    }
    
    function saveStats(){
        tfLeftCalfs.value = laf.verify.trim(tfLeftCalfs.value);
        tfRightCalfs.value = laf.verify.trim(tfRightCalfs.value);
        
        if (!laf.verify.isNumeric(tfLeftCalfs.value) && !laf.verify.isEmpty(tfLeftCalfs)) {
            laf.window.alert('Invalid', 'Please enter a numeric value for your left calf.');
            tfLeftCalfs.focus();
            return;
        }
        
        if (!laf.verify.isNumeric(tfRightCalfs.value) && !laf.verify.isEmpty(tfRightCalfs)) {
            laf.window.alert('Invalid', 'Please enter a numeric value for your right calf.');
            tfRightCalfs.focus();
            return;
        }
        
        tfLeftCalfs.value = (tfLeftCalfs.value.toString().length > 0) ? parseFloat(tfLeftCalfs.value).toString() : (tfRightCalfs.value.toString().length > 0) ? parseFloat(tfRightCalfs.value).toString() : 0;
        tfRightCalfs.value = (tfRightCalfs.value.toString().length > 0) ? parseFloat(tfRightCalfs.value).toString() : (tfLeftCalfs.value.toString().length > 0) ? parseFloat(tfLeftCalfs.value).toString() : 0;
        
        updateStatsHistory();
        laf.window.fire('measurementsChange');
        
        if (history.length == 0 || history[0].StatsDate != laf.dateTime.toDateString()) {
            guid = laf.data.workoutScalar('SELECT GUID FROM CalvesHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
            if (guid == undefined) {
                guid = laf.object.newGUID();
            }
            
            if (history.length == 0) {
                tvHistory.appendRow(newHistoryRow(laf.dateTime.toDateString(), tfLeftCalfs.value, tfRightCalfs.value, guid));
            }
            else {
                tvHistory.insertRowBefore(0, newHistoryRow(laf.dateTime.toDateString(), tfLeftCalfs.value, tfRightCalfs.value, guid));
            }
            
            history.splice(0, 0, {
                LeftCalfs: tfLeftCalfs.value,
                RightCalfs: tfRightCalfs.value,
                StatsDate: laf.dateTime.toDateString(),
                GUID: guid
            });
        }
        else {
            if (history.length > 0) {
                history[0].tfLeftCalfs = tfLeftCalfs.value;
                history[0].tfRightCalfs = tfRightCalfs.value;
            }
            
            if (laf.device.isiPhone()) {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].tfLeftCalfs, history[0].tfRightCalfs, history[0].GUID), {
                    animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                });
            }
            else {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].tfLeftCalfs, history[0].tfRightCalfs, history[0].GUID));
            }
        }
    }
    
    function updateStatsHistory(){
        var guid = laf.data.workoutScalar('SELECT GUID FROM CalvesHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
        if (guid == undefined) {
            guid = laf.object.newGUID();
        }
        laf.data.workoutMakeSync('CalvesHistory', guid, false, ['StatsDate', 'LeftCalfs', 'RightCalfs'], [laf.dateTime.toDateString(), tfLeftCalfs.value, tfRightCalfs.value]);
    }
    //=== EVENTS =============================
    btnGraph.addEventListener('click', function(e){
        laf.window.create('Calves', '/views/track/progressCalfGraph.js');
        laf.window.open();
    });
    
    tfLeftCalfs.addEventListener('return', function(e){
        saveStats();
        tfLeftCalfs.blur();
    });
    
    tfRightCalfs.addEventListener('return', function(e){
        saveStats();
        tfRightCalfs.blur();
    });
    
    tvHistory.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.guid != undefined) {
            var dlgProgressOptions;
            
            if (laf.device.isAndroid()) {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share'],
                    title: 'Options',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share', 'Cancel'],
                    destructive: 0,
                    cancel: 2
                });
            }
            
            dlgProgressOptions.addEventListener('click', function(data){
                if (data.index == 0 && (!laf.device.isAndroid() || !data.button)) {
                    if (history.length == 1) {
                        laf.window.alert('Must keep at least one entry.');
                        return;
                    }
                    
                    laf.window.alert('Delete Record', 'Are you sure you want to delete?', ['Delete', 'Cancel'], function(msg){
                        if (msg.index == 0) {
                            laf.data.workoutMakeSync('CalvesHistory', e.rowData.guid, true);
                            if (e.index == 0) {
                                history.splice(0, 1);
                                tvHistory.deleteRow(0);
                                
                                var result = laf.data.workoutRow('SELECT LeftCalfs, RightCalfs FROM CalvesHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
                                if (result.LeftCalfs != undefined && !laf.verify.isEmpty(result.LeftCalfs) && result.RightCalfs != undefined && !laf.verify.isEmpty(result.RightCalfs)) {
                                    tfLeftCalfs.value = result.LeftCalfs.toString();
                                    tfRightCalfs.value = result.RightCalfs.toString();
                                }
                                
                                laf.window.fire('measurementsChange');
                            }
                            else {
                                history.splice(e.index, 1);
                                tvHistory.deleteRow(e.index);
                                
                                if (laf.device.isiPhone()) {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].LeftCalfs, history[e.index - 1].RightCalfs, history[e.index - 1].GUID), {
                                        animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                    });
                                }
                                else {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].LeftCalfs, history[e.index - 1].RightCalfs, history[e.index - 1].GUID));
                                }
                            }
                        }
                    });
                }
            });
            
            tfLeftCalfs.blur();
            tfRightCalfs.blur();
            dlgProgressOptions.show();
        }
    });
    //=== DISPLAY =============================
    refreshStats();
    vwMain.add(tvHistory);
    vwMain.add(vwHeader);
})();
