(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    Ti.include('../../common/utilPicker.js');
    
    var history = [];
    var dftFeet;
    var dftInches;
    var heightValue;
    
    //=== OBJECTS =============================			
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    function newLabel(text){
        return Titanium.UI.createLabel({
            color: '#FFFFFF',
            font: {
                fontSize: 16,
                fontWeight: 'bold',
                fontFamily: 'Arial'
            },
            text: text,
            height: 'auto',
            width: 'auto'
        });
    }
    
    function newTextField(hintText){
        return Titanium.UI.createTextField({
            color: '#336699',
            height: (Titanium.Platform.name == 'iPhone OS') ? 35 : 40,
            width: 80,
            autocorrect: false,
            borderStyle: Titanium.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Titanium.UI.INPUT_BUTTONMODE_ONFOCUS,
            hintText: hintText,
            keyboardType: Titanium.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Titanium.UI.RETURNKEY_DONE
        });
    }
    
    var lblCurrent = newLabel('Current:');
    lblCurrent.left = 5;
    vwHeader.add(lblCurrent);
    
    var tfCurrent = newTextField('Height');
    tfCurrent.left = 70;
    vwHeader.add(tfCurrent);
    
    if (laf.device.isAndroid()) {
        tfCurrent.softKeyboardOnFocus = Ti.UI.Android.SOFT_KEYBOARD_HIDE_ON_FOCUS;
    }
    
    var btnGraph = Ti.UI.createButton({
        title: 'Graph'
    });
    
    if (laf.device.isiPhone()) {
        btnGraph.style = Ti.UI.iPhone.SystemButtonStyle.BORDERED;
        btnGraph.image = laf.path.images + 'graph.png';
    }
    setRightNav(btnGraph);
    
    //=== FUNCTIONS =============================    
    function newHistoryRow(date, height, prevHeight, guid){
        height = parseInt(height, 10);
        prevHeight = parseInt(prevHeight, 10);
        dftFeet = parseInt(parseInt(height, 10) / 12, 10) + '\'';
        dftInches = ' ' + parseInt(parseInt(height, 10) % 12, 10) + '"';
        
        var tvrRow = Ti.UI.createTableViewRow({
            height: 35,
            className: 'trackProgressHeightHistoryRow',
            rowType: 'historyRow',
            guid: (guid != undefined) ? guid : undefined
        });
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            text: date.replace(/\//g, '-'),
            textAlign: 'left'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: dftFeet + dftInches,
            textAlign: 'center'
        }));
        
        if (prevHeight != undefined) {
            var change = height - prevHeight;
            if (change != 0 && !isNaN(change)) {
                if (isNaN(change) == false) {
                    dftFeet = parseInt(parseInt(change, 10) / 12, 10) + '\'';
                    dftInches = ' ' + parseInt(parseInt(change, 10) % 12, 10) + '"';
                    
                    tvrRow.add(Ti.UI.createLabel({
                        color: 'black',
                        height: 22,
                        right: 25,
                        text: dftFeet + dftInches,
                        textAlign: 'right'
                    }));
                    
                    tvrRow.add(Ti.UI.createView({
                        backgroundImage: (change > 0) ? laf.path.images + 'arrowUp.png' : laf.path.images + 'arrowDown.png',
                        top: 11,
                        right: 5,
                        width: 16,
                        height: 16
                    }));
                }
            }
        }
        
        return tvrRow;
    }
    
    function setHistoryRows(){
        var data = [];
        data.push(laf.table.section('Height History'));
        
        history = laf.data.workoutSet('SELECT Height, StatsDate, GUID FROM HeightHistory WHERE Height IS NOT NULL AND StatsDate IS NOT NULL AND GUID IS NOT NULL AND Inactive = 0 ORDER BY StatsDate DESC', ['Height', 'StatsDate', 'GUID']);
        if (history != undefined && history.length > 0) {
            for (var historyItr = 0, historyLen = history.length; historyItr < historyLen; historyItr++) {
                data.push(newHistoryRow(history[historyItr].StatsDate, history[historyItr].Height, (historyItr + 1 < historyLen) ? history[historyItr + 1].Height : undefined, history[historyItr].GUID));
            }
        }
        else {
            laf.window.alert('How to', 'With your shoes off and eyes parallel to the floor stand with your back straight against a wall.  Mark the spot on the wall then measure the distance from the floor to the spot.');
        }
        
        tvHistory.setData(data);
    }
    
    function refreshStats(){
        var currentValue = laf.data.workoutScalar('SELECT Height FROM HeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        
        if (currentValue != undefined && !laf.verify.isEmpty(currentValue)) {
            dftFeet = parseInt(parseInt(currentValue, 10) / 12, 10) + '\'';
            dftInches = ' ' + parseInt(parseInt(currentValue, 10) % 12, 10) + '"';
            tfCurrent.value = dftFeet + dftInches;
        }
        
        setHistoryRows();
    }
    
    function saveStats(){
        tfCurrent.value = laf.verify.trim(tfCurrent.value);
        
        if (!laf.verify.isEmpty(tfCurrent) && tfCurrent.value.substring(0, 1) == ' ') {
            laf.window.alert((laf.verify.isEmpty(tfCurrent)) ? 'Required' : 'Invalid', 'Please enter a numeric value for height.');
            tfCurrent.focus();
            return;
        }
        
        updateStatsHistory();
        laf.window.fire('statsChange');
        
        if (history.length == 0 || history[0].StatsDate != laf.dateTime.toDateString()) {
            guid = laf.data.workoutScalar('SELECT GUID FROM HeightHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
            if (guid == undefined) {
                guid = laf.object.newGUID();
            }
            
            if (history.length == 0) {
                tvHistory.appendRow(newHistoryRow(laf.dateTime.toDateString(), heightValue, undefined, guid));
            }
            else {
                tvHistory.insertRowBefore(0, newHistoryRow(laf.dateTime.toDateString(), heightValue, history[0].Height, guid));
            }
            
            history.splice(0, 0, {
                Height: heightValue,
                StatsDate: laf.dateTime.toDateString(),
                GUID: guid
            });
        }
        else {
            if (history.length > 0) {
                history[0].Height = heightValue;
            }
            
            if (laf.device.isiPhone()) {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].Height, (history.length > 1) ? history[1].Height : undefined, history[0].GUID), {
                    animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                });
            }
            else {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].Height, (history.length > 1) ? history[1].Height : undefined, history[0].GUID));
            }
        }
    }
    
    function updateStatsHistory(){
        var guid = laf.data.workoutScalar('SELECT GUID FROM HeightHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
        if (guid == undefined) {
            guid = laf.object.newGUID();
        }
        
        laf.data.workoutMakeSync('HeightHistory', guid, false, ['Height', 'StatsDate'], [heightValue, laf.dateTime.toDateString()]);
    }
    //=== EVENTS =============================
    btnGraph.addEventListener('click', function(e){
        laf.window.create('Height', '/views/track/progressHeightGraph.js');
        laf.window.open();
    });
    
    tfCurrent.addEventListener('focus', function(e){
    
        if (history.length > 0 && history[0].Height != undefined) {
            var heightInInches = parseInt(history[0].Height, 10);
            dftFeet = parseInt(heightInInches / 12, 10) + '\'';
            dftInches = ' ' + parseInt(heightInInches % 12, 10) + '"';
        }
        
        var oncomplete = function(selectedValues){
            if (selectedValues != undefined && selectedValues.length > 0 && selectedValues[0].length > 0) {
                if (laf.device.isAndroid()) {
                    tfCurrent.value = selectedValues;
                }
                else {
                    tfCurrent.value = '';
                    for (var i = 0; i < selectedValues.length; i++) {
                        tfCurrent.value += selectedValues[i];
                    }
                }
                
                heightValue = parseInt(tfCurrent.value.toString().substring(0, tfCurrent.value.toString().indexOf('\'')), 10);
                heightValue = heightValue * 12;
                heightValue += parseInt(tfCurrent.value.toString().substring(tfCurrent.value.toString().indexOf('\'') + 1), 10);
                
                saveStats();
                laf.table.scrollToTop(tvHistory, false);
            }
        };
        
        if (laf.device.isiPhone()) {
            standardPicker('Select your height:', 'Select Height', [',3\',4\',5\',6\',7\'', ' 0", 1", 2", 3", 4", 5", 6", 7", 8", 9", 10", 11"'], [dftFeet, dftInches], oncomplete);
        }
        else {
            standardPickerForAndroid('Select your height:', 'Select Height', ['3\'', '4\'', '5\'', '6\'', '7\''], [' 0"', ' 1"', ' 2"', ' 3"', ' 4"', ' 5"', ' 6"', ' 7"', ' 8"', ' 9"', ' 10"', ' 11"'], undefined, [dftFeet, dftInches], oncomplete);
        }
        
        tfCurrent.blur();
    });
    
    tvHistory.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.guid != undefined) {
            var dlgProgressOptions;
            
            if (laf.device.isAndroid()) {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share'],
                    title: 'Options',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share', 'Cancel'],
                    destructive: 0,
                    cancel: 2
                });
            }
            
            dlgProgressOptions.addEventListener('click', function(data){
                if (data.index == 0 && (!laf.device.isAndroid() || !data.button)) {
                    if (history.length == 1) {
                        laf.window.alert('Must keep at least one entry.');
                        return;
                    }
                    
                    laf.window.alert('Delete Record', 'Are you sure you want to delete?', ['Delete', 'Cancel'], function(msg){
                        if (msg.index == 0) {
                            laf.data.workoutMakeSync('HeightHistory', e.rowData.guid, true);
                            if (e.index == 0) {
                                history.splice(0, 1);
                                tvHistory.deleteRow(0);
                                currentValue = laf.data.workoutScalar('SELECT Height FROM HeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC');
                                dftFeet = parseInt(parseInt(currentValue, 10) / 12, 10) + '\'';
                                dftInches = ' ' + parseInt(parseInt(currentValue, 10) % 12, 10) + '"';
                                tfCurrent.value = dftFeet + dftInches;
                                
                                laf.window.fire('statsChange');
                            }
                            else {
                                history.splice(e.index, 1);
                                tvHistory.deleteRow(e.index);
                                
                                if (laf.device.isiPhone()) {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].Height, (history.length > 1) ? history[e.index].Height : undefined, history[e.index - 1].GUID), {
                                        animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                    });
                                }
                                else {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].Height, (history.length > 1) ? history[e.index].Height : undefined, history[e.index - 1].GUID));
                                }
                            }
                        }
                    });
                }
            });
            
            tfCurrent.blur();
            dlgProgressOptions.show();
        }
    });
    //=== DISPLAY =============================
    refreshStats();
    vwMain.add(tvHistory);
    vwMain.add(vwHeader);
})();
