(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    var history = [];
    
    //=== OBJECTS =============================			
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    function newLabel(text){
        return Titanium.UI.createLabel({
            color: '#FFFFFF',
            font: {
                fontSize: 16,
                fontWeight: 'bold',
                fontFamily: 'Arial'
            },
            text: text,
            height: 'auto',
            width: 'auto'
        });
    }
    
    function newTextField(hintText){
        return Titanium.UI.createTextField({
            color: '#336699',
            height: (Titanium.Platform.name == 'iPhone OS') ? 35 : 40,
            width: 80,
            autocorrect: false,
            borderStyle: Titanium.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Titanium.UI.INPUT_BUTTONMODE_ONFOCUS,
            hintText: hintText,
            keyboardType: Titanium.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Titanium.UI.RETURNKEY_DONE
        });
    }
    
    var lblCurrent = newLabel('Current:');
    lblCurrent.left = 5;
    vwHeader.add(lblCurrent);
    
    var tfCurrent = newTextField('Hips');
    tfCurrent.left = 70;
    vwHeader.add(tfCurrent);
    
    var btnGraph = Ti.UI.createButton({
        title: 'Graph'
    });
    
    if (laf.device.isiPhone()) {
        btnGraph.style = Ti.UI.iPhone.SystemButtonStyle.BORDERED;
        btnGraph.image = laf.path.images + 'graph.png';
    }
    setRightNav(btnGraph);
    
    //=== FUNCTIONS =============================    	
    function newHistoryRow(date, hips, prevHips, guid){
        hips = parseFloat(hips);
        prevHips = parseFloat(prevHips);
        
        var tvrRow = Ti.UI.createTableViewRow({
            height: 35,
            className: 'trackProgressHipsHistoryRow',
            rowType: 'historyRow',
            guid: (guid != undefined) ? guid : undefined
        });
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            text: date.replace(/\//g, '-'),
            textAlign: 'left'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: hips.toFixed(1) + '"',
            textAlign: 'center'
        }));
        
        if (prevHips != undefined) {
            var change = hips - prevHips;
            if (change != 0 && !isNaN(change)) {
                tvrRow.add(Ti.UI.createLabel({
                    color: 'black',
                    height: 22,
                    right: 25,
                    text: (isNaN(change) == false) ? change.toFixed(1) : '',
                    textAlign: 'right'
                }));
                
                tvrRow.add(Ti.UI.createView({
                    backgroundImage: (change > 0) ? laf.path.images + 'arrowUp.png' : laf.path.images + 'arrowDown.png',
                    top: 11,
                    right: 5,
                    width: 16,
                    height: 16
                }));
            }
        }
        
        return tvrRow;
    }
    
    function setHistoryRows(){
        var data = [];
        data.push(laf.table.section('Hips History'));
        
        history = laf.data.workoutSet('SELECT Hips, StatsDate, GUID FROM HipsHistory WHERE Hips IS NOT NULL AND StatsDate IS NOT NULL AND GUID IS NOT NULL AND Inactive = 0 ORDER BY StatsDate DESC', ['Hips', 'StatsDate', 'GUID']);
        if (history != undefined && history.length > 0) {
            for (var historyItr = 0, historyLen = history.length; historyItr < historyLen; historyItr++) {
                data.push(newHistoryRow(history[historyItr].StatsDate, history[historyItr].Hips, (historyItr + 1 < historyLen) ? history[historyItr + 1].Hips : undefined, history[historyItr].GUID));
            }
        }
        else {
            laf.window.alert('How To', 'Measure your hips around the largest part of your buttocks with your heels togethers.');
        }
        
        tvHistory.setData(data);
    }
    
    function refreshStats(){
        var currentValue = laf.data.workoutScalar('SELECT Hips FROM HipsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        
        if (currentValue != undefined && !laf.verify.isEmpty(currentValue)) {
            tfCurrent.value = currentValue.toString();
        }
        
        setHistoryRows();
    }
    
    function saveStats(){
        tfCurrent.value = laf.verify.trim(tfCurrent.value);
        
        if (laf.verify.isEmpty(tfCurrent) || !laf.verify.isNumeric(tfCurrent.value)) {
            laf.window.alert((laf.verify.isEmpty(tfCurrent)) ? 'Required' : 'Invalid', 'Please enter a numeric value for hips.');
            tfCurrent.focus();
            return;
        }
        
        updateStatsHistory();
        laf.window.fire('measurementsChange');
        
        if (history.length == 0 || history[0].StatsDate != laf.dateTime.toDateString()) {
            guid = laf.data.workoutScalar('SELECT GUID FROM HipsHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
            if (guid == undefined) {
                guid = laf.object.newGUID();
            }
            
            if (history.length == 0) {
                tvHistory.appendRow(newHistoryRow(laf.dateTime.toDateString(), tfCurrent.value, undefined, guid));
            }
            else {
                tvHistory.insertRowBefore(0, newHistoryRow(laf.dateTime.toDateString(), tfCurrent.value, history[0].Hips, guid));
            }
            
            history.splice(0, 0, {
                Hips: tfCurrent.value,
                StatsDate: laf.dateTime.toDateString(),
                GUID: guid
            });
        }
        else {
            if (history.length > 0) {
                history[0].Hips = tfCurrent.value;
            }
            
            if (laf.device.isiPhone()) {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].Hips, (history.length > 1) ? history[1].Hips : undefined, history[0].GUID), {
                    animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                });
            }
            else {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].Hips, (history.length > 1) ? history[1].Hips : undefined, history[0].GUID));
            }
        }
    }
    
    function updateStatsHistory(){
        var guid = laf.data.workoutScalar('SELECT GUID FROM HipsHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
        if (guid == undefined) {
            guid = laf.object.newGUID();
        }
        laf.data.workoutMakeSync('HipsHistory', guid, false, ['Hips', 'StatsDate'], [tfCurrent.value, laf.dateTime.toDateString()]);
    }
    //=== EVENTS =============================
    btnGraph.addEventListener('click', function(e){
        laf.window.create('Hips', '/views/track/progressHipsGraph.js');
        laf.window.open();
    });
    
    tfCurrent.addEventListener('return', function(e){
        saveStats();
        tfCurrent.blur();
    });
    
    tvHistory.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.guid != undefined) {
            var dlgProgressOptions;
            
            if (laf.device.isAndroid()) {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share'],
                    title: 'Options',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share', 'Cancel'],
                    destructive: 0,
                    cancel: 2
                });
            }
            
            dlgProgressOptions.addEventListener('click', function(data){
                if (data.index == 0 && (!laf.device.isAndroid() || !data.button)) {
                    if (history.length == 1) {
                        laf.window.alert('Must keep at least history one entry.');
                        return;
                    }
                    
                    laf.window.alert('Delete Record', 'Are you sure you want to delete?', ['Delete', 'Cancel'], function(msg){
                        if (msg.index == 0) {
                            laf.data.workoutMakeSync('HipsHistory', e.rowData.guid, true);
                            if (e.index == 0) {
                                history.splice(0, 1);
                                tvHistory.deleteRow(0);
                                tfCurrent.value = laf.data.workoutScalar('SELECT Hips FROM HipsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC').toString();
                                laf.window.fire('measurementsChange');
                            }
                            else {
                                history.splice(e.index, 1);
                                tvHistory.deleteRow(e.index);
                                
                                if (laf.device.isiPhone()) {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].Hips, (history.length > 1) ? history[e.index].Hips : undefined, history[e.index - 1].GUID), {
                                        animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                    });
                                }
                                else {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].Hips, (history.length > 1) ? history[e.index].Hips : undefined, history[e.index - 1].GUID));
                                }
                            }
                        }
                    });
                }
            });
            
            tfCurrent.blur();
            dlgProgressOptions.show();
        }
    });
    
    //=== DISPLAY =============================
    refreshStats();
    vwMain.add(tvHistory);
    vwMain.add(vwHeader);
})();
