(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    Ti.include('../../common/utilPicker.js');
    
    var progressPhotos = [];
    
    var member = (laf.object.isSaved('Member')) ? laf.object.load('Member') : undefined;
    
    var memberID = (member == undefined || member.ID == undefined) ? '0' : member.ID.toString();
    var memberDir = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, memberID);
    if (!memberDir.exists()) {
        memberDir.createDirectory();
    }
    
    //=== OBJECTS ===================================	
    var vwBackground = Ti.UI.createView({
        backgroundImage: laf.path.images + 'background.png',
        left: 0,
        right: 0,
        top: 0,
        bottom: 0,
        opacity: 0.80,
        visible: false
    });
    
    var tvTrackPhotos = Ti.UI.createTableView({
        backgroundColor: 'transparent',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    vwHeader.add(Titanium.UI.createView({
        backgroundImage: laf.path.images + 'photo.png',
        left: 5,
        width: 30,
        height: 30
    }));
    
    vwHeader.add(Ti.UI.createLabel({
        color: 'white',
        font: {
            fontSize: 16,
            fontFamily: 'Arial',
            fontWeight: 'light'
        },
        top: 5,
        height: 40,
        left: 45,
        textAlign: 'left',
        text: 'Track personal progress with photographs of yourself.'
    }));
    
    var btnAdd = Ti.UI.createButton({
        title: 'Add'
    });
    
    if (laf.device.isiPhone()) {
        btnAdd.systemButton = Ti.UI.iPhone.SystemButton.ADD;
    }
    
    //=== FUNCTIONS ================================    
    function newPhotoRow(imageDate, weight){
        var tvRow = Ti.UI.createTableViewRow({
            height: 40,
            className: 'TrackProgressPhotos',
            hasChild: true,
            imageDate: imageDate
        });
        
        tvRow.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 16,
                fontFamily: 'Arial'
            },
            left: 10,
            right: laf.table.leftDataRightMargin,
            height: 20,
            textAlign: 'left',
            text: imageDate
        }));
        
        if (weight != undefined && weight > 0) {
            tvRow.add(Ti.UI.createLabel({
                color: '#576996',
                font: {
                    fontSize: 16,
                    fontFamily: 'Arial'
                },
                right: laf.table.detailsRight,
                height: 20,
                textAlign: 'right',
                text: weight + ' lbs'
            }));
        }
        
        return tvRow;
    }
    
    function getAllFiles(){
        progressPhotos = [];
        var memberFiles = memberDir.getDirectoryListing();
        for (var i = 0, memberLen = memberFiles.length; i < memberLen; i++) {
            if (memberFiles[i].toString().indexOf('.png') != -1) {
                progressPhotos.push(memberFiles[i].toString());
            }
        }
        progressPhotos.sort();
    }
    
    function getWeightForDate(queryDate){
        var result = laf.data.workoutScalar('SELECT Weight FROM WeightOnDate WHERE OnDate = "' + queryDate + '" ');
        return (result != undefined) ? parseInt(result, 10) : 0;
    }
    
    function refreshTableView(){
        var data = [];
        data.push(laf.table.section('Photograph History'));
        
        if (progressPhotos.length > 0) {
            vwBackground.visible = false;
            tvTrackPhotos.separatorColor = '#e1e1e1';
            
            if (progressPhotos != undefined && progressPhotos.length > 0) {
                if (progressPhotos.length > 1) {
                    data.push(laf.table.actionRow('Start Slideshow', 'Slideshow', 48, 'play2.png'));
                }
                
                for (var i = progressPhotos.length - 1; i >= 0; i--) {
                    var displayDate = progressPhotos[i].substring(0, 4) + '-' + progressPhotos[i].substring(5, 7) + '-' + progressPhotos[i].substring(8, 10);
                    data.push(newPhotoRow(displayDate, getWeightForDate(displayDate.replace(/-/g, '/'))));
                }
            }
        }
        else {
            vwBackground.visible = true;
            tvTrackPhotos.separatorColor = 'transparent';
            
            var strAddPicture = 'You have no saved photographs.\n\nClick the';
            strAddPicture += (laf.device.isiPhone() ? ' + ' : ' add ') + 'button in the upper right to start your personal photograph history.';
            
            var tvrNoUpcoming = Ti.UI.createTableViewRow({
                height: 145,
                className: 'UpcomingNoUpcoming'
            });
            tvrNoUpcoming.add(Ti.UI.createLabel({
                color: 'white',
                font: {
                    fontSize: 18,
                    fontFamily: 'Arial'
                },
                top: 15,
                left: 5,
                right: 5,
                height: 120,
                textAlign: 'left',
                text: strAddPicture
            }));
            
            data.push(tvrNoUpcoming);
        }
        tvTrackPhotos.setData(data);
    }
    
    function resizeImage(media, maxDimension){
        maxDimension = parseFloat(maxDimension);
        
        var blob = Ti.UI.createImageView({
            image: media
        }).toBlob();
        
        var scale = 1.0;
        if (blob.height > maxDimension || blob.width > maxDimension) {
            var bigSide = (blob.width > blob.height) ? blob.width : blob.height;
            scale = maxDimension / bigSide;
        }
        
        //Create a black view to center image on, for slideshow
        var outputImage = Ti.UI.createView({
            backgroundColor: 'black',
            width: maxDimension,
            height: maxDimension
        });
        
        outputImage.add(Ti.UI.createImageView({
            width: blob.width * scale,
            height: blob.height * scale,
            image: blob
        }));
        
        return Ti.UI.createImageView({
            backgroundColor: 'black',
            width: maxDimension,
            height: maxDimension,
            image: outputImage.toImage()
        }).toBlob();
    };
    
    //=== EVENTS ===================================
    tvTrackPhotos.addEventListener('click', function(e){
        if (e.rowData != undefined) {
            if (e.rowData.rowType != undefined && e.rowData.rowType == 'Slideshow') {
                var winToOpen = laf.window.create('Photos', '/views/track/progressPhotosSlideshow.js', {
                    progressPhotos: progressPhotos,
                    index: 0
                });
                winToOpen.backgroundColor = 'black';
                winToOpen.hideNavBar = true;
                laf.window.open();
            }
            if (e.rowData.imageDate != undefined) {
                laf.window.create('Photos', '/views/track/progressPhotosView.js', {
                    imageDate: e.rowData.imageDate + '.png',
                    progressPhotos: progressPhotos
                });
                laf.window.open();
            }
        }
    });
    
    btnAdd.addEventListener('click', function(e){
        var dlgPhotoOptions;
        
        if (laf.device.isAndroid()) {
            dlgPhotoOptions = Ti.UI.createOptionDialog({
                options: ['Take a Photo', 'Pick a Photo'],
                buttonNames: ['Cancel']
            });
        }
        else {
            dlgPhotoOptions = Ti.UI.createOptionDialog({
                options: ['Take New Photo', 'Use Existing Photo', 'Cancel'],
                cancel: 2
            });
        }
        
        dlgPhotoOptions.addEventListener('click', function(e){
            if (e.index == 0 && (!laf.device.isAndroid() || !e.button)) {
                var onComplete = function(event){
                    try {
                        var newPhotoName = laf.dateTime.toDateString(undefined, '-') + '.png';
                        var newPhoto = Ti.Filesystem.getFile(memberDir.nativePath, newPhotoName);
                        if (newPhoto.exists()) {
                            newPhoto.deleteFile();
                        }
                        newPhoto.write(resizeImage(event.media, 320));
                    } 
                    catch (ex) {
                        Ti.API.info(ex);
                        laf.window.alert(ex);
                    }
                    //If there wasn't already a photo for today add to array
                    if (progressPhotos.indexOf(newPhotoName) == -1) {
                        tvTrackPhotos.setData(null);
                        getAllFiles();
                        refreshTableView();
                    }
                };
                Ti.Media.showCamera({
                    success: onComplete,
                    cancel: function(){
                    },
                    error: function(error){
                        laf.window.alert((error.code == Ti.Media.NO_CAMERA) ? 'Your device does not\nhave a camera.' : 'Unexpected error: ' + error.code);
                    },
                    allowImageEditing: true,
                    saveToPhotoGallery: false,
                    mediaTypes: [Titanium.Media.MEDIA_TYPE_PHOTO]
                });
            }
            if (e.index == 1) {
                var successComplete = function(event){
                    var onComplete = function(selectedDate){
                        if (selectedDate != undefined) {
                            if (selectedDate > new Date()) {
                                laf.window.alert('Date in Future', 'Error: You cannot save with a date from the future.');
                                datePicker('Select the date of this photo:', 'Select Date', undefined, undefined, new Date(), onComplete);
                            }
                            
                            try {
                                var newPhotoName = laf.dateTime.toDateString(selectedDate, '-') + '.png';
                                var newPhoto = Ti.Filesystem.getFile(memberDir.nativePath, newPhotoName);
                                if (newPhoto.exists()) {
                                    newPhoto.deleteFile();
                                }
                                newPhoto.write(resizeImage(event.media, 320));
                            } 
                            catch (ex) {
                                Ti.API.info(ex);
                                laf.window.alert(ex);
                            }
                            //If there wasn't already a photo for that day add to array
                            if (progressPhotos.indexOf(newPhotoName) == -1) {
                                tvTrackPhotos.setData(null);
                                getAllFiles();
                                refreshTableView();
                            }
                        }
                    };
                    datePicker('Select the date of this photo:', 'Select Date', undefined, undefined, new Date(), onComplete);
                };
                
                Ti.Media.openPhotoGallery({
                    success: successComplete,
                    cancel: function(){
                    },
                    error: function(error){
                    },
                    allowImageEditing: true,
                    saveToPhotoGallery: false,
                    mediaTypes: [Titanium.Media.MEDIA_TYPE_PHOTO]
                });
            }
        });
        dlgPhotoOptions.show();
    });
    
    laf.window.listen('PhotosChange', function(e){
        if (laf.device.isAndroid()) {
            if (progressPhotos.length == 0) {
                tvTrackPhotos.deleteRow(0);
                refreshTableView();
            }
            else {
                tvTrackPhotos.deleteRow(parseInt(progressPhotos.length, 10) - parseInt(e.index, 10) + 1);
                if (progressPhotos.length == 1) {
                    tvTrackPhotos.deleteRow(0);
                }
            }
        }
        else {
            if (progressPhotos.length == 1) {
                tvTrackPhotos.deleteRow(0);
                progressPhotos.splice(0, 1);
                refreshTableView();
            }
            else {
                tvTrackPhotos.deleteRow(parseInt(progressPhotos.length, 10) - parseInt(e.index, 10));
                progressPhotos.splice(e.index, 1);
                if (progressPhotos.length == 1) {
                    tvTrackPhotos.deleteRow(0);
                }
            }
        }
    });
    
    //=== DISPLAY ==================================
    getAllFiles();
    refreshTableView();
    vwMain.add(vwBackground);
    vwMain.add(tvTrackPhotos);
    vwMain.add(vwHeader);
    setRightNav(btnAdd);
})();
