(function(){
    //=== HEADER & DATA =============================
    var win = Ti.UI.currentWindow;
    var laf = Ti.App.laf; //Get alias to global laf instance
    var winData = (win != undefined && win.winData != undefined) ? win.winData : {};
    var progressPhotos = (winData.progressPhotos != undefined) ? winData.progressPhotos : [];
    var length = (progressPhotos.length != 0) ? progressPhotos.length : 0;
    
    var member = (laf.object.isSaved('Member')) ? laf.object.load('Member') : undefined;
    var memberID = (member == undefined || member.ID == undefined) ? '0' : member.ID.toString();
    var memberDir = Ti.Filesystem.getFile(Ti.Filesystem.applicationDataDirectory, memberID);
    
    var images = [];
    if (length > 1) {
        for (var photoItr = 1; photoItr < length; photoItr++) {
            images.push(memberDir.nativePath + '/' + progressPhotos[photoItr]);
        }
        images.push(memberDir.nativePath + '/' + progressPhotos[0]);
    }
    
    var counter = 0;
    //=== OBJECTS ===================================
    var vwPictures = Ti.UI.createView({
        backgroundColor: 'black',
        height: 320,
        width: 320,
        left: 0,
        right: 0,
        top: (laf.device.isiPhone()) ? 0 : 20,
        bottom: (laf.device.isiPhone()) ? 0 : 30
    });
    
    var ivBackground = Ti.UI.createImageView({
        image: memberDir.nativePath + '/' + progressPhotos[0],
        height: 320,
        width: 320,
        left: 0,
        right: 0,
        top: (laf.device.isiPhone()) ? 0 : 20,
        bottom: (laf.device.isiPhone()) ? 0 : 30
    });
    vwPictures.add(ivBackground);
    
    var ivPhoto = Ti.UI.createImageView({
        images: images,
        duration: 2000,
        repeatCount: 0,
        height: 320,
        width: 320,
        left: 0,
        right: 0,
        top: (laf.device.isiPhone()) ? 20 : 50,
        bottom: (laf.device.isiPhone()) ? 0 : 20
    });
    vwPictures.add(ivPhoto);
    
    var lblDate = Ti.UI.createLabel({
        color: 'white',
        top: 10,
        height: 20,
        textAlign: 'center',
        text: progressPhotos[counter].toString().substring(0, 10)
    });
    vwPictures.add(lblDate);
    
    var vwFooter = Ti.UI.createView({
        bottom: 5,
        width: 60,
        height: 35,
        opacity: 0.4,
        backgroundColor: 'black',
        borderRadius: 10
    });
    
    var btnPlay = Ti.UI.createButton({
        bottom: 7,
        height: 30,
        width: 30,
        visible: false,
        backgroundImage: laf.path.images + 'play.png'
    });
    
    var btnPause = Ti.UI.createButton({
        bottom: 7,
        height: 30,
        width: 30,
        visible: false,
        backgroundImage: laf.path.images + 'pause.png'
    });
    
    var btnClose = Ti.UI.createButton({
        title: 'X',
        color: 'white',
        font: {
            fontSize: 30,
            fontFamily: 'Helvetica'
        },
        height: 35,
        width: 50,
        top: 5,
        right: 5,
        backgroundImage: laf.path.images + 'BUTT_red_off.png',
        backgroundSelectedImage: laf.path.images + 'BUTT_red_on.png'
    });
    
    //=== FUNCTIONS ================================
    function playSlideshow(){
        if (laf.device.isAndroid() || !ivPhoto.animating) {
            btnPlay.visible = false;
            ivPhoto.start();
            btnPause.enabled = false;
            btnPause.opacity = 0.5;
            btnPause.visible = true;
            
            setTimeout(function(){
                btnPause.enabled = true;
                btnPause.opacity = 1.0;
            }, 1000);
        }
    }
    
    //=== EVENTS ===================================    
    btnClose.addEventListener('click', function(){
        if (laf.device.isiPhone()) {
            win.showNavBar();
            Ti.UI.iPhone.statusBarStyle = Ti.UI.iPhone.StatusBar.DEFAULT;
        }
        //necessary for android
        win.navBarHidden = false;
        ivPhoto.stop();
        win.close();
    });
    
    btnPause.addEventListener('click', function(e){
        if (ivPhoto.animating) {
            ivPhoto.pause();
            btnPause.visible = false;
            btnPlay.visible = true;
        }
    });
    
    btnPlay.addEventListener('click', function(e){
        playSlideshow();
    });
    
    ivPhoto.addEventListener('load', function(e){
        playSlideshow();
    });
    
    ivPhoto.addEventListener('change', function(e){
        if (counter == length) {
            counter = 0;
        }
        lblDate.text = progressPhotos[counter++].toString().substring(0, 10);
    });
    
    //=== DISPLAY ==================================
    if (laf.device.isiPhone()) {
        win.hideNavBar();
        Ti.UI.iPhone.statusBarStyle = Ti.UI.iPhone.StatusBar.OPAQUE_BLACK;
    }
    
    win.navBarHidden = true;
    win.backgroundColor = '#000';
    win.add(vwPictures);
    win.add(btnClose);
    
    if (laf.device.isiPhone()) {
        win.add(vwFooter);
        win.add(btnPlay);
        win.add(btnPause);
    }
    
    setTimeout(function(){
        lblDate.text = progressPhotos[counter++].toString().substring(0, 10);
    }, 2000);
    
    setTimeout(function(){
        ivBackground.visible = false;
    }, 2400);
    
})();
