(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    var history = [];
    
    //=== OBJECTS =============================			
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    function newLabel(text){
        return Titanium.UI.createLabel({
            color: '#FFFFFF',
            font: {
                fontSize: 16,
                fontWeight: 'bold',
                fontFamily: 'Arial'
            },
            text: text,
            height: 'auto',
            width: 'auto'
        });
    }
    
    function newTextField(hintText){
        return Titanium.UI.createTextField({
            color: '#336699',
            height: (Titanium.Platform.name == 'iPhone OS') ? 35 : 40,
            width: 80,
            autocorrect: false,
            borderStyle: Titanium.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Titanium.UI.INPUT_BUTTONMODE_ONFOCUS,
            hintText: hintText,
            keyboardType: Titanium.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Titanium.UI.RETURNKEY_DONE
        });
    }
    
    var lblLeftThighs = newLabel('Left:');
    lblLeftThighs.left = 5;
    vwHeader.add(lblLeftThighs);
    
    var tfLeftThighs = newTextField('Thigh');
    tfLeftThighs.left = 41;
    vwHeader.add(tfLeftThighs);
    
    var lblRightThighs = newLabel('Right:');
    lblRightThighs.right = 85;
    vwHeader.add(lblRightThighs);
    
    var tfRightThighs = newTextField('Thigh');
    tfRightThighs.right = 5;
    vwHeader.add(tfRightThighs);
    
    var btnGraph = Ti.UI.createButton({
        title: 'Graph'
    });
    
    if (laf.device.isiPhone()) {
        btnGraph.style = Ti.UI.iPhone.SystemButtonStyle.BORDERED;
        btnGraph.image = laf.path.images + 'graph.png';
    }
    setRightNav(btnGraph);
    
    //=== FUNCTIONS =============================  
    function newHistoryRow(date, leftThighs, rightThighs, guid){
        var tvrRow = Ti.UI.createTableViewRow({
            height: 35,
            className: 'trackProgressThighsHistoryRow',
            rowType: 'historyRow',
            guid: (guid != undefined) ? guid : undefined
        });
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            text: date.replace(/\//g, '-'),
            textAlign: 'left'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: parseFloat(leftThighs).toFixed(1) + '" L',
            textAlign: 'center'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: parseFloat(rightThighs).toFixed(1) + '" R',
            textAlign: 'right'
        }));
        
        return tvrRow;
    }
    
    function setHistoryRows(){
        var data = [];
        data.push(laf.table.section('Thighs History'));
        
        history = laf.data.workoutSet('SELECT LeftThighs, RightThighs, StatsDate, GUID FROM ThighsHistory WHERE LeftThighs IS NOT NULL AND RightThighs IS NOT NULL AND StatsDate IS NOT NULL AND GUID IS NOT NULL AND Inactive = 0 ORDER BY StatsDate DESC', ['LeftThighs', 'RightThighs', 'StatsDate', 'GUID']);
        if (history != undefined && history.length > 0) {
            for (var historyItr = 0, historyLen = history.length; historyItr < historyLen; historyItr++) {
                data.push(newHistoryRow(history[historyItr].StatsDate, history[historyItr].LeftThighs, history[historyItr].RightThighs, history[historyItr].GUID));
            }
        }
        else {
            laf.window.alert('How To', 'Thighs are measured separately.  Stand with your legs slightly apart.  Measure your upper leg where the circumference is largest.');
        }
        
        tvHistory.setData(data);
    }
    
    function refreshStats(){
        var result = laf.data.workoutRow('SELECT LeftThighs, RightThighs FROM ThighsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        
        if (result.LeftThighs != undefined && !laf.verify.isEmpty(result.LeftThighs) && result.RightThighs != undefined && !laf.verify.isEmpty(result.RightThighs)) {
            tfLeftThighs.value = result.LeftThighs.toString();
            tfRightThighs.value = result.RightThighs.toString();
        }
        
        setHistoryRows();
    }
    
    function saveStats(){
        tfLeftThighs.value = laf.verify.trim(tfLeftThighs.value);
        tfRightThighs.value = laf.verify.trim(tfRightThighs.value);
        
        if (!laf.verify.isNumeric(tfLeftThighs.value) && !laf.verify.isEmpty(tfLeftThighs)) {
            laf.window.alert('Invalid', 'Please enter a numeric value for your left thigh.');
            tfLeftThighs.focus();
            return;
        }
        
        if (!laf.verify.isNumeric(tfRightThighs.value) && !laf.verify.isEmpty(tfRightThighs)) {
            laf.window.alert('Invalid', 'Please enter a numeric value for your right thigh.');
            tfRightThighs.focus();
            return;
        }
        
        tfLeftThighs.value = (tfLeftThighs.value.length > 0) ? parseFloat(tfLeftThighs.value).toString() : (tfRightThighs.value.length > 0) ? parseFloat(tfRightThighs.value).toString() : 0;
        tfRightThighs.value = (tfRightThighs.value.length > 0) ? parseFloat(tfRightThighs.value).toString() : (tfLeftThighs.value.length > 0) ? parseFloat(tfLeftThighs.value).toString() : 0;
        
        updateStatsHistory();
        laf.window.fire('measurementsChange');
        
        if (history.length == 0 || history[0].StatsDate != laf.dateTime.toDateString()) {
            guid = laf.data.workoutScalar('SELECT GUID FROM ThighsHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
            if (guid == undefined) {
                guid = laf.object.newGUID();
            }
            
            if (history.length == 0) {
                tvHistory.appendRow(newHistoryRow(laf.dateTime.toDateString(), tfLeftThighs.value, tfRightThighs.value, guid));
            }
            else {
                tvHistory.insertRowBefore(0, newHistoryRow(laf.dateTime.toDateString(), tfLeftThighs.value, tfRightThighs.value, guid));
            }
            
            history.splice(0, 0, {
                LeftThighs: tfLeftThighs.value,
                RightThighs: tfRightThighs.value,
                StatsDate: laf.dateTime.toDateString(),
                GUID: guid
            });
        }
        else {
            if (history.length > 0) {
                history[0].LeftThighs = tfLeftThighs.value;
                history[0].RightThighs = tfRightThighs.value;
            }
            
            if (laf.device.isiPhone()) {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].LeftThighs, history[0].RightThighs, history[0].GUID), {
                    animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                });
            }
            else {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].LeftThighs, history[0].RightThighs, history[0].GUID));
            }
        }
    }
    
    function updateStatsHistory(){
        var guid = laf.data.workoutScalar('SELECT GUID FROM ThighsHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
        if (guid == undefined) {
            guid = laf.object.newGUID();
        }
        laf.data.workoutMakeSync('ThighsHistory', guid, false, ['StatsDate', 'LeftThighs', 'RightThighs'], [laf.dateTime.toDateString(), tfLeftThighs.value, tfRightThighs.value]);
    }
    //=== EVENTS =============================
    btnGraph.addEventListener('click', function(e){
        laf.window.create('Thighs', '/views/track/progressThighsGraph.js');
        laf.window.open();
    });
    
    tfLeftThighs.addEventListener('return', function(e){
        saveStats();
        tfLeftThighs.blur();
    });
    
    tfRightThighs.addEventListener('return', function(e){
        saveStats();
        tfRightThighs.blur();
    });
    
    tvHistory.addEventListener('click', function(e){
        if (e.rowData != undefined && e.rowData.guid != undefined) {
            var dlgProgressOptions;
            
            if (laf.device.isAndroid()) {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share'],
                    title: 'Options',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share', 'Cancel'],
                    destructive: 0,
                    cancel: 2
                });
            }
            
            dlgProgressOptions.addEventListener('click', function(data){
                if (data.index == 0 && (!laf.device.isAndroid() || !data.button)) {
                    if (history.length == 1) {
                        laf.window.alert('Must keep at least one entry.');
                        return;
                    }
                    
                    laf.window.alert('Delete Record', 'Are you sure you want to delete?', ['Delete', 'Cancel'], function(msg){
                        if (msg.index == 0) {
                            laf.data.workoutMakeSync('ThighsHistory', e.rowData.guid, true);
                            if (e.index == 0) {
                                history.splice(0, 1);
                                tvHistory.deleteRow(0);
                                
                                var result = laf.data.workoutRow('SELECT LeftThighs, RightThighs FROM ThighsHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
                                
                                if (result.LeftThighs != undefined && !laf.verify.isEmpty(result.LeftThighs) && result.RightThighs != undefined && !laf.verify.isEmpty(result.RightThighs)) {
                                    tfLeftThighs.value = result.LeftThighs.toString();
                                    tfRightThighs.value = result.RightThighs.toString();
                                }
                                
                                laf.window.fire('measurementsChange');
                            }
                            else {
                                history.splice(e.index, 1);
                                tvHistory.deleteRow(e.index);
                                
                                if (laf.device.isiPhone()) {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].LeftThighs, history[e.index - 1].RightThighs, history[e.index - 1].GUID), {
                                        animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                    });
                                }
                                else {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].LeftThighs, history[e.index - 1].RightThighs, history[e.index - 1].GUID));
                                }
                            }
                        }
                    });
                }
            });
            
            tfLeftThighs.blur();
            tfRightThighs.blur();
            dlgProgressOptions.show();
        }
    });
    //=== DISPLAY =============================
    refreshStats();
    vwMain.add(tvHistory);
    vwMain.add(vwHeader);
})();
