(function(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/winHeader.js');
    
    var history = [];
    var currentValue;
    
    //=== OBJECTS =============================			
    var tvHistory = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: '#e1e1e1',
        top: 48
    });
    
    var vwHeader = Ti.UI.createView({
        left: 0,
        right: 0,
        top: 0,
        height: 48,
        backgroundColor: '#576996'
    });
    
    function newLabel(text){
        return Titanium.UI.createLabel({
            color: '#FFFFFF',
            font: {
                fontSize: 16,
                fontWeight: 'bold',
                fontFamily: 'Arial'
            },
            text: text,
            height: 'auto',
            width: 'auto'
        });
    }
    
    function newTextField(hintText){
        return Titanium.UI.createTextField({
            color: '#336699',
            height: (Titanium.Platform.name == 'iPhone OS') ? 35 : 40,
            width: 80,
            autocorrect: false,
            borderStyle: Titanium.UI.INPUT_BORDERSTYLE_ROUNDED,
            clearButtonMode: Titanium.UI.INPUT_BUTTONMODE_ONFOCUS,
            hintText: hintText,
            keyboardType: Titanium.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            autocapitalization: Titanium.UI.TEXT_AUTOCAPITALIZATION_NONE,
            returnKeyType: Titanium.UI.RETURNKEY_DONE
        });
    }
    
    var lblCurrent = newLabel('Current:');
    lblCurrent.left = 5;
    vwHeader.add(lblCurrent);
    
    var tfCurrent = newTextField('Weight');
    tfCurrent.left = 70;
    vwHeader.add(tfCurrent);
    
    var lblGoal = newLabel('Goal:');
    lblGoal.right = 85;
    vwHeader.add(lblGoal);
    
    var tfGoal = newTextField('Goal');
    tfGoal.right = 5;
    vwHeader.add(tfGoal);
    
    var btnGraph = Ti.UI.createButton({
        title: 'Graph'
    });
    
    if (laf.device.isiPhone()) {
        btnGraph.style = Ti.UI.iPhone.SystemButtonStyle.BORDERED;
        btnGraph.image = laf.path.images + 'graph.png';
    }
    setRightNav(btnGraph);
    
    //=== FUNCTIONS =============================
    function newHistoryRow(date, weight, prevWeight, guid){
        weight = parseInt(weight, 10);
        prevWeight = parseInt(prevWeight, 10);
        
        var tvrRow = Ti.UI.createTableViewRow({
            height: 35,
            className: 'trackProgressWeightHistoryRow',
            rowType: 'historyRow',
            guid: (guid != undefined) ? guid : undefined
        });
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            text: date.replace(/\//g, '-'),
            textAlign: 'left'
        }));
        
        tvrRow.add(Ti.UI.createLabel({
            color: 'black',
            height: 22,
            left: 5,
            right: 5,
            text: weight.toString() + ' lbs',
            textAlign: 'center'
        }));
        
        if (prevWeight != undefined) {
            var change = weight - prevWeight;
            if (change != 0 && !isNaN(change)) {
                tvrRow.add(Ti.UI.createLabel({
                    color: 'black',
                    height: 22,
                    right: 25,
                    text: (!isNaN(change)) ? change.toString() : '',
                    textAlign: 'right'
                }));
                
                tvrRow.add(Ti.UI.createView({
                    backgroundImage: (change > 0) ? laf.path.images + 'arrowUpRed.png' : laf.path.images + 'arrowDownGreen.png',
                    top: 11,
                    right: 5,
                    width: 16,
                    height: 16
                }));
            }
        }
        
        return tvrRow;
    }
    
    function setHistoryRows(){
        var data = [];
        data.push(laf.table.section('Weight History'));
        
        history = laf.data.workoutSet('SELECT Weight, StatsDate, GUID FROM WeightHistory WHERE Weight IS NOT NULL AND StatsDate IS NOT NULL AND GUID IS NOT NULL AND Inactive = 0 ORDER BY StatsDate DESC', ['Weight', 'StatsDate', 'GUID']);
        if (history != undefined && history.length > 0) {
            for (var historyItr = 0, historyLen = history.length; historyItr < historyLen; historyItr++) {
                data.push(newHistoryRow(history[historyItr].StatsDate, history[historyItr].Weight, (historyItr + 1 < historyLen) ? history[historyItr + 1].Weight : undefined, history[historyItr].GUID));
            }
        }
        
        tvHistory.setData(data);
    }
    
    function refreshStats(){
        currentValue = laf.data.workoutScalar('SELECT Weight FROM WeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        
        if (currentValue != undefined && !laf.verify.isEmpty(currentValue)) {
            tfCurrent.value = currentValue.toString();
        }
        
        currentValue = laf.data.workoutScalar('SELECT WeightGoal FROM BasicStats ORDER BY UpdateUTC DESC LIMIT 1');
        
        if (currentValue != undefined && !laf.verify.isEmpty(currentValue)) {
            tfGoal.value = currentValue.toString();
        }
        
        setHistoryRows();
    }
    
    function saveStats(){
        tfCurrent.value = (!laf.verify.isEmpty(tfCurrent) && tfCurrent.value.toString().indexOf('.')) ? parseInt(tfCurrent.value, 10).toString() : laf.verify.trim(tfCurrent.value);
        tfGoal.value = (!laf.verify.isEmpty(tfGoal) && tfGoal.value.toString().indexOf('.')) ? parseInt(tfGoal.value, 10).toString() : laf.verify.trim(tfGoal.value);
        
        if (laf.verify.isEmpty(tfCurrent) || !laf.verify.isNumeric(tfCurrent.value)) {
            laf.window.alert((laf.verify.isEmpty(tfCurrent)) ? 'Required' : 'Invalid', 'Please enter a numeric value for weight.');
            tfCurrent.focus();
            return;
        }
        
        if (!laf.verify.isEmpty(tfGoal) && !laf.verify.isNumeric(tfGoal.value)) {
            laf.window.alert('Invalid', 'Please enter a numeric value for weight goal or leave blank.');
            tfGoal.focus();
            return;
        }
        
        // Update weight goal from basic stats table         
        if (!laf.verify.isEmpty(tfGoal) && tfGoal.value.toString().length > 0) {
            updateStatsHistory('SELECT GUID FROM BasicStats WHERE Inactive = 0', 'BasicStats', ['WeightGoal'], [tfGoal.value]);
        }
        
        // Update weight from body fat history
        updateStatsHistory('SELECT GUID FROM WeightHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0', 'WeightHistory', ['Weight', 'StatsDate'], [tfCurrent.value, laf.dateTime.toDateString()]);
        
        laf.window.fire('statsChange');
        
        if (history.length == 0 || history[0].StatsDate != laf.dateTime.toDateString()) {
            guid = laf.data.workoutScalar('SELECT GUID FROM WeightHistory WHERE StatsDate = "' + laf.dateTime.toDateString() + '" AND Inactive = 0');
            if (guid == undefined) {
                guid = laf.object.newGUID();
            }
            
            if (history.length == 0) {
                tvHistory.appendRow(newHistoryRow(laf.dateTime.toDateString(), tfCurrent.value, undefined, guid));
            }
            else {
                tvHistory.insertRowBefore(0, newHistoryRow(laf.dateTime.toDateString(), tfCurrent.value, history[0].Weight, guid));
            }
            
            history.splice(0, 0, {
                Weight: tfCurrent.value,
                StatsDate: laf.dateTime.toDateString(),
                GUID: guid
            });
        }
        else {
            if (history.length > 0) {
                history[0].Weight = tfCurrent.value;
            }
            
            if (laf.device.isiPhone()) {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].Weight, (history.length > 1) ? history[1].Weight : undefined, history[0].GUID), {
                    animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                });
            }
            else {
                tvHistory.updateRow(0, newHistoryRow(history[0].StatsDate, history[0].Weight, (history.length > 1) ? history[1].Weight : undefined, history[0].GUID));
            }
        }
    }
    
    function updateStatsHistory(sqlQuery, fieldTable, fieldNames, fieldValues){
        var guid = laf.data.workoutScalar(sqlQuery);
        if (guid == undefined) {
            guid = laf.object.newGUID();
        }
        laf.data.workoutMakeSync(fieldTable, guid, false, fieldNames, fieldValues);
    }
    
    //=== EVENTS =============================
    btnGraph.addEventListener('click', function(e){
        laf.window.create('Weight', '/views/track/progressWeightGraph.js');
        laf.window.open();
    });
    
    tfCurrent.addEventListener('return', function(e){
        saveStats();
        tfCurrent.blur();
    });
    
    tfGoal.addEventListener('return', function(e){
        saveStats();
        tfGoal.blur();
    });
    
    tvHistory.addEventListener('click', function(e){
    
        if (e.rowData != undefined && e.rowData.guid != undefined) {
            var dlgProgressOptions;
            
            if (laf.device.isAndroid()) {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share'],
                    title: 'Options',
                    buttonNames: ['Cancel']
                });
            }
            else {
                dlgProgressOptions = Ti.UI.createOptionDialog({
                    options: ['Delete', 'Share', 'Cancel'],
                    destructive: 0,
                    cancel: 2
                });
            }
            
            dlgProgressOptions.addEventListener('click', function(data){
                if (data.index == 0 && (!laf.device.isAndroid() || !data.button)) {
                    if (history.length == 1) {
                        laf.window.alert('Must keep at least one entry.');
                        return;
                    }
                    
                    laf.window.alert('Delete Record', 'Are you sure you want to delete?', ['Delete', 'Cancel'], function(msg){
                        if (msg.index == 0) {
                            laf.data.workoutMakeSync('WeightHistory', e.rowData.guid, true);
                            if (e.index == 0) {
                                history.splice(0, 1);
                                tvHistory.deleteRow(0);
                                tfCurrent.value = laf.data.workoutScalar('SELECT Weight FROM WeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC').toString();
                                laf.window.fire('statsChange');
                            }
                            else {
                                history.splice(e.index, 1);
                                tvHistory.deleteRow(e.index);
                                
                                if (laf.device.isiPhone()) {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].Weight, (history.length > 1) ? history[e.index].Weight : undefined, history[e.index - 1].GUID), {
                                        animationStyle: Ti.UI.iPhone.RowAnimationStyle.FADE
                                    });
                                }
                                else {
                                    tvHistory.updateRow(e.index - 1, newHistoryRow(history[e.index - 1].StatsDate, history[e.index - 1].Weight, (history.length > 1) ? history[e.index].Weight : undefined, history[e.index - 1].GUID));
                                }
                            }
                        }
                    });
                }
            });
            
            tfCurrent.blur();
            tfGoal.blur();
            dlgProgressOptions.show();
        }
    });
    
    //=== DISPLAY =============================
    refreshStats();
    vwMain.add(tvHistory);
    vwMain.add(vwHeader);
})();
