function statistics(){
    //=== HEADER & DATA =============================
    Ti.include('../../common/utilPicker.js');
    
    var newStats = {};
    
    //=== OBJECTS =============================		
    var vwActivity = new activityIndicator();
    
    var btnCancel = Ti.UI.createButton({
        title: 'Cancel'
    });
    
    var btnSave = Ti.UI.createButton({
        title: 'Save',
        style: Ti.UI.iPhone.SystemButtonStyle.DONE
    });
    
    var tvStatistics = Ti.UI.createTableView({
        backgroundColor: 'white',
        rowBackgroundColor: 'transparent',
        separatorColor: 'transparent'
    });
    
    function newEditRow(lblText, control){
        var tvrEntry = Ti.UI.createTableViewRow({
            height: 45,
            backgroundSelectedColor: 'white',
            className: lblText
        });
        laf.table.ignoreRowSelection(tvrEntry);
        
        tvrEntry.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            left: 10,
            height: 25,
            width: 100,
            textAlign: 'left',
            fontWeight: 'bold',
            text: lblText
        }));
        
        tvrEntry.add(control);
        
        laf.table.ignoreRowSelection(tvrEntry);
        return tvrEntry;
    }
    
    function newTextField(hintText){
        var tfEntry = Ti.UI.createTextField({
            color: '#336699',
            height: 40,
            left: 100,
            right: 10,
            hintText: hintText,
            borderStyle: Ti.UI.INPUT_BORDERSTYLE_ROUNDED,
            clickName: hintText,
            keyboardType: Ti.UI.KEYBOARD_NUMBERS_PUNCTUATION,
            returnKeyType: Ti.UI.RETURNKEY_DONE
        });
        
        if (laf.device.isAndroid() && hintText != 'Weight') {
            tfEntry.softKeyboardOnFocus = Ti.UI.Android.SOFT_KEYBOARD_HIDE_ON_FOCUS;
        }
        
        return tfEntry;
    }
    
    var tfGender = newTextField('Gender', 18);
    var tfAge = newTextField('Age', 68);
    var tfHeight = newTextField('Height', 118);
    var tfWeight = newTextField('Weight', 168);
    
    //=== FUNCTIONS =============================
    function getAge(birthday){
        var now = new Date();
        var age = now.getFullYear() - birthday.getFullYear();
        if (now.getMonth() < birthday.getMonth() || (now.getMonth() == birthday.getMonth() && now.getDate() < birthday.getDate())) {
            --age;
        }
        return age;
    }
    
    function setSetupRows(){
        var data = [];
        
        data.push(laf.table.section('Setup'));
        
        var tvrHeader = Ti.UI.createTableViewRow({
            height: 100,
            className: 'HeaderRow'
        });
        laf.table.ignoreRowSelection(tvrHeader);
        
        tvrHeader.add(Ti.UI.createView({
            backgroundImage: laf.path.images + 'gear.png',
            height: 48,
            width: 48,
            top: 25,
            right: 10
        }));
        
        tvrHeader.add(Ti.UI.createLabel({
            color: 'black',
            font: {
                fontSize: 18,
                fontFamily: 'Arial'
            },
            top: 5,
            left: 15,
            right: 60,
            height: 80,
            textAlign: 'left',
            text: 'In order to track & analyze your fitness the following information is required.'
        }));
        
        data.push(tvrHeader);
        
        data.push(newEditRow('Gender:', tfGender));
        data.push(newEditRow('Age:', tfAge));
        data.push(newEditRow('Height:', tfHeight));
        data.push(newEditRow('Weight:', tfWeight));
        
        tvStatistics.setData(data);
        laf.table.scrollToTop(tvStatistics, false);
    }
    
    function refresh(){
        newStats = {};
        
        newStats = laf.data.workoutRow('SELECT Gender, Birthday FROM BasicStats WHERE Inactive = 0 ORDER BY UpdateUTC DESC LIMIT 1', ['Gender', 'Birthday']);
        if (!laf.verify.isEmpty(newStats.Gender)) {
            tfGender.value = (newStats.Gender == 'F') ? 'Female' : 'Male';
        }
        
        if (!laf.verify.isEmpty(newStats.Birthday)) {
            tfAge.value = newStats.Age = getAge(new Date(laf.dateTime.toDateString(newStats.Birthday)));
        }
        
        var currentValue = laf.data.workoutScalar('SELECT Weight FROM WeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            tfWeight.value = newStats.Weight = currentValue;
        }
        
        currentValue = laf.data.workoutScalar('SELECT Height FROM HeightHistory WHERE Inactive = 0 ORDER BY StatsDate DESC LIMIT 1');
        if (!laf.verify.isEmpty(currentValue)) {
            var heightInInches = newStats.Height = parseInt(currentValue, 10);
            tfHeight.value = parseInt(heightInInches / 12, 10) + '\' ';
            tfHeight.value += parseInt(heightInInches % 12, 10) + '"';
        }
    }
    
    function rowSelection(rowName){
        switch (rowName) {
            case 'Age':
                tfAge.blur();
                var dftDate = new Date();
                if (newStats.Birthday != undefined) {
                    dftDate = new Date(new Date(laf.dateTime.toDateString(newStats.Birthday)));
                }
                datePicker('Select your birthday:', 'Select Birthday', undefined, undefined, dftDate, function(selectedDate){
                    if (selectedDate != undefined) {
                        if (selectedDate > new Date()) {
                            laf.window.alert('Birthday in Future', 'Error: You cannot have been born in the future.');
                        }
                        else {
                            newStats.Birthday = laf.dateTime.toDateString(selectedDate);
                            newStats.Age = getAge(selectedDate);
                            tfAge.value = newStats.Age;
                        }
                    }
                });
                break;
            case 'Gender':
                tfGender.blur();
                var dftGender = (newStats.Gender != undefined && newStats.Gender == 'F') ? 'Female' : 'Male';
                if (laf.device.isiPhone()) {
                    standardPicker('Select your gender:', 'Select Gender', ['Male,Female'], [dftGender], function(selectedValues){
                        if (selectedValues != undefined && selectedValues.length > 0 && selectedValues[0].length > 0) {
                            newStats.Gender = selectedValues[0].substring(0, 1);
                            tfGender.value = selectedValues[0];
                        }
                    });
                }
                else {
                    standardPickerForAndroid('Select your gender:', 'Select Gender', ['Male', 'Female'], undefined, undefined, [dftGender], function(selectedValues){
                        if (selectedValues != undefined && selectedValues.length > 0) {
                            newStats.Gender = selectedValues.substring(0, 1);
                            tfGender.value = selectedValues;
                        }
                    });
                }
                break;
            case 'Height':
                tfHeight.blur();
                var dftFeet;
                var dftInches;
				
                if (newStats.Height != undefined) {
                    var heightInInches = parseInt(newStats.Height, 10);
                    dftFeet = parseInt(heightInInches / 12, 10) + '\'';
                    dftInches = ' ' + parseInt(heightInInches % 12, 10) + '"';
                }

                var oncomplete = function(selectedValues){
                    if (selectedValues != undefined && selectedValues.length > 0 && selectedValues[0].length > 0) {
                        if (laf.device.isAndroid()) {
                            tfHeight.value = selectedValues;
                        }
                        else {
                            tfHeight.value = '';
                            for (var i = 0; i < selectedValues.length; i++) {
                                tfHeight.value += selectedValues[i];
                            }
                        }
                        
                        var heightValue = parseInt(tfHeight.value.toString().substring(0, tfHeight.value.toString().indexOf('\'')), 10);
                        heightValue = heightValue * 12;
                        heightValue += parseInt(tfHeight.value.toString().substring(tfHeight.value.toString().indexOf('\'') + 1), 10);
                        newStats.Height = heightValue;
                    }
                };
                
                if (laf.device.isiPhone()) {
                    standardPicker('Select your height:', 'Select Height', [',3\',4\',5\',6\',7\'', ' 0", 1", 2", 3", 4", 5", 6", 7", 8", 9", 10", 11"'], [dftFeet, dftInches], oncomplete);
                }
                else {
                    standardPickerForAndroid('Select your height:', 'Select Height', ['3\'', '4\'', '5\'', '6\'', '7\''], [' 0"', ' 1"', ' 2"', ' 3"', ' 4"', ' 5"', ' 6"', ' 7"', ' 8"', ' 9"', ' 10"', ' 11"'], undefined, [dftFeet, dftInches], oncomplete);
                }
                break;
        }
    }
    
    
    function saveStats(){
        tfWeight.blur();
        laf.table.scrollToTop(tvStatistics, false);
        
        if (laf.verify.isEmpty(newStats.Gender)) {
            laf.window.alert('Required', 'Please select your gender.');
            return;
        }
        
        if (laf.verify.isEmpty(newStats.Age) || laf.verify.isEmpty(newStats.Birthday)) {
            laf.window.alert('Required', 'Please enter your age.');
            return;
        }
        
        if (laf.verify.isEmpty(newStats.Height)) {
            laf.window.alert('Required', 'Please enter your height.');
            return;
        }
        
        if (laf.verify.isEmpty(tfWeight) || !laf.verify.isNumeric(tfWeight.value)) {
            laf.window.alert(laf.verify.isEmptry(tfWeight) ? 'Required' : 'Invalid', 'Please enter your weight in pounds.');
            tfWeight.focus();
            return;
        }
        
        var statsDate = laf.dateTime.toDateString();
        laf.data.workoutMakeSync('BasicStats', undefined, false, ['Gender', 'Birthday'], [newStats.Gender, newStats.Birthday]);
        laf.data.workoutMakeSync('WeightHistory', undefined, false, ['Weight', 'StatsDate'], [tfWeight.value, statsDate]);
        laf.data.workoutMakeSync('HeightHistory', undefined, false, ['Height', 'StatsDate'], [newStats.Height, statsDate]);
        
        laf.window.alert('Saved');
    }
    
    //=== EVENTS =============================
	tfWeight.addEventListener('return', saveStats);	
	
    btnSave.addEventListener('click', function(e){
        saveStats();
    });
    
    btnCancel.addEventListener('click', function(e){
        win.close();
    });
    
    if (laf.device.isiPhone()) {
        tfAge.addEventListener('focus', function(e){
            rowSelection('Age');
        });
        
        tfGender.addEventListener('focus', function(e){
            rowSelection('Gender');
        });
        
        tfHeight.addEventListener('focus', function(e){
            rowSelection('Height');
        });
    };
    
    if (laf.device.isAndroid()) {
        tvStatistics.addEventListener('click', function(e){
            if (e.source.clickName) {
                rowSelection(e.source.clickName);
            }
        });
    }
    
    //=== DISPLAY =============================
    this.hide = function(){
        setLeftNav(null);
        setRightNav(null);
        tvStatistics.visible = false;
    };
    
    this.show = function(){
        setLeftNav(btnCancel);
        setRightNav(btnSave);
        tvStatistics.visible = true;
    };
    
    this.view = function(){
        return tvStatistics;
    };
    
    this.refresh = function(){
        vwActivity.show('Loading...');
        setSetupRows();
        refresh();
        vwActivity.hide();
    };
};
